@@ -236,7 +236,7 @@ int AsciiSource::readFullLine(QFile &file, QString &str) {
 
   return read;
 }
- 
+
 
 bool AsciiSource::initRowIndex() {
   if (!_rowIndex) {
@@ -284,7 +284,7 @@ KstObject::UpdateType AsciiSource::update(int u) {
     // Re-update the field list since we have one now
     _fields = fieldListFor(_filename, _config);
     _fieldListComplete = _fields.count() > 1;
-    
+
     // Re-update the matrix list since we have one now
     _matrixList = matrixList();
   }
@@ -308,12 +308,12 @@ KstObject::UpdateType AsciiSource::update(int u) {
   }
 
   _valid = true;
-  
+
   int bufstart, bufread;
   bool new_data = false;
   char tmpbuf[MAXBUFREADLEN+1];
   const char *del = _config->_delimiters; // beware
-  
+
   do {
     /* Read the tmpbuffer, starting at row_index[_numFrames] */
     if (_byteLength - _rowIndex[_numFrames] > MAXBUFREADLEN) {
@@ -326,11 +326,11 @@ KstObject::UpdateType AsciiSource::update(int u) {
     file.at(bufstart); // expensive?
     file.readBlock(tmpbuf, bufread);
     tmpbuf[bufread] = '\0';
-    
+
     bool is_comment = false, has_dat = false;
     char *comment = strpbrk(tmpbuf, del);
-    for (int i = 0; i < bufread; i++) {      
-      if (comment == &(tmpbuf[i])) {    
+    for (int i = 0; i < bufread; i++) {
+      if (comment == &(tmpbuf[i])) {
         is_comment = true;
       } else if (tmpbuf[i] == '\n' || tmpbuf[i] == '\r') {
         if (has_dat) {
@@ -352,7 +352,7 @@ KstObject::UpdateType AsciiSource::update(int u) {
       }
     }
   } while (bufread == MAXBUFREADLEN);
-  
+
   file.close();
 
   updateNumFramesScalar();
@@ -366,14 +366,13 @@ bool AsciiSource::fieldListIsComplete() const {
 
 
 bool AsciiSource::matrixDimensions(const QString& matrix, int* xDim, int* yDim) {
-  
   if (!isValidMatrix(matrix)) {
-    return false;  
+    return false;
   }
 
   // total frames in the matrix
   int totalFrames = frameCount(matrix);
-  
+
   // y dimension is in the matrix name
   *yDim = matrix.section(',', 1,1).toInt();
   *xDim = totalFrames / (*yDim); // the last row doesn't count
@@ -382,16 +381,16 @@ bool AsciiSource::matrixDimensions(const QString& matrix, int* xDim, int* yDim)
 
 
 int AsciiSource::readMatrix(KstMatrixData* data, const QString& matrix, int xStart, int yStart, int xNumSteps, int yNumSteps) {
-  
+
   if (!isValidMatrix(matrix)) {
-    return 0;  
+    return 0;
   }
-  
+
   // empty submatrix
   if (xNumSteps == 0 || yNumSteps == 0) {
-    return 0;  
+    return 0;
   }
-  
+
   // first get matrix parameters - for ascii, this is just in the field name in the
   // form [MATRIX,Y,x,y,w,l]
   int mYDimension = matrix.section(',', 1,1).toInt();
@@ -401,42 +400,42 @@ int AsciiSource::readMatrix(KstMatrixData* data, const QString& matrix, int xSta
   QString mYStepSizeString = matrix.section(',', 5,5);
   mYStepSizeString.truncate(mYStepSizeString.length() - 1);
   double mYStepSize = mYStepSizeString.toDouble();
-  
+
   // if we are trying to start beyond the y dimension, just return 0 samples read
   if (yStart >= mYDimension) {
-    return 0;  
+    return 0;
   }
-  
+
   // ?NumSteps < 0 means read one sample per frame - but AsciiSource always has 1 sample per frame
   if (xNumSteps < 0) {
-    xNumSteps = 1;   
-  }  
-  if (yNumSteps < 0) {
-    yNumSteps = 1;  
+    xNumSteps = 1;
   }
-  
+  if (yNumSteps < 0) {
+    yNumSteps = 1;
+  }
+
   // make sure requested number of steps in y direction is not greater than the 
   // y dimension of the matrix - can't just reduce it because yNumSteps is not returned
   if (yNumSteps + yStart > mYDimension) {
-    return 0; 
-  } 
+    return 0;
+  }
   // use readField to read the specified matrix range 
   // (for AsciiSource, all matrix fields are vector fields as well)
   double* zPos = data->z;
   int totalSamples = 0;
-  
+
   for (int i = 0; i < xNumSteps; i++) {
     int samples = readField(zPos, matrix, xStart*mYDimension + i*mYDimension + yStart, yNumSteps);
     totalSamples += samples;
     zPos += samples;
   }
-  
+
   // set the suggested matrix transform params
   data->xMin = mXMin + xStart*mXStepSize;
   data->yMin = mYMin + yStart*mYStepSize;
   data->xStepSize = mXStepSize;
   data->yStepSize = mYStepSize;
-  
+
   return totalSamples;
 }
 
@@ -534,7 +533,7 @@ int AsciiSource::readField(double *v, const QString& field, int s, int n) {
     for (int i = 0; i < n; i++, s++) {
       bool incol = false;
       uint i_col = 0;
-      
+
       v[i] = KST::NOPOINT;
       for (int ch = _rowIndex[s] - bufstart; ch < bufread; ++ch) {     
         if (isspace(_tmpBuf[ch])) {
@@ -576,7 +575,7 @@ bool AsciiSource::isValidField(const QString& field) const {
 
 
 bool AsciiSource::isValidMatrix(const QString& matrix) const {
-  return matrixList().contains(matrix);  
+  return matrixList().contains(matrix);
 }
 
 
@@ -734,7 +733,7 @@ QStringList AsciiSource::matrixList() const {
     //       l = y step size
     _matrixList = fieldList().grep(QRegExp("^\\[\\w*,\\S*,\\S*,\\S*,\\S*,\\S*\\]$"));
   }
-  
+
   return _matrixList;
 }
 
@@ -790,6 +789,100 @@ int AsciiSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
 }
 
 
+QString AsciiSource::configuration(QString setting) {
+  if (setting.lower() == "commentindicators") {
+    return _config->_delimiters;
+  } else if (setting.lower() == "alwaysacceptfilesmatching") {
+    return _config->_fileNamePattern;
+  } else if (setting.lower() == "datastartline") {
+    return QString("%1").arg(_config->_dataLine);
+  } else if (setting.lower() == "readfieldnames") {
+    if (_config->_readFields) {
+      return QString("true");
+    } else {
+      return QString("false");
+    }
+  } else if (setting.lower() == "readfieldnamesline") {
+    return QString("%1").arg(_config->_fieldsLine);
+  } else if (setting.lower() == "dataformat") {
+    return QString("%1").arg(_config->_columnType);
+  } else if (setting.lower() == "columndelimiter") {
+    return _config->_columnDelimiter;
+  } else if (setting.lower() == "columnwidth") {
+    return QString("%1").arg(_config->_columnWidth);
+  }
+
+  return QString();
+}
+
+
+bool AsciiSource::setConfiguration(QString setting, const QString &value) {
+  if (setting.lower() == "commentindicators") {
+    _config->_delimiters = value.utf8();
+    return true;
+  } else if (setting.lower() == "alwaysacceptfilesmatching") {
+    _config->_fileNamePattern = value;
+    return true;
+  } else if (setting.lower() == "datastartline") {
+    bool ok;
+    int val = value.toInt(&ok);
+    if (ok) {
+      _config->_dataLine = val;
+      return true;
+    }
+  } else if (setting.lower() == "readfieldnames") {
+    if (value.lower() == "true") {
+      _config->_readFields = true;
+      return true;
+    } else if (value.lower() == "false") {
+      _config->_readFields = false;
+      return true;
+    }
+  } else if (setting.lower() == "readfieldnamesline") {
+    bool ok;
+    int val = value.toInt(&ok);
+    if (ok) {
+      _config->_fieldsLine = val;
+      return true;
+    }
+  } else if (setting.lower() == "dataformat") {
+    if (value.lower() == "whitespacedelimited") {
+      _config->_columnType = Config::Whitespace;
+      return true;
+    } else if (value.lower() == "fixedwidthcolumns") {
+      _config->_columnType = Config::Fixed;
+      return true;
+    } else if (value.lower() == "customdelimiter") {
+      _config->_columnType = Config::Custom;
+      return true;
+    }
+
+    bool ok;
+    int val = value.toInt(&ok);
+    if (ok) {
+      if (val >= 0 && val < 3) {
+        _config->_columnType = (Config::ColumnType)val;
+        return true;
+      }
+    }
+  } else if (setting.lower() == "columndelimiter") {
+    _config->_columnDelimiter = value.utf8();
+    return true;
+  } else if (setting.lower() == "columnwidth") {
+    bool ok;
+    int val = value.toInt(&ok);
+    if (ok) {
+      if (val >= 0) {
+        _config->_columnWidth = val;
+        return true;
+      }
+    }
+  }
+
+  return false;
+}
+
+
 class ConfigWidgetAscii : public KstDataSourceConfigWidget {
   public:
     ConfigWidgetAscii() : KstDataSourceConfigWidget() {
@@ -832,7 +925,7 @@ class ConfigWidgetAscii : public KstDataSourceConfigWidget {
         if (_instance->fieldList().contains(src->_config->_indexVector)) {
           _ac->_indexVector->setCurrentText(src->_config->_indexVector);
         }
-        
+
         _cfg->setGroup(src->fileName());
         _ac->_delimiters->setText(_cfg->readEntry("Comment Delimiters", _ac->_delimiters->text()));
         _ac->_columnDelimiter->setText(_cfg->readEntry("Column Delimiter", _ac->_columnDelimiter->text()));
@@ -1008,4 +1101,3 @@ QWidget *widget_ascii(const QString& filename) {
 
 KST_KEY_DATASOURCE_PLUGIN(ascii)
 
-// vim: ts=2 sw=2 et
