@@ -16,22 +16,66 @@
  ***************************************************************************/
 
 #include "planckIDEF.h"
+#include "planckIDEFconfig.h"
 
 #include <ctype.h>
 #include <stdlib.h>
 
+#include <qcheckbox.h>
 #include <qdir.h>
 #include <qfile.h>
 #include <qfileinfo.h>
+#include <qlayout.h>
+#include <qlineedit.h>
+#include <qradiobutton.h>
+#include <qregexp.h>
+#include <qspinbox.h>
+#include <qstylesheet.h>
 
 #include <kdebug.h>
 
 #include "kststring.h"
 
-#define TIME_FIELD  "TIME"
+class PLANCKIDEFSource::Config {
+  public:
+    Config() {
+      _checkFilename = true;
+    }
 
-PLANCKIDEFSource::PLANCKIDEFSource( KConfig *cfg, const QString& filename, const QString& type )
-: KstDataSource( cfg, filename, type )
+    void read(KConfig *cfg, const QString& fileName = QString::null) {
+      Q_UNUSED( fileName );
+
+      cfg->setGroup("PlanckIDEF General");
+      _checkFilename = cfg->readBoolEntry("Check Filename", true);
+    }
+
+    bool _checkFilename;
+
+    void save(QTextStream& str, const QString& indent) {
+      if (_checkFilename) {
+        str << indent << "checkfilename=\"" << _checkFilename << "\"/>";
+      }
+    }
+
+    void load(const QDomElement& e) {
+      _checkFilename = false;
+
+      QDomNode n = e.firstChild();
+      while (!n.isNull()) {
+        QDomElement e = n.toElement();
+        if (!e.isNull()) {
+          if (e.tagName() == "checkfilename") {
+            _checkFilename = true;
+          }
+        }
+        n = n.nextSibling();
+      }
+   }
+};
+
+
+PLANCKIDEFSource::PLANCKIDEFSource( KConfig *cfg, const QString& filename, const QString& type, const QDomElement& e)
+: KstDataSource( cfg, filename, type ), _config(0L)
 {
   _fields.setAutoDelete( TRUE );
 
@@ -39,6 +83,12 @@ PLANCKIDEFSource::PLANCKIDEFSource( KConfig *cfg, const QString& filename, const
   {
     if( initialize( ) )
     {
+      _config = new PLANCKIDEFSource::Config;
+      _config->read(cfg, filename);
+      if (!e.isNull()) {
+        _config->load(e);
+      }
+
       _valid = true;
     }
   }
@@ -47,55 +97,151 @@ PLANCKIDEFSource::PLANCKIDEFSource( KConfig *cfg, const QString& filename, const
 
 PLANCKIDEFSource::~PLANCKIDEFSource( )
 {
+  delete _config;
+  _config = 0L;
 }
 
 
-bool PLANCKIDEFSource::isValidFilename( const QString& filename )
+bool PLANCKIDEFSource::isValidFilename( const QString& filename, Config *config )
 {
   bool ok = false;
-  unsigned minLength = 21;
 
-  if( filename.right( 3 ).lower( ) == ".gz" ) 
+  if( !config || config->_checkFilename )
   {
-    minLength += 3;
-  }
+    unsigned gzLength;
 
-  //
-  // _yyyymmddhhmm_vv.fits
-  //  yyyy = four digits coding the start timeline year
-  //  mm = two digits coding the start timeline month
-  //  dd = two digits coding the start timeline day
-  //  hh = two digits coding the start timeline hour
-  //  mm = two digits coding the start timeline minute
-  //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
-  //
-  if( filename.length() > minLength )
-  {
-    int year;
-    int month;
-    int day;
-    int hour;
-    int minute;
-    int version;
-
-    QString tail = filename.right( minLength );
-
-    if( sscanf( tail.latin1(), "_%4d%2d%2d%2d%2d_%2d.fits", &year, &month, &day, &hour, &minute, &version ) == 6 )
+    if( filename.right( 3 ).lower( ) == ".gz" ) 
     {
-      if( year > 0      &&
-          month >= 1    &&
-          month <= 12   &&
-          day >= 1      &&
-          day <= 31     &&
-          hour >= 0     &&
-          hour <= 24    &&
-          minute >= 0   &&
-          minute <= 60  &&
-          version >= 0  )
+      gzLength = 3;
+    }
+    else
+    {
+      gzLength = 0;
+    }
+
+    if( !ok )
+    {
+      //
+      // check for a valid science timeline file...
+      //
+      // Accc-xxxx-T-yyyymmdd.fits
+      //  A = one character coding the instrument identifier
+      //  ccc = three character coding the obervation frequency
+      //  xxxx = four digits identifying the operational day to which the data belong
+      //  T = {C,R} one letter identifying if the timeline is converted or reduced
+      //  yyyy = four digits coding the start timeline year
+      //  mm = two digits coding the start timeline month
+      //  dd = two digits coding the start timeline day
+      //
+
+      unsigned checkLength = gzLength + 25;
+      if( filename.length() >= checkLength )
       {
-        ok = true;
+        QString tail = filename.right( checkLength );
+        char instrument;
+        char frequency[3];
+        char timeline;
+        int operationalDay;
+        int year;
+        int month;
+        int day;
+
+        if( sscanf( tail.latin1(), "%c%c%c%c-%4d-%c-%4d%2d%2d.fits", 
+          &instrument, &frequency[0], &frequency[1], &frequency[2], 
+          &operationalDay, &timeline, &year, &month, &day ) == 9 )
+        {
+          if( year > 0      &&
+              month >= 1    &&
+              month <= 12   &&
+              day >= 1      &&
+              day <= 31     )
+          {
+            ok = true;
+          }
+        }
       }
     }
+
+    if( !ok )
+    {
+      //
+      // check for a valid HK timeline file...
+      //
+      // A-namefile-xxxx-yyyymmdd.fits
+      //  A = one character coding the instrument identifier
+      //  xxxx = four digits identifying the operational day to which the data belong
+      //  yyyy = four digits coding the start timeline year
+      //  mm = two digits coding the start timeline month
+      //  dd = two digits coding the start timeline day
+      //
+
+      unsigned checkLength = gzLength + 19;
+      if( filename.length() >= checkLength )
+      {
+        QString tail = filename.right( checkLength );
+        int operationalDay;
+        int year;
+        int month;
+        int day;
+
+        if( sscanf( tail.latin1(), "-%4d-%4d%2d%2d.fits", 
+          &operationalDay, &year, &month, &day ) == 4 )
+        {
+          if( year > 0      &&
+              month >= 1    &&
+              month <= 12   &&
+              day >= 1      &&
+              day <= 31     )
+          {
+            ok = true;
+          }
+        }
+      }
+    }
+
+    if( !ok )
+    {
+      //
+      // check for a previosuly valid definition of the filename...
+      //
+      // *_yyyymmddhhmm_vv.fits
+      //  yyyy = four digits coding the start timeline year
+      //  mm = two digits coding the start timeline month
+      //  dd = two digits coding the start timeline day
+      //  hh = two digits coding the start timeline hour
+      //  mm = two digits coding the start timeline minute
+      //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
+      //
+
+      unsigned checkLength = gzLength + 21;
+      if( filename.length() >= checkLength )
+      {
+        QString tail = filename.right( checkLength );
+        int year;
+        int month;
+        int day;
+        int hour;
+        int minute;
+        int version;
+
+        if( sscanf( tail.latin1(), "_%4d%2d%2d%2d%2d_%2d.fits", 
+            &year, &month, &day, &hour, &minute, &version ) == 6 )        
+        {
+          if( year > 0      &&
+              month >= 1    &&
+              month <= 12   &&
+              day >= 1      &&
+              day <= 31     )
+          {
+            ok = true;
+          }
+        }
+      }
+    }
+  }
+  else
+  {
+    ok = true;
   }
 
   return ok;
@@ -105,7 +251,7 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename )
 QString PLANCKIDEFSource::baseFilename( const QString& filename )
 {
   QString base;
-  unsigned minLength = 21;
+  unsigned minLength = 14;
 
   if( filename.right( 3 ).lower( ) == ".gz" ) 
   {
@@ -113,13 +259,10 @@ QString PLANCKIDEFSource::baseFilename( const QString& filename )
   }
 
   //
-  // _yyyymmddhhmm_vv.fits
+  // -yyyymmdd.fits
   //  yyyy = four digits coding the start timeline year
   //  mm = two digits coding the start timeline month
   //  dd = two digits coding the start timeline day
-  //  hh = two digits coding the start timeline hour
-  //  mm = two digits coding the start timeline minute
-  //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
   //
   if( filename.length() > minLength )
   {
@@ -130,41 +273,6 @@ QString PLANCKIDEFSource::baseFilename( const QString& filename )
 }
 
 
-int PLANCKIDEFSource::versionNumber( const QString& filename )
-{
-  int version = -1;
-  unsigned minLength = 21;
-
-  if( filename.right( 3 ).lower( ) == ".gz" ) 
-  {
-    minLength += 3;
-  }
-
-  //
-  // _yyyymmddhhmm_vv.fits
-  //  yyyy = four digits coding the start timeline year
-  //  mm = two digits coding the start timeline month
-  //  dd = two digits coding the start timeline day
-  //  hh = two digits coding the start timeline hour
-  //  mm = two digits coding the start timeline minute
-  //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
-  //
-  if( filename.length() > minLength )
-  {
-    char time[13];
-
-    QString tail = filename.right( minLength );
-
-    if( sscanf( tail.latin1(), "_%12s_%2d.fits", time, &version ) != 2 )
-    {
-      version = -1;
-    }
-  }
-
-  return version;
-}
-
-
 bool PLANCKIDEFSource::reset( )
 {
   return true;
@@ -571,7 +679,7 @@ bool PLANCKIDEFSource::initFolder( )
   {
     for( QStringList::ConstIterator it = files.begin(); it != files.end(); ++it )
     {
-      if( isValidFilename( *it ) )
+      if( isValidFilename( *it, 0L ) )
       {
         fileList*   folderFields;
         folderField folderField;
@@ -919,8 +1027,6 @@ int PLANCKIDEFSource::samplesPerFrame( const QString& fieldName )
 
 int PLANCKIDEFSource::frameCount( const QString& fieldName ) const
 {
-  Q_UNUSED( fieldName )
-
   int rc = 0;
 
   if( _isSingleFile )
@@ -931,17 +1037,20 @@ int PLANCKIDEFSource::frameCount( const QString& fieldName ) const
   {
     field* fld;
 
-    fld = _fields.find( fieldName );
-    if( fld != 0L )
+    if( !fieldName.isEmpty() )
     {
-      fileList* folderFields;
-
-      folderFields = _basefiles.find( fld->basefile );
-      if( folderFields != 0L )
+      fld = _fields.find( fieldName );
+      if( fld != 0L )
       {
-        for( fileList::ConstIterator it = folderFields->begin(); it != folderFields->end(); ++it )
+        fileList* folderFields;
+
+        folderFields = _basefiles.find( fld->basefile );
+        if( folderFields != 0L )
         {
-          rc += (*it).frames;
+          for( fileList::ConstIterator it = folderFields->begin(); it != folderFields->end(); ++it )
+          {
+            rc += (*it).frames;
+          }
         }
       }
     }
@@ -966,6 +1075,7 @@ QString PLANCKIDEFSource::fileType( ) const
 void PLANCKIDEFSource::save( QTextStream& ts, const QString& indent )
 {
   KstDataSource::save( ts, indent );
+  _config->save(ts, indent);
 }
 
 
@@ -989,7 +1099,7 @@ bool PLANCKIDEFSource::checkValidPlanckIDEFFolder( const QString& filename )
     {
       pathname = folder.path() + separator() + *it;
 
-      if( checkValidPlanckIDEFFile( pathname ) )
+      if( checkValidPlanckIDEFFile( pathname, 0L ) )
       {
         ok = true;
 
@@ -1002,7 +1112,7 @@ bool PLANCKIDEFSource::checkValidPlanckIDEFFolder( const QString& filename )
 }
 
 
-bool PLANCKIDEFSource::checkValidPlanckIDEFFile( const QString& filename )
+bool PLANCKIDEFSource::checkValidPlanckIDEFFile( const QString& filename, Config *cfg )
 {
   bool ok = false;
   fitsfile* ffits;
@@ -1011,7 +1121,7 @@ bool PLANCKIDEFSource::checkValidPlanckIDEFFile( const QString& filename )
   //
   // determine if it is a Planck IDIS DMC Exchange Format file...
   //
-  if( isValidFilename( filename ) )
+  if( isValidFilename( filename, cfg ) )
   {
     if( fits_open_file( &ffits, filename.ascii( ), READONLY, &iStatus ) == 0 )
     {
@@ -1064,7 +1174,6 @@ bool PLANCKIDEFSource::checkValidPlanckIDEFFile( const QString& filename )
           {
             long rowsCompare = 0;
             long rows;
-            bool bAbsoluteTimes = false;
             int cols;
 
             for( i=0; i<iNumHeaderDataUnits-1 && ok; i++ )
@@ -1079,56 +1188,17 @@ bool PLANCKIDEFSource::checkValidPlanckIDEFFile( const QString& filename )
                 {
                   if( fits_read_keyword( ffits, "EXTNAME", value, comment, &iStatus ) == 0 )
                   {
-                    QString section = QString( value ).section( '-', 1, 1 );
+                    QString section = value;
 
-                    if( section.compare( "OBTT" ) == 0 ||
-                        section.compare( "TOD." ) == 0 ||
-                        section.compare( "OBTH" ) == 0 ||
-                        section.compare( "HKP." ) == 0 )
-                    {
-                      if( section.compare( "OBTT" ) == 0)
-                      {
-                        bOBTHeader = true;
-                      }
+                    ok = true;
 
-                      ok = true;
-                    }
-                    else
+                    section.stripWhiteSpace();
+                    if( section.compare( "OBT" ) == 0 )
                     {
-                      ok = false;
+                      bOBTHeader = true;
                     }
                   }
 
-                  //
-                  // for OBT information the TIMEZERO flag is "UTC value corresponding to first OBT
-                  //  value (keyword omitted if times are only relative)"
-                  //
-                  // for channel information if the TIMEZERO flag is present then it must have the 
-                  //  "same meaning and value as in corresponding arrays of OBTs - the presence of 
-                  //  this keyword means that TOD is expressed with absolute times."
-                  //
-                  if( ok && fits_read_keyword( ffits, "TIMEZERO", value, comment, &iStatus ) == 0 )
-                  {
-                    if( bOBTHeader )
-                    {
-                      bAbsoluteTimes = true;
-                    }
-                    else if( !bAbsoluteTimes )
-                    {
-                      //
-                      // the channel information has the keyword TIMEZERO value but the OBT header does not...
-                      //
-                      ok = false;
-                    }
-                  }
-                  else if( bAbsoluteTimes )
-                  {
-                    //
-                    // the channel information does not have the keyword TIMEZERO value but the OBT header does...
-                    //
-                    ok = false;
-                  }
-
                   //
                   // all tables should have the same number of rows...
                   //
@@ -1197,12 +1267,79 @@ bool PLANCKIDEFSource::checkValidPlanckIDEFFile( const QString& filename )
 }
 
 
+QString PLANCKIDEFSource::configuration(QString setting) 
+{
+  if (setting.lower() == "checkfilename") 
+  {
+    if (_config->_checkFilename) 
+    {
+      return QString("true");
+    }
+    else
+    {
+      return QString("false");
+    }
+  }
+
+  return QString();
+}
+
+
+bool PLANCKIDEFSource::setConfiguration(QString setting, const QString &value) {
+  if (setting.lower() == "checkfilename") {
+    if (value.lower() == "true") {
+      _config->_checkFilename = true;
+      return true;
+    } else if (value.lower() == "false") {
+      _config->_checkFilename = false;
+      return true;
+    }
+  }
+
+  return false;
+}
+
+
+class ConfigWidgetPlanckIDEF : public KstDataSourceConfigWidget {
+  public:
+    ConfigWidgetPlanckIDEF() : KstDataSourceConfigWidget() {
+      QGridLayout *layout = new QGridLayout(this, 1, 1);
+      _ac = new PlanckIDEFConfig(this);
+      layout->addWidget(_ac, 0, 0);
+      layout->activate();
+    }
+
+    virtual ~ConfigWidgetPlanckIDEF() {}
+
+    virtual void setConfig(KConfig *cfg) {
+      KstDataSourceConfigWidget::setConfig(cfg);
+    }
+
+    virtual void load() {
+      _cfg->setGroup("PlanckIDEF General");
+      _ac->_checkFilename->setChecked(_cfg->readBoolEntry("Check Filename", true));
+    }
+
+    virtual void save() {
+      _cfg->setGroup("PlanckIDEF General");
+      _cfg->writeEntry("Check Filename", (int)_ac->_checkFilename->isChecked());
+    }
+
+    PlanckIDEFConfig *_ac;
+};
+
+
 extern "C" {
   KstDataSource *create_planckIDEF( KConfig *cfg, const QString& filename, const QString& type )
   {
     return new PLANCKIDEFSource( cfg, filename, type );
   }
 
+  KstDataSource *load_planckIDEF(KConfig *cfg, const QString& filename, const QString& type, const QDomElement& e) 
+  {
+    return new PLANCKIDEFSource(cfg, filename, type, e);
+  }
+
   QStringList provides_planckIDEF( )
   {
     QStringList rc;
@@ -1217,14 +1354,17 @@ extern "C" {
     return true;
   }
 
-  int understands_planckIDEF( KConfig*, const QString& filename )
+  int understands_planckIDEF( KConfig* cfg, const QString& filename )
   {
+    PLANCKIDEFSource::Config config;
     QFileInfo fileinfo( filename );
     int       iRetVal = 0;
 
+    config.read(cfg, filename);
+
     if( fileinfo.isFile( ) )
     {
-      if( PLANCKIDEFSource::checkValidPlanckIDEFFile( filename ) )
+      if( PLANCKIDEFSource::checkValidPlanckIDEFFile( filename, &config ) )
       {
         iRetVal = 99;
       }
@@ -1239,6 +1379,12 @@ extern "C" {
 
     return iRetVal;
   }
+
+  QWidget *widget_planckIDEF(const QString& filename) {
+    Q_UNUSED(filename)
+
+    return new ConfigWidgetPlanckIDEF;
+  }
 }
 
 KST_KEY_DATASOURCE_PLUGIN(planckIDEF)
