@@ -39,7 +39,7 @@ typedef struct {
 
 class PLANCKIDEFSource : public KstDataSource {
   public:
-    PLANCKIDEFSource(KConfig *cfg, const QString& filename, const QString& type);
+    PLANCKIDEFSource(KConfig *cfg, const QString& filename, const QString& type, const QDomElement& e = QDomElement());
    ~PLANCKIDEFSource();
 
     KstObject::UpdateType update(int = -1);
@@ -52,8 +52,11 @@ class PLANCKIDEFSource : public KstDataSource {
     bool                  isEmpty() const;
     bool                  supportsHierarchy() const;
     bool                  reset();
+    virtual QString       configuration(QString setting);
+    virtual bool          setConfiguration(QString setting, const QString &value);
 
-    static bool           checkValidPlanckIDEFFile( const QString& filename );
+    class Config;
+    static bool           checkValidPlanckIDEFFile( const QString& filename, PLANCKIDEFSource::Config *config );
     static bool           checkValidPlanckIDEFFolder( const QString& filename );
 
   private:
@@ -62,9 +65,8 @@ class PLANCKIDEFSource : public KstDataSource {
     int                   readFileFrames( const QString& filename, field *fld, double *v, int s, int n );
     int                   readFolderFrames( field *fld, double *v, int s, int n );
 
-    static bool           isValidFilename( const QString& filename );
+    static bool           isValidFilename( const QString& filename, Config *config );
     static QString        baseFilename( const QString& filename );
-    static int            versionNumber( const QString& filename );
 
     void                  addToMetadata( fitsfile *ffits, int &iStatus );
     void                  addToFieldList( fitsfile *ffits, const int iNumCols, int &iStatus );
@@ -75,6 +77,8 @@ class PLANCKIDEFSource : public KstDataSource {
     bool                  initFolder();
     bool                  initialize();
 
+    friend class ConfigWidgetPlanckIDEF;
+    mutable Config       *_config;
     QDict<field>          _fields;
     QDict<fileList>       _basefiles;
     double                _dTimeZero;
