@@ -59,9 +59,7 @@ KstBindArrow::~KstBindArrow() {
 
 KJS::Object KstBindArrow::construct(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr view = extractViewObject(exec, args[0]);
@@ -70,9 +68,7 @@ KJS::Object KstBindArrow::construct(KJS::ExecState *exec, const KJS::List& args)
     if (w) {
       view = w->view();
     } else {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 0);
     }
   }
 
@@ -186,18 +182,14 @@ KJS::Value KstBindArrow::get(KJS::ExecState *exec, const KJS::Identifier& proper
 KJS::Value KstBindArrow::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindLine::methodCount();
   if (id > start) {
     KstBindArrow *imp = dynamic_cast<KstBindArrow*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*arrowBindings[id - start - 1].method)(exec, args);
@@ -219,15 +211,11 @@ void KstBindArrow::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 
 void KstBindArrow::setFromArrow(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
 
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
@@ -243,9 +231,7 @@ void KstBindArrow::setFromArrow(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindArrow::fromArrow(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
@@ -260,15 +246,11 @@ KJS::Value KstBindArrow::fromArrow(KJS::ExecState *exec) const {
 
 void KstBindArrow::setToArrow(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
 
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
@@ -284,9 +266,7 @@ void KstBindArrow::setToArrow(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindArrow::toArrow(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
@@ -301,15 +281,11 @@ KJS::Value KstBindArrow::toArrow(KJS::ExecState *exec) const {
 
 void KstBindArrow::setFromArrowScaling(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
 
   if (value.type() !=  KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
@@ -325,9 +301,7 @@ void KstBindArrow::setFromArrowScaling(KJS::ExecState *exec, const KJS::Value& v
 
 KJS::Value KstBindArrow::fromArrowScaling(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
@@ -342,15 +316,11 @@ KJS::Value KstBindArrow::fromArrowScaling(KJS::ExecState *exec) const {
 
 void KstBindArrow::setToArrowScaling(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
 
   if (value.type() !=  KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
@@ -366,9 +336,7 @@ void KstBindArrow::setToArrowScaling(KJS::ExecState *exec, const KJS::Value& val
 
 KJS::Value KstBindArrow::toArrowScaling(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstViewArrowPtr d = makeArrow(_d);
