@@ -147,16 +147,12 @@ KJS::Value KstBindAxis::get(KJS::ExecState *exec, const KJS::Identifier& propert
 KJS::Value KstBindAxis::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstBindAxis *imp = dynamic_cast<KstBindAxis*>(self.imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   return (imp->*axisBindings[id - 1].method)(exec, args);
@@ -179,9 +175,7 @@ KJS::Value KstBindAxis::type(KJS::ExecState *exec) const {
 
 KJS::Value KstBindAxis::title(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   return KJS::Object(new KstBindAxisLabel(exec, _d, _xAxis));
@@ -190,9 +184,7 @@ KJS::Value KstBindAxis::title(KJS::ExecState *exec) const {
 
 KJS::Value KstBindAxis::tickLabel(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   return KJS::Object(new KstBindAxisTickLabel(exec, _d, _xAxis));
@@ -201,9 +193,7 @@ KJS::Value KstBindAxis::tickLabel(KJS::ExecState *exec) const {
 
 KJS::Value KstBindAxis::label(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -216,14 +206,10 @@ KJS::Value KstBindAxis::label(KJS::ExecState *exec) const {
 
 void KstBindAxis::setLabel(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -238,9 +224,7 @@ void KstBindAxis::setLabel(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindAxis::transformation(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -253,14 +237,10 @@ KJS::Value KstBindAxis::transformation(KJS::ExecState *exec) const {
 
 void KstBindAxis::setTransformation(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -275,9 +255,7 @@ void KstBindAxis::setTransformation(KJS::ExecState *exec, const KJS::Value& valu
 
 KJS::Value KstBindAxis::log(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -290,14 +268,10 @@ KJS::Value KstBindAxis::log(KJS::ExecState *exec) const {
 
 void KstBindAxis::setLog(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -312,9 +286,7 @@ void KstBindAxis::setLog(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindAxis::majorGridLines(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -327,14 +299,10 @@ KJS::Value KstBindAxis::majorGridLines(KJS::ExecState *exec) const {
 
 void KstBindAxis::setMajorGridLines(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -349,9 +317,7 @@ void KstBindAxis::setMajorGridLines(KJS::ExecState *exec, const KJS::Value& valu
 
 KJS::Value KstBindAxis::minorGridLines(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -364,14 +330,10 @@ KJS::Value KstBindAxis::minorGridLines(KJS::ExecState *exec) const {
 
 void KstBindAxis::setMinorGridLines(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -386,9 +348,7 @@ void KstBindAxis::setMinorGridLines(KJS::ExecState *exec, const KJS::Value& valu
 
 KJS::Value KstBindAxis::reversed(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -401,14 +361,10 @@ KJS::Value KstBindAxis::reversed(KJS::ExecState *exec) const {
 
 void KstBindAxis::setReversed(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -423,9 +379,7 @@ void KstBindAxis::setReversed(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindAxis::offsetMode(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -438,14 +392,10 @@ KJS::Value KstBindAxis::offsetMode(KJS::ExecState *exec) const {
 
 void KstBindAxis::setOffsetMode(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -460,9 +410,7 @@ void KstBindAxis::setOffsetMode(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindAxis::suppressed(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -475,14 +423,10 @@ KJS::Value KstBindAxis::suppressed(KJS::ExecState *exec) const {
 
 void KstBindAxis::setSuppressed(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -497,9 +441,7 @@ void KstBindAxis::setSuppressed(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindAxis::oppositeSuppressed(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -512,14 +454,10 @@ KJS::Value KstBindAxis::oppositeSuppressed(KJS::ExecState *exec) const {
 
 void KstBindAxis::setOppositeSuppressed(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -534,9 +472,7 @@ void KstBindAxis::setOppositeSuppressed(KJS::ExecState *exec, const KJS::Value&
 
 KJS::Value KstBindAxis::innerTicks(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -549,14 +485,10 @@ KJS::Value KstBindAxis::innerTicks(KJS::ExecState *exec) const {
 
 void KstBindAxis::setInnerTicks(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -571,9 +503,7 @@ void KstBindAxis::setInnerTicks(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindAxis::outerTicks(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -586,14 +516,10 @@ KJS::Value KstBindAxis::outerTicks(KJS::ExecState *exec) const {
 
 void KstBindAxis::setOuterTicks(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker wl(_d);
   if (_xAxis) {
@@ -608,9 +534,7 @@ void KstBindAxis::setOuterTicks(KJS::ExecState *exec, const KJS::Value& value) {
 
 KJS::Value KstBindAxis::majorGridColor(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   return KJSEmbed::convertToValue(exec, _d->majorGridColor());
@@ -619,15 +543,11 @@ KJS::Value KstBindAxis::majorGridColor(KJS::ExecState *exec) const {
 
 void KstBindAxis::setMajorGridColor(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   QVariant cv = KJSEmbed::convertToVariant(exec, value);
   if (!cv.canCast(QVariant::Color)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker rl(_d);
   _d->setGridLinesColor(cv.toColor(), _d->minorGridColor(), false, _d->defaultMinorGridColor());
@@ -638,9 +558,7 @@ void KstBindAxis::setMajorGridColor(KJS::ExecState *exec, const KJS::Value& valu
 
 KJS::Value KstBindAxis::minorGridColor(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   return KJSEmbed::convertToValue(exec, _d->minorGridColor());
@@ -649,15 +567,11 @@ KJS::Value KstBindAxis::minorGridColor(KJS::ExecState *exec) const {
 
 void KstBindAxis::setMinorGridColor(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   QVariant cv = KJSEmbed::convertToVariant(exec, value);
   if (!cv.canCast(QVariant::Color)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstWriteLocker rl(_d);
   _d->setGridLinesColor(_d->majorGridColor(), cv.toColor(), _d->defaultMajorGridColor(), false);
@@ -673,9 +587,7 @@ KJS::Value KstBindAxis::interpretation(KJS::ExecState *exec) const {
 
 KJS::Value KstBindAxis::minorTickCount(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
@@ -688,14 +600,10 @@ KJS::Value KstBindAxis::minorTickCount(KJS::ExecState *exec) const {
 
 void KstBindAxis::setMinorTickCount(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   KstWriteLocker rl(_d);
@@ -711,9 +619,7 @@ void KstBindAxis::setMinorTickCount(KJS::ExecState *exec, const KJS::Value& valu
 
 KJS::Value KstBindAxis::majorTickDensity(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(_d);
   int i = 0;
@@ -744,34 +650,28 @@ KJS::Value KstBindAxis::majorTickDensity(KJS::ExecState *exec) const {
 
 void KstBindAxis::setMajorTickDensity(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
   if (value.type() != KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   int i = value.toInt32(exec);
   switch (i) {
     case 0:
-        i = 2;
+      i = 2;
       break;
     case 1:
-        i = 5;
+      i = 5;
       break;
     case 2:
-        i = 10;
+      i = 10;
       break;
     case 3:
-        i = 15;
+      i = 15;
       break;
     default:
-      KJS::Object eobj = KJS::Error::create(exec, KJS::RangeError);
-      exec->setException(eobj);
-      return;
+      return createPropertyRangeError(exec);
   }
 
   KstWriteLocker rl(_d);
@@ -787,10 +687,8 @@ void KstBindAxis::setMajorTickDensity(KJS::ExecState *exec, const KJS::Value& va
 
 KJS::Value KstBindAxis::scaleMode(KJS::ExecState *exec) const {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
-  }
+    return createInternalError(exec);
+}
   KstReadLocker rl(_d);
   KstScaleModeType i;
   if (_xAxis) {
@@ -806,15 +704,11 @@ KJS::Value KstBindAxis::scaleMode(KJS::ExecState *exec) const {
 
 KJS::Value KstBindAxis::scaleAuto(KJS::ExecState *exec, const KJS::List& args) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly zero arguments.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstWriteLocker rl(_d);
@@ -831,15 +725,11 @@ KJS::Value KstBindAxis::scaleAuto(KJS::ExecState *exec, const KJS::List& args) {
 
 KJS::Value KstBindAxis::scaleAutoSpikeInsensitive(KJS::ExecState *exec, const KJS::List& args) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly zero arguments.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstWriteLocker rl(_d);
@@ -856,21 +746,17 @@ KJS::Value KstBindAxis::scaleAutoSpikeInsensitive(KJS::ExecState *exec, const KJ
 
 KJS::Value KstBindAxis::scaleExpression(KJS::ExecState *exec, const KJS::List& args) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 2) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly two arguments.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
-  if (args[0].type() != KJS::StringType || args[1].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+  if (args[0].type() != KJS::StringType) {
+    return createTypeError(exec, 0);
+  } else if (args[1].type() != KJS::StringType) {
+    return createTypeError(exec, 1);
   }
 
   KstWriteLocker rl(_d);
@@ -889,21 +775,17 @@ KJS::Value KstBindAxis::scaleExpression(KJS::ExecState *exec, const KJS::List& a
 
 KJS::Value KstBindAxis::scaleRange(KJS::ExecState *exec, const KJS::List& args) {
   if (!_d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 2) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly two arguments.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
-  if (args[0].type() != KJS::NumberType || args[1].type() != KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+  if (args[0].type() != KJS::NumberType) {
+    return createTypeError(exec, 0);
+  } else if (args[1].type() != KJS::NumberType) {
+    return createTypeError(exec, 1);
   }
 
   KstWriteLocker rl(_d);
