@@ -105,16 +105,12 @@ bool KstBindCollection::hasProperty(KJS::ExecState *exec, const KJS::Identifier&
 KJS::Value KstBindCollection::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstBindCollection *imp = dynamic_cast<KstBindCollection*>(self.imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   return (imp->*collectionBindings[id - 1].method)(exec, args);
@@ -151,33 +147,29 @@ KJS::Value KstBindCollection::getPropertyByIndex(KJS::ExecState *exec, unsigned
 
 KJS::Value KstBindCollection::append(KJS::ExecState *exec, const KJS::List& args) {
   Q_UNUSED(args)
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+
+  return createGeneralError(exec, i18n("Pure virtual function."));
 }
 
 
 KJS::Value KstBindCollection::prepend(KJS::ExecState *exec, const KJS::List& args) {
   Q_UNUSED(args)
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+
+  return createGeneralError(exec, i18n("Pure virtual function."));
 }
 
 
 KJS::Value KstBindCollection::remove(KJS::ExecState *exec, const KJS::List& args) {
   Q_UNUSED(args)
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+
+  return createGeneralError(exec, i18n("Pure virtual function."));
 }
 
 
 KJS::Value KstBindCollection::clear(KJS::ExecState *exec, const KJS::List& args) {
   Q_UNUSED(args)
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+
+  return createGeneralError(exec, i18n("Pure virtual function."));
 }
 
 
@@ -188,30 +180,24 @@ KJS::Value KstBindCollection::readOnly(KJS::ExecState *exec) const {
 
 
 KJS::Value KstBindCollection::length(KJS::ExecState *exec) const {
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+  return createGeneralError(exec, i18n("Pure virtual function."));
 }
 
 
 QStringList KstBindCollection::collection(KJS::ExecState *exec) const {
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
+  createGeneralError(exec, i18n("Pure virtual function."));
   return QStringList();
 }
 
 
 KJS::Value KstBindCollection::extract(KJS::ExecState *exec, const KJS::Identifier& item) const {
   Q_UNUSED(item)
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+
+  return createGeneralError(exec, i18n("Pure virtual function."));
 }
 
 
 KJS::Value KstBindCollection::extract(KJS::ExecState *exec, unsigned item) const {
   Q_UNUSED(item)
-  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+  return createGeneralError(exec, i18n("Pure virtual function."));
 }
