@@ -87,14 +87,10 @@ KJS::Object KstBindCurve::construct(KJS::ExecState *exec, const KJS::List& args)
 
           return KJS::Object(new KstBindCurve(exec, d));
         } else {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "The histogram must have an associated vector.");
-          exec->setException(eobj);
-          return KJS::Object();
+          return createGeneralError(exec, i18n("The histogram must have an associated vector."));
         }
       } else {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-        exec->setException(eobj);
-        return KJS::Object();
+        return createTypeError(exec, 0);
       }
     }
   }
@@ -102,67 +98,51 @@ KJS::Object KstBindCurve::construct(KJS::ExecState *exec, const KJS::List& args)
   if (args.size() > 0) {
     x = extractVector(exec, args[0]);
     if (!x) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 0);
     }
   }
 
   if (args.size() > 1) {
     y = extractVector(exec, args[1]);
     if (!y) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 1);
     }
   }
 
   if (args.size() > 2) {
     ex = extractVector(exec, args[2]);
     if (!ex) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 2);
     }
   }
 
   if (args.size() > 3) {
     ey = extractVector(exec, args[3]);
     if (!ey) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 3);
     }
   }
 
   if (args.size() > 4) {
     exm = extractVector(exec, args[4]);
     if (!exm) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 4);
     }
   }
 
   if (args.size() > 5) {
     eym = extractVector(exec, args[5]);
     if (!eym) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 5);
     }
   }
 
   if (args.size() > 6) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createTypeError(exec, 6);
   }
 
   if (!x || !y) { // force at least X and Y vectors
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   QColor color = KstColorSequence::next();
@@ -220,6 +200,7 @@ static CurveProperties curveProperties[] = {
   { "topLabel", 0L, &KstBindCurve::topLabel },
   { "xLabel", 0L, &KstBindCurve::xLabel },
   { "yLabel", 0L, &KstBindCurve::yLabel },
+  { "legendText", &KstBindCurve::setLegendText, &KstBindCurve::legendText },
   { 0L, 0L, 0L }
 };
 
@@ -290,18 +271,14 @@ KJS::Value KstBindCurve::get(KJS::ExecState *exec, const KJS::Identifier& proper
 KJS::Value KstBindCurve::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindDataObject::methodCount();
   if (id > start) {
     KstBindCurve *imp = dynamic_cast<KstBindCurve*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*curveBindings[id - start - 1].method)(exec, args);
@@ -325,22 +302,16 @@ void KstBindCurve::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 KJS::Value KstBindCurve::point(KJS::ExecState *exec, const KJS::List& args) {
   KstVCurvePtr d = makeCurve(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstReadLocker rl(d);
@@ -353,28 +324,20 @@ KJS::Value KstBindCurve::point(KJS::ExecState *exec, const KJS::List& args) {
 KJS::Value KstBindCurve::xErrorPoint(KJS::ExecState *exec, const KJS::List& args) {
   KstVCurvePtr d = makeCurve(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   if (!d->xErrorVector()) {
-   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No +X error bar is defined.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createGeneralError(exec, i18n("No +X error bar is defined."));
   }
 
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstReadLocker rl(d);
@@ -387,28 +350,20 @@ KJS::Value KstBindCurve::xErrorPoint(KJS::ExecState *exec, const KJS::List& args
 KJS::Value KstBindCurve::yErrorPoint(KJS::ExecState *exec, const KJS::List& args) {
   KstVCurvePtr d = makeCurve(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   if (!d->yErrorVector()) {
-   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No +Y error bar is defined.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createGeneralError(exec, i18n("No +Y error bar is defined."));
   }
 
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstReadLocker rl(d);
@@ -421,28 +376,20 @@ KJS::Value KstBindCurve::yErrorPoint(KJS::ExecState *exec, const KJS::List& args
 KJS::Value KstBindCurve::xMinusErrorPoint(KJS::ExecState *exec, const KJS::List& args) {
   KstVCurvePtr d = makeCurve(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   if (!d->xMinusErrorVector()) {
-   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No -X error bar is defined.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createGeneralError(exec, i18n("No -X error bar is defined."));
   }
 
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstReadLocker rl(d);
@@ -455,28 +402,20 @@ KJS::Value KstBindCurve::xMinusErrorPoint(KJS::ExecState *exec, const KJS::List&
 KJS::Value KstBindCurve::yMinusErrorPoint(KJS::ExecState *exec, const KJS::List& args) {
   KstVCurvePtr d = makeCurve(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   if (!d->yMinusErrorVector()) {
-   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No -Y error bar is defined.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createGeneralError(exec, i18n("No -Y error bar is defined."));
   }
 
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstReadLocker rl(d);
@@ -489,9 +428,7 @@ KJS::Value KstBindCurve::yMinusErrorPoint(KJS::ExecState *exec, const KJS::List&
 void KstBindCurve::setColor(KJS::ExecState *exec, const KJS::Value& value) {
   QVariant cv = KJSEmbed::convertToVariant(exec, value);
   if (!cv.canCast(QVariant::Color)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -577,8 +514,7 @@ void KstBindCurve::setXErrorVector(KJS::ExecState *exec, const KJS::Value& value
       d->setXError(vp);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
-    exec->setException(eobj);
+    return createPropertyTypeError(exec);
   }
 }
 
@@ -611,8 +547,7 @@ void KstBindCurve::setYErrorVector(KJS::ExecState *exec, const KJS::Value& value
       d->setYError(vp);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
-    exec->setException(eobj);
+    return createPropertyTypeError(exec);
   }
 }
 
@@ -645,8 +580,7 @@ void KstBindCurve::setXMinusErrorVector(KJS::ExecState *exec, const KJS::Value&
       d->setXMinusError(vp);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
-    exec->setException(eobj);
+    return createPropertyTypeError(exec);
   }
 }
 
@@ -679,8 +613,7 @@ void KstBindCurve::setYMinusErrorVector(KJS::ExecState *exec, const KJS::Value&
       d->setYMinusError(vp);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
-    exec->setException(eobj);
+    return createPropertyTypeError(exec);
   }
 }
 
@@ -711,9 +644,7 @@ KJS::Value KstBindCurve::samplesPerFrame(KJS::ExecState *exec) const {
 
 void KstBindCurve::setIgnoreAutoScale(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -736,9 +667,7 @@ KJS::Value KstBindCurve::ignoreAutoScale(KJS::ExecState *exec) const {
 
 void KstBindCurve::setHasPoints(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -761,9 +690,7 @@ KJS::Value KstBindCurve::hasPoints(KJS::ExecState *exec) const {
 
 void KstBindCurve::setHasLines(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -786,9 +713,7 @@ KJS::Value KstBindCurve::hasLines(KJS::ExecState *exec) const {
 
 void KstBindCurve::setHasBars(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -812,9 +737,7 @@ KJS::Value KstBindCurve::hasBars(KJS::ExecState *exec) const {
 void KstBindCurve::setLineWidth(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned width = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(width)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   KstVCurvePtr d = makeCurve(_d);
@@ -839,9 +762,7 @@ KJS::Value KstBindCurve::lineWidth(KJS::ExecState *exec) const {
 void KstBindCurve::setPointDensity(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned i = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -865,9 +786,7 @@ KJS::Value KstBindCurve::pointDensity(KJS::ExecState *exec) const {
 void KstBindCurve::setPointStyle(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned i = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -891,9 +810,7 @@ KJS::Value KstBindCurve::pointStyle(KJS::ExecState *exec) const {
 void KstBindCurve::setLineStyle(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned i = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -917,9 +834,7 @@ KJS::Value KstBindCurve::lineStyle(KJS::ExecState *exec) const {
 void KstBindCurve::setBarStyle(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned i = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
@@ -973,5 +888,27 @@ KJS::Value KstBindCurve::yLabel(KJS::ExecState *exec) const {
 }
 
 
+void KstBindCurve::setLegendText(KJS::ExecState *exec, const KJS::Value& value) {
+  if (value.type() != KJS::StringType) {
+    return createPropertyTypeError(exec);
+  }
+  KstVCurvePtr d = makeCurve(_d);
+  if (d) {
+    KstWriteLocker wl(d);
+    d->setLegendText(value.toString(exec).qstring());
+  }
+}
+
+
+KJS::Value KstBindCurve::legendText(KJS::ExecState *exec) const {
+  Q_UNUSED(exec)
+  KstVCurvePtr d = makeCurve(_d);
+  if (d) {
+    KstReadLocker rl(d);
+    return KJS::String(d->legendText());
+  }
+  return KJS::String();
+}
+
 #undef makeCurve
 
