@@ -81,8 +81,8 @@ class KstBindCurve : public KstBindDataObject {
     KJS::Value point(KJS::ExecState *exec, const KJS::List& args);
 
     /* @method xErrorPoint
-       @returns Point
-       @description Retrieve the coordinates for a given point in the X error
+       @returns number
+       @description Retrieve the value for a given point in the X error
                     bars.  Returns an invalid point if that index does not
                     exist.
        @arg number index The index of the point to retrieve the coordinates
@@ -91,8 +91,8 @@ class KstBindCurve : public KstBindDataObject {
     KJS::Value xErrorPoint(KJS::ExecState *exec, const KJS::List& args);
 
     /* @method yErrorPoint
-       @returns Point
-       @description Retrieve the coordinates for a given point in the Y error
+       @returns number
+       @description Retrieve the value for a given point in the Y error
                     bars.  Returns an invalid point if that index does not
                     exist.
        @arg number index The index of the point to retrieve the coordinates
@@ -101,8 +101,8 @@ class KstBindCurve : public KstBindDataObject {
     KJS::Value yErrorPoint(KJS::ExecState *exec, const KJS::List& args);
 
     /* @method xMinusErrorPoint
-       @returns Point
-       @description Retrieve the coordinates for a given point in the X minus
+       @returns number
+       @description Retrieve the value for a given point in the X minus
                     error bars.  Returns an invalid point if that index does
                     not exist.
        @arg number index The index of the point to retrieve the coordinates
@@ -111,8 +111,8 @@ class KstBindCurve : public KstBindDataObject {
     KJS::Value xMinusErrorPoint(KJS::ExecState *exec, const KJS::List& args);
 
     /* @method yMinusErrorPoint
-       @returns Point
-       @description Retrieve the coordinates for a given point in the Y minus
+       @returns number
+       @description Retrieve the value for a given point in the Y minus
                     error bars.  Returns an invalid point if that index does
                     not exist.
        @arg number index The index of the point to retrieve the coordinates
@@ -120,7 +120,6 @@ class KstBindCurve : public KstBindDataObject {
     */
     KJS::Value yMinusErrorPoint(KJS::ExecState *exec, const KJS::List& args);
 
-
     /* @property string color
        @description The color of the curve.  Stored in the form "#RRGGBB" as
                     hex values.  This property can also be set with English
@@ -276,6 +275,12 @@ class KstBindCurve : public KstBindDataObject {
     */
     KJS::Value yLabel(KJS::ExecState *exec) const;
 
+    /* @property string legendText
+       @description The legend text associated with a curve.
+    */
+    void setLegendText(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value legendText(KJS::ExecState *exec) const;
+
   protected:
     KstBindCurve(int id);
     void addBindings(KJS::ExecState *exec, KJS::Object& obj);
