@@ -57,18 +57,14 @@ KJS::Object KstBindDataMatrix::construct(KJS::ExecState *exec, const KJS::List&
   KstDataSourcePtr dp = extractDataSource(exec, args[0], false);
 
   if (!dp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createTypeError(exec, 0);
   }
 
   if (args.size() >= 2) {
     if (args[1].type() == KJS::StringType) {
       field = args[1].toString(exec).qstring();
       if (!dp->matrixList().contains(field)) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "No such matrix is available.");
-        exec->setException(eobj);
-        return KJS::Object();
+        return createTypeError(exec, 1);
       }
     } else if (args[1].type() == KJS::NumberType) {
       unsigned index;
@@ -77,19 +73,13 @@ KJS::Object KstBindDataMatrix::construct(KJS::ExecState *exec, const KJS::List&
         if (index < dp->matrixList().count()) {
           field = dp->matrixList()[index];
         } else {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "No such matrix is available.");
-          exec->setException(eobj);
-          return KJS::Object();
+          return createTypeError(exec, 1);
         }
       } else {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-        exec->setException(eobj);
-        return KJS::Object();
+        return createTypeError(exec, 1);
       }
     } else {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 1);
     }
   }
 
@@ -100,13 +90,14 @@ KJS::Object KstBindDataMatrix::construct(KJS::ExecState *exec, const KJS::List&
 
   // Constructor: DataMatrix(DataSource, field, xStart, yStart, xCount, yCount)
   if (args.size() == 6) {
-    if (args[2].type() != KJS::NumberType ||
-        args[3].type() != KJS::NumberType ||
-        args[4].type() != KJS::NumberType ||
-        args[5].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
+    } else if (args[4].type() != KJS::NumberType) {
+      return createTypeError(exec, 4);
+    } else if (args[5].type() != KJS::NumberType) {
+      return createTypeError(exec, 5);
     }
 
     int xStart = d2i(args[2].toNumber(exec));
@@ -119,14 +110,16 @@ KJS::Object KstBindDataMatrix::construct(KJS::ExecState *exec, const KJS::List&
 
   // Constructor: DataMatrix(DataSource, field, xStart, yStart, xCount, yCount, skip)
   if (args.size() == 7) {
-    if (args[2].type() != KJS::NumberType ||
-        args[3].type() != KJS::NumberType ||
-        args[4].type() != KJS::NumberType ||
-        args[5].type() != KJS::NumberType ||
-        args[6].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
+    } else if (args[4].type() != KJS::NumberType) {
+      return createTypeError(exec, 4);
+    } else if (args[5].type() != KJS::NumberType) {
+      return createTypeError(exec, 5);
+    } else if (args[6].type() != KJS::NumberType) {
+      return createTypeError(exec, 6);
     }
 
     int xStart = d2i(args[2].toNumber(exec));
@@ -141,15 +134,18 @@ KJS::Object KstBindDataMatrix::construct(KJS::ExecState *exec, const KJS::List&
 
   // Constructor: DataMatrix(DataSource, field, xStart, yStart, xCount, yCount, skip, ave)
   if (args.size() == 8) {
-    if (args[2].type() != KJS::NumberType ||
-        args[3].type() != KJS::NumberType ||
-        args[4].type() != KJS::NumberType ||
-        args[5].type() != KJS::NumberType ||
-        args[6].type() != KJS::NumberType ||
-        args[7].type() != KJS::BooleanType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
+    } else if (args[4].type() != KJS::NumberType) {
+      return createTypeError(exec, 4);
+    } else if (args[5].type() != KJS::NumberType) {
+      return createTypeError(exec, 5);
+    } else if (args[6].type() != KJS::NumberType) {
+      return createTypeError(exec, 6);
+    } else if (args[7].type() != KJS::BooleanType) {
+      return createTypeError(exec, 7);
     }
 
     int xStart = d2i(args[2].toNumber(exec));
@@ -163,9 +159,7 @@ KJS::Object KstBindDataMatrix::construct(KJS::ExecState *exec, const KJS::List&
   }
 
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   return KJS::Object(new KstBindDataMatrix(exec, v));
@@ -275,18 +269,14 @@ KJS::Value KstBindDataMatrix::get(KJS::ExecState *exec, const KJS::Identifier& p
 KJS::Value KstBindDataMatrix::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindMatrix::methodCount();
   if (id > start) {
     KstBindDataMatrix *imp = dynamic_cast<KstBindDataMatrix*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*dataMatrixBindings[id - start - 1].method)(exec, args);
@@ -311,9 +301,7 @@ KJS::Value KstBindDataMatrix::reload(KJS::ExecState *exec, const KJS::List& args
   Q_UNUSED(args)
   KstRMatrixPtr v = makeDataMatrix(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstWriteLocker wl(v);
   v->reload();
@@ -324,36 +312,26 @@ KJS::Value KstBindDataMatrix::reload(KJS::ExecState *exec, const KJS::List& args
 KJS::Value KstBindDataMatrix::changeFile(KJS::ExecState *exec, const KJS::List& args) {
   KstRMatrixPtr v = makeDataMatrix(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::ObjectType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstBindDataSource *imp = dynamic_cast<KstBindDataSource*>(args[0].toObject(exec).imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
 #define makeSource(X) dynamic_cast<KstDataSource*>(const_cast<KstObject*>(X.data()))
   KstDataSourcePtr s = makeSource(imp->_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
   v->writeLock();
   s->writeLock();
@@ -369,17 +347,14 @@ KJS::Value KstBindDataMatrix::changeFile(KJS::ExecState *exec, const KJS::List&
 KJS::Value KstBindDataMatrix::change(KJS::ExecState *exec, const KJS::List& args) {
   KstRMatrixPtr v = makeDataMatrix(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() > 3) {
-    if (args[0].type() != KJS::NumberType ||
-        args[1].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+    if (args[0].type() != KJS::NumberType) {
+      return createTypeError(exec, 0);
+    } else if (args[1].type() != KJS::NumberType) {
+      return createTypeError(exec, 1);
     }
 
     KstWriteLocker wl(v);
@@ -392,31 +367,25 @@ KJS::Value KstBindDataMatrix::change(KJS::ExecState *exec, const KJS::List& args
 
     if (args.size() > 4) {
       if (args[4].type() != KJS::NumberType) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-        exec->setException(eobj);
-        return KJS::Undefined();
+        return createTypeError(exec, 4);
       }
 
       skip = d2i(args[4].toNumber(exec));
 
       if (args.size() > 5) {
         if (args[5].type() != KJS::BooleanType) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-          exec->setException(eobj);
-          return KJS::Undefined();
+          return createTypeError(exec, 5);
         }
 
         ave = d2i(args[5].toBoolean(exec));
       }
     }
 
-    v->change(v->dataSource(), v->field(), v->tag(), xStart, yStart, xCount, yCount, skip, skip >= 0, ave);
+    v->change(v->dataSource(), v->field(), v->tag(), xStart, yStart, xCount, yCount, ave, skip >= 0, skip);
     return KJS::Undefined();
   }
 
-  KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+  return createSyntaxError(exec);
 }
 
 
