@@ -46,15 +46,11 @@ KstBindDataSource::~KstBindDataSource() {
 
 KJS::Object KstBindDataSource::construct(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() < 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createTypeError(exec, 0);
   }
 
   QString file = args[0].toString(exec).qstring();
@@ -62,9 +58,7 @@ KJS::Object KstBindDataSource::construct(KJS::ExecState *exec, const KJS::List&
 
   if (args.size() == 2) {
     if (args[1].type() != KJS::StringType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 1);
     }
     type = args[1].toString(exec).qstring();
   }
@@ -80,9 +74,8 @@ KJS::Object KstBindDataSource::construct(KJS::ExecState *exec, const KJS::List&
   }
 
   if (!ds) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Object();
+    QString error = QString("Failed to create data source from '%1'").arg(file);
+    return createGeneralError(exec, error);
   }
 
   if (newSource) {
@@ -178,18 +171,14 @@ KJS::Value KstBindDataSource::get(KJS::ExecState *exec, const KJS::Identifier& p
 KJS::Value KstBindDataSource::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindObject::methodCount();
   if (id > start) {
     KstBindDataSource *imp = dynamic_cast<KstBindDataSource*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*dataSourceBindings[id - start - 1].method)(exec, args);
@@ -215,9 +204,7 @@ KJS::Value KstBindDataSource::fieldList(KJS::ExecState *exec, const KJS::List& a
   KJS::List rc;
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Object(exec->interpreter()->builtinArray().construct(exec, rc));
+    return createInternalError(exec);
   }
   s->readLock();
   QStringList l = s->fieldList();
@@ -235,9 +222,7 @@ KJS::Value KstBindDataSource::matrixList(KJS::ExecState *exec, const KJS::List&
   KJS::List rc;
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Object(exec->interpreter()->builtinArray().construct(exec, rc));
+    return createInternalError(exec);
   }
   s->readLock();
   QStringList l = s->matrixList();
@@ -252,16 +237,12 @@ KJS::Value KstBindDataSource::matrixList(KJS::ExecState *exec, const KJS::List&
 
 KJS::Value KstBindDataSource::reset(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   s->readLock();
@@ -274,22 +255,16 @@ KJS::Value KstBindDataSource::reset(KJS::ExecState *exec, const KJS::List& args)
 
 KJS::Value KstBindDataSource::isValidField(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Boolean(false);
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Boolean(false);
+    return createTypeError(exec, 0);
   }
 
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Boolean(false);
+    return createInternalError(exec);
   }
 
   s->writeLock();
@@ -305,22 +280,16 @@ KJS::Value KstBindDataSource::frameCount(KJS::ExecState *exec, const KJS::List&
 
   if (args.size() == 1) {
     if (args[0].type() != KJS::StringType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Number(0);
+      return createTypeError(exec, 0);
     }
     field = args[0].toString(exec).qstring();
   } else if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires at most one argument.");
-    exec->setException(eobj);
-    return KJS::Number(0);
+    return createSyntaxError(exec);
   }
 
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Number(0);
+    return createInternalError(exec);
   }
 
   s->writeLock();
@@ -333,22 +302,16 @@ KJS::Value KstBindDataSource::frameCount(KJS::ExecState *exec, const KJS::List&
 
 KJS::Value KstBindDataSource::samplesPerFrame(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Number(0);
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Number(0);
+    return createTypeError(exec, 0);
   }
 
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Number(0);
+    return createInternalError(exec);
   }
 
   s->writeLock();
@@ -361,16 +324,12 @@ KJS::Value KstBindDataSource::samplesPerFrame(KJS::ExecState *exec, const KJS::L
 
 KJS::Value KstBindDataSource::configuration(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   QString result;
@@ -383,28 +342,18 @@ KJS::Value KstBindDataSource::configuration(KJS::ExecState *exec, const KJS::Lis
 
 KJS::Value KstBindDataSource::setConfiguration(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 2) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly two arguments.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
-  }
-
-  if (args[1].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
+  } else if (args[1].type() != KJS::StringType) {
+    return createTypeError(exec, 1);
   }
 
   KstDataSourcePtr s = makeSource(_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (s->setConfiguration(args[0].toString(exec).qstring(), args[1].toString(exec).qstring())) {
