@@ -53,14 +53,12 @@ inline int d2i(double x) {
 
 KJS::Object KstBindDataVector::construct(KJS::ExecState *exec, const KJS::List& args) {
   KstRVectorPtr v;
-
   KstDataSourcePtr dp = extractDataSource(exec, args[0]);
+
   // Constructor: DataVector(DataSource, field)
   if (args.size() == 2) {
     if (args[1].type() != KJS::StringType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 1);
     }
 
     QString field = args[1].toString(exec).qstring();
@@ -70,12 +68,12 @@ KJS::Object KstBindDataVector::construct(KJS::ExecState *exec, const KJS::List&
 
   // Constructor: DataVector(DataSource, field, start, n)
   if (args.size() == 4) {
-    if (args[1].type() != KJS::StringType ||
-        args[2].type() != KJS::NumberType ||
-        args[3].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[1].type() != KJS::StringType) {
+      return createTypeError(exec, 1);
+    } else if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
     }
 
     QString field = args[1].toString(exec).qstring();
@@ -87,13 +85,14 @@ KJS::Object KstBindDataVector::construct(KJS::ExecState *exec, const KJS::List&
 
   // Constructor: DataVector(DataSource, field, start, n, skip)
   if (args.size() == 5) {
-    if (args[1].type() != KJS::StringType ||
-        args[2].type() != KJS::NumberType ||
-        args[3].type() != KJS::NumberType ||
-        args[4].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[1].type() != KJS::StringType) {
+      return createTypeError(exec, 1);
+    } else if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
+    } else if (args[4].type() != KJS::NumberType) {
+      return createTypeError(exec, 4);
     }
 
     QString field = args[1].toString(exec).qstring();
@@ -104,17 +103,18 @@ KJS::Object KstBindDataVector::construct(KJS::ExecState *exec, const KJS::List&
     v = new KstRVector(dp, field, KstObjectTag::invalidTag, start, count, skip, true, false);
   }
 
-
   // Constructor: DataVector(DataSource, field, start, n, skip, ave)
   if (args.size() == 6) {
-    if (args[1].type() != KJS::StringType ||
-        args[2].type() != KJS::NumberType ||
-        args[3].type() != KJS::NumberType ||
-        args[4].type() != KJS::NumberType ||
-        args[5].type() != KJS::BooleanType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[1].type() != KJS::StringType) {
+      return createTypeError(exec, 1);
+    } else if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
+    } else if (args[4].type() != KJS::NumberType) {
+      return createTypeError(exec, 4);
+    } else if (args[5].type() != KJS::BooleanType) {
+      return createTypeError(exec, 5);
     }
 
     QString field = args[1].toString(exec).qstring();
@@ -127,9 +127,7 @@ KJS::Object KstBindDataVector::construct(KJS::ExecState *exec, const KJS::List&
   }
 
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   return KJS::Object(new KstBindDataVector(exec, v));
@@ -242,18 +240,14 @@ KJS::Value KstBindDataVector::get(KJS::ExecState *exec, const KJS::Identifier& p
 KJS::Value KstBindDataVector::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindVector::methodCount();
   if (id > start) {
     KstBindDataVector *imp = dynamic_cast<KstBindDataVector*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*dataVectorBindings[id - start - 1].method)(exec, args);
@@ -278,9 +272,7 @@ KJS::Value KstBindDataVector::reload(KJS::ExecState *exec, const KJS::List& args
   Q_UNUSED(args)
   KstRVectorPtr v = makeDataVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstWriteLocker wl(v);
   v->reload();
@@ -291,36 +283,26 @@ KJS::Value KstBindDataVector::reload(KJS::ExecState *exec, const KJS::List& args
 KJS::Value KstBindDataVector::changeFile(KJS::ExecState *exec, const KJS::List& args) {
   KstRVectorPtr v = makeDataVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::ObjectType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstBindDataSource *imp = dynamic_cast<KstBindDataSource*>(args[0].toObject(exec).imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
 #define makeSource(X) dynamic_cast<KstDataSource*>(const_cast<KstObject*>(X.data()))
   KstDataSourcePtr s = makeSource(imp->_d);
   if (!s) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
   v->writeLock();
   s->writeLock();
@@ -336,17 +318,14 @@ KJS::Value KstBindDataVector::changeFile(KJS::ExecState *exec, const KJS::List&
 KJS::Value KstBindDataVector::changeFrames(KJS::ExecState *exec, const KJS::List& args) {
   KstRVectorPtr v = makeDataVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() > 1) {
-    if (args[0].type() != KJS::NumberType ||
-        args[1].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+    if (args[0].type() != KJS::NumberType) {
+      return createTypeError(exec, 0);
+    } else if (args[1].type() != KJS::NumberType) {
+      return createTypeError(exec, 1);
     }
 
     KstWriteLocker wl(v);
@@ -357,31 +336,26 @@ KJS::Value KstBindDataVector::changeFrames(KJS::ExecState *exec, const KJS::List
 
     if (args.size() > 2) {
       if (args[2].type() != KJS::NumberType) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-        exec->setException(eobj);
-        return KJS::Undefined();
+        return createTypeError(exec, 2);
       }
 
       skip = d2i(args[2].toNumber(exec));
 
       if (args.size() > 3) {
         if (args[3].type() != KJS::BooleanType) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-          exec->setException(eobj);
-          return KJS::Undefined();
+          return createTypeError(exec, 3);
         }
 
-        ave = d2i(args[3].toBoolean(exec));
+        ave = args[3].toBoolean(exec);
       }
     }
 
     v->changeFrames(start, count, skip, skip >= 0, ave);
+
     return KJS::Undefined();
   }
 
-  KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-  exec->setException(eobj);
-  return KJS::Undefined();
+  return createSyntaxError(exec);
 }
 
 
