@@ -34,10 +34,6 @@ class KstBindDebugLog : public KstBinding {
     KstBindDebugLog(KJS::ExecState *exec);
     ~KstBindDebugLog();
 
-    /* @constructor
-       @description Create a new DebugLog object which is a reference to the
-                    Kst debug log.
-    */
     KJS::Object construct(KJS::ExecState *exec, const KJS::List& args);
     KJS::Value call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args);
     KJS::Value get(KJS::ExecState *exec, const KJS::Identifier& propertyName) const;
