@@ -63,19 +63,16 @@ KJS::Object KstBindEquation::construct(KJS::ExecState *exec, const KJS::List& ar
 
   // KstEquation(equation, xVector[, interp = true])
   if (args.size() == 2 || args.size() == 3) {
-    if (args[0].type() != KJS::StringType ||
-        (args.size() == 3 && args[2].type() != KJS::BooleanType)) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[0].type() != KJS::StringType) {
+      return createTypeError(exec, 0);
+    } else if (args.size() == 3 && args[2].type() != KJS::BooleanType) {
+      return createTypeError(exec, 2);
     }
 
     KstVectorPtr vp = extractVector(exec, args[1]);
 
     if (!vp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 1);
     }
 
     bool interp = true;
@@ -90,29 +87,27 @@ KJS::Object KstBindEquation::construct(KJS::ExecState *exec, const KJS::List& ar
 
   // KstEquation(equation, x0, x1, nx)
   if (args.size() == 4) {
-    if (args[0].type() != KJS::StringType ||
-        args[1].type() != KJS::NumberType ||
-        args[2].type() != KJS::NumberType ||
-        args[3].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[0].type() != KJS::StringType) {
+      return createTypeError(exec, 0);
+    } else if (args[1].type() != KJS::NumberType) {
+      return createTypeError(exec, 1);
+    } else if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
     }
 
     unsigned npts;
+
     if (!args[3].toUInt32(npts)) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 3);
     }
 
     d = new KstEquation(QString::null, args[0].toString(exec).qstring(), args[1].toNumber(exec), args[2].toNumber(exec), npts);
   }
 
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   KST::dataObjectList.lock().writeLock();
@@ -208,7 +203,7 @@ KJS::Value KstBindEquation::get(KJS::ExecState *exec, const KJS::Identifier& pro
       return (this->*equationProperties[i].get)(exec);
     }
   }
-  
+
   return KstBindDataObject::get(exec, propertyName);
 }
 
@@ -216,18 +211,14 @@ KJS::Value KstBindEquation::get(KJS::ExecState *exec, const KJS::Identifier& pro
 KJS::Value KstBindEquation::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindDataObject::methodCount();
   if (id > start) {
     KstBindEquation *imp = dynamic_cast<KstBindEquation*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*equationBindings[id - start - 1].method)(exec, args);
@@ -250,9 +241,7 @@ void KstBindEquation::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 
 void KstBindEquation::setEquation(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstEquationPtr d = makeEquation(_d);
   KstWriteLocker wl(d);
