@@ -59,9 +59,7 @@ KstBindHistogram::~KstBindHistogram() {
 
 KJS::Object KstBindHistogram::construct(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() < 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   double xmin = -10.0;
@@ -69,41 +67,33 @@ KJS::Object KstBindHistogram::construct(KJS::ExecState *exec, const KJS::List& a
   unsigned bins = 60;
 
   KstVectorPtr v = extractVector(exec, args[0]);
-
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createTypeError(exec, 0);
   }
 
   if (args.size() == 2) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   if (args.size() > 2) {
-    if (args[1].type() != KJS::NumberType || args[2].type() != KJS::NumberType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+    if (args[1].type() != KJS::NumberType) {
+      return createTypeError(exec, 0);
+    } else if (args[2].type() != KJS::NumberType) {
+      return createTypeError(exec, 1);
     }
+
     xmin = args[1].toNumber(exec);
     xmax = args[2].toNumber(exec);
   }
 
   if (args.size() > 3) {
     if (args[3].type() != KJS::NumberType || !args[3].toUInt32(bins)) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 3);
     }
   }
 
   if (args.size() > 4) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   KstHistogramPtr d = new KstHistogram(QString::null, v, xmin, xmax, bins, KST_HS_NUMBER);
@@ -214,18 +204,14 @@ KJS::Value KstBindHistogram::get(KJS::ExecState *exec, const KJS::Identifier& pr
 KJS::Value KstBindHistogram::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindDataObject::methodCount();
   if (id > start) {
     KstBindHistogram *imp = dynamic_cast<KstBindHistogram*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*histogramBindings[id - start - 1].method)(exec, args);
@@ -248,9 +234,7 @@ void KstBindHistogram::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 
 void KstBindHistogram::setRealTimeAutoBin(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstHistogramPtr d = makeHistogram(_d);
   if (d) {
@@ -274,9 +258,7 @@ KJS::Value KstBindHistogram::realTimeAutoBin(KJS::ExecState *exec) const {
 
 void KstBindHistogram::setNormalization(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstHistogramPtr d = makeHistogram(_d);
   if (d) {
@@ -299,9 +281,7 @@ void KstBindHistogram::setNormalization(KJS::ExecState *exec, const KJS::Value&
         d->setDirty();
         break;
       default:
-        KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Value is out of range.");
-        exec->setException(eobj);
-        return;
+        return createPropertyRangeError(exec);
     }
   }
 }
@@ -330,10 +310,9 @@ KJS::Value KstBindHistogram::normalization(KJS::ExecState *exec) const {
 
 void KstBindHistogram::setBins(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned i = 0;
+
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstHistogramPtr d = makeHistogram(_d);
   if (d) {
@@ -385,15 +364,11 @@ KJS::Value KstBindHistogram::yVector(KJS::ExecState *exec) const {
 KJS::Value KstBindHistogram::setVector(KJS::ExecState *exec, const KJS::List& args) {
   KstHistogramPtr d = makeHistogram(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstVectorPtr v = extractVector(exec, args[0]);
@@ -410,21 +385,17 @@ KJS::Value KstBindHistogram::setVector(KJS::ExecState *exec, const KJS::List& ar
 KJS::Value KstBindHistogram::setRange(KJS::ExecState *exec, const KJS::List& args) {
   KstHistogramPtr d = makeHistogram(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 2) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly two arguments.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
-  if (args[0].type() != KJS::NumberType || args[1].type() != KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+  if (args[0].type() != KJS::NumberType) {
+    return createTypeError(exec, 0);
+  } else if (args[1].type() != KJS::NumberType) {
+    return createTypeError(exec, 1);
   }
 
   double x0 = args[0].toNumber(exec);
