@@ -82,28 +82,6 @@ class KstBindLabel : public KstBindBorderedViewObject {
     void setFontSize(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value fontSize(KJS::ExecState *exec) const;
 
-    /* @property number justification
-       @description The justification for the label.  This is a bit field with
-                    two segments, one for horizontal and one for vertical
-                    justification.  The values are as follows:
-                    <ul>
-                    <li>0 - Justify None</li>
-                    <li>1 - Justify Left / Top</li>
-                    <li>2 - Justify Right / Bottom</li>
-                    <li>3 - Justify Center</li>
-                    </ul>
-                    <p>Set the low order 8 bits to one of these values to
-                    control horizontal justification.  Set the next 8 bits
-                    to one of these to control vertical justification.
-                    Example:</p>
-                    <code><pre>
-                    // Set justification to Right-Center
-                    label.justification = 2 | (3 << 8);
-                    </pre></code>
-    */
-    void setJustification(KJS::ExecState *exec, const KJS::Value& value);
-    KJS::Value justification(KJS::ExecState *exec) const;
-
     /* @property number rotation
        @description Contains the rotation angle of the label.  Rotation is
                     clockwise from <i>normal</i> and is stored in degrees.
