@@ -60,9 +60,7 @@ KstBindLine::~KstBindLine() {
 
 KJS::Object KstBindLine::construct(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr view = extractViewObject(exec, args[0]);
@@ -71,9 +69,7 @@ KJS::Object KstBindLine::construct(KJS::ExecState *exec, const KJS::List& args)
     if (w) {
       view = w->view();
     } else {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 0);
     }
   }
 
@@ -188,18 +184,14 @@ KJS::Value KstBindLine::get(KJS::ExecState *exec, const KJS::Identifier& propert
 KJS::Value KstBindLine::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindViewObject::methodCount();
   if (id > start) {
     KstBindLine *imp = dynamic_cast<KstBindLine*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*lineBindings[id - start - 1].method)(exec, args);
@@ -223,9 +215,7 @@ void KstBindLine::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 void KstBindLine::setWidth(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned w = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(w)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewLinePtr d = makeLine(_d);
   if (d) {
@@ -250,9 +240,7 @@ KJS::Value KstBindLine::width(KJS::ExecState *exec) const {
 void KstBindLine::setFrom(KJS::ExecState *exec, const KJS::Value& value) {
   KstBindPoint *imp = 0L;
   if (value.type() != KJS::ObjectType || !(imp = dynamic_cast<KstBindPoint*>(value.toObject(exec).imp()))) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewLinePtr d = makeLine(_d);
   if (d) {
@@ -276,9 +264,7 @@ KJS::Value KstBindLine::from(KJS::ExecState *exec) const {
 void KstBindLine::setTo(KJS::ExecState *exec, const KJS::Value& value) {
   KstBindPoint *imp = 0L;
   if (value.type() != KJS::ObjectType || !(imp = dynamic_cast<KstBindPoint*>(value.toObject(exec).imp()))) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewLinePtr d = makeLine(_d);
   if (d) {
@@ -302,9 +288,7 @@ KJS::Value KstBindLine::to(KJS::ExecState *exec) const {
 void KstBindLine::setCapStyle(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned w = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(w)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewLinePtr d = makeLine(_d);
   if (d) {
@@ -320,9 +304,7 @@ void KstBindLine::setCapStyle(KJS::ExecState *exec, const KJS::Value& value) {
         d->setCapStyle(Qt::RoundCap);
         break;
       default:
-        KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Value is out of range.");
-        exec->setException(eobj);
-        return;
+        return createPropertyRangeError(exec);
     }
     KstApp::inst()->paintAll(KstPainter::P_PAINT);
   }
@@ -352,9 +334,7 @@ KJS::Value KstBindLine::capStyle(KJS::ExecState *exec) const {
 void KstBindLine::setLineStyle(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned w = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(w)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewLinePtr d = makeLine(_d);
   if (d) {
@@ -376,9 +356,7 @@ void KstBindLine::setLineStyle(KJS::ExecState *exec, const KJS::Value& value) {
         d->setPenStyle(Qt::DashDotDotLine);
         break;
       default:
-        KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Value is out of range.");
-        exec->setException(eobj);
-        return;
+        return createPropertyRangeError(exec);
     }
     KstApp::inst()->paintAll(KstPainter::P_PAINT);
   }
