@@ -37,7 +37,7 @@
 class KstBindPlugin : public KstBindDataObject {
   public:
     /* @constructor
-       @description Main constructor for the Plugini class.  New plugins are
+       @description Main constructor for the Plugin class.  New plugins are
                     typically invalid until various properties have been set.
        @optarg PluginModule module The plugin module to use for this plugin.
     */
