@@ -121,16 +121,12 @@ KJS::Value KstBindPluginIO::get(KJS::ExecState *exec, const KJS::Identifier& pro
 KJS::Value KstBindPluginIO::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstBindPluginIO *imp = dynamic_cast<KstBindPluginIO*>(self.imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   return (imp->*pluginIOBindings[id - 1].method)(exec, args);
