@@ -117,7 +117,7 @@ KJS::Value KstBindPluginManager::get(KJS::ExecState *exec, const KJS::Identifier
       return (this->*pluginManagerProperties[i].get)(exec);
     }
   }
-  
+
   return KstBinding::get(exec, propertyName);
 }
 
@@ -125,16 +125,12 @@ KJS::Value KstBindPluginManager::get(KJS::ExecState *exec, const KJS::Identifier
 KJS::Value KstBindPluginManager::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstBindPluginManager *imp = dynamic_cast<KstBindPluginManager*>(self.imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   return (imp->*pluginManagerBindings[id - 1].method)(exec, args);
