@@ -137,18 +137,12 @@ KJS::Value KstBindPluginModule::call(KJS::ExecState *exec, KJS::Object& self, co
   int id = this->id();
 
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstBindPluginModule *imp = dynamic_cast<KstBindPluginModule*>(self.imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   return (imp->*pluginModuleBindings[id - 1].method)(exec, args);
