@@ -61,6 +61,18 @@ class KstBindPowerSpectrum : public KstBindDataObject {
     void setLength(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value length(KJS::ExecState *exec) const;
 
+    /* @property number output
+      @description the normalization for the transform:
+                    <ul>
+                    <li>0 - amplitude spectral density</li>
+                    <li>1 - power spectral density</li>
+                    <li>2 - amplitude spectrum</li>
+                    <li>3 - power spectrum</li>
+                    </ul>
+    */
+    void setOutput(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value output(KJS::ExecState *exec) const;
+
     /* @property boolean removeMean
        @description True if the mean should be removed before performing the
                     transform.
@@ -80,6 +92,24 @@ class KstBindPowerSpectrum : public KstBindDataObject {
     void setApodize(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value apodize(KJS::ExecState *exec) const;
 
+    /* @property number apodizeFn
+       @description The apodization function to be used in the case that apodize is true:
+                    <ul>
+                    <li>0 - default</li>
+                    <li>1 - bartlett</li>
+                    <li>2 - blackman</li>
+                    <li>3 - connes</li>
+                    <li>4 - cosine</li>
+                    <li>5 - gaussian</li>
+                    <li>6 - hamming</li>
+                    <li>7 - hann</li>
+                    <li>8 - welch</li>
+                    <li>9 - uniform</li>
+                    </ul>
+    */
+    void setApodizeFn(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value apodizeFn(KJS::ExecState *exec) const;
+
     /* @property number frequency
        @description Contains the sampling rate of the power spectrum.
     */
@@ -110,6 +140,12 @@ class KstBindPowerSpectrum : public KstBindDataObject {
     void setRUnits(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value rUnits(KJS::ExecState *exec) const;
 
+    /* @property boolean interpolateHoles
+       @description True if the transform should automatically interpolate over missing data values.
+    */
+    void setInterpolateHoles(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value interpolateHoles(KJS::ExecState *exec) const;
+
   protected:
     KstBindPowerSpectrum(int id);
     void addBindings(KJS::ExecState *exec, KJS::Object& obj);
