@@ -82,19 +82,13 @@ KJS::Object KstBindVector::construct(KJS::ExecState *exec, const KJS::List& args
       if (obj.className().qstring() == "Array") {
         return KJS::Object(new KstBindVector(exec, obj));
       } else {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-        exec->setException(eobj);
-        return KJS::Object();
+        return createTypeError(exec, 0);
       }
     } else {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 0);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 }
 
@@ -171,18 +165,14 @@ bool KstBindVector::hasProperty(KJS::ExecState *exec, const KJS::Identifier& pro
 KJS::Value KstBindVector::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindObject::methodCount();
   if (id > start) {
     KstBindVector *imp = dynamic_cast<KstBindVector*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*vectorBindings[id - start - 1].method)(exec, args);
@@ -260,15 +250,11 @@ void KstBindVector::putPropertyByIndex(KJS::ExecState *exec, unsigned propertyNa
   Q_UNUSED(attr)
   KstVectorPtr v = makeVector(_d);
   if (!v || !v->editable()) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return;
+    return createPropertyInternalError(exec);
   }
 
   if (value.type() != KJS::NumberType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
 
   v->writeLock();
@@ -276,8 +262,7 @@ void KstBindVector::putPropertyByIndex(KJS::ExecState *exec, unsigned propertyNa
     v->value()[propertyName] = value.toNumber(exec);
     v->setDirty();
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::RangeError);
-    exec->setException(eobj);
+    return createPropertyRangeError(exec);
   }
 
   v->unlock();
@@ -303,24 +288,18 @@ KJS::Value KstBindVector::length(KJS::ExecState *exec) const {
 
 KJS::Value KstBindVector::resize(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstVectorPtr v = makeVector(_d);
   if (!v || !v->editable()) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   unsigned sz = 0;
 
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(sz)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   v->writeLock();
@@ -335,9 +314,7 @@ KJS::Value KstBindVector::resize(KJS::ExecState *exec, const KJS::List& args) {
 KJS::Value KstBindVector::min(KJS::ExecState *exec) const {
   KstVectorPtr v = makeVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   if (v->dirty()) {
     v->update();
@@ -350,9 +327,7 @@ KJS::Value KstBindVector::min(KJS::ExecState *exec) const {
 KJS::Value KstBindVector::max(KJS::ExecState *exec) const {
   KstVectorPtr v = makeVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   if (v->dirty()) {
     v->update();
@@ -365,9 +340,7 @@ KJS::Value KstBindVector::max(KJS::ExecState *exec) const {
 KJS::Value KstBindVector::mean(KJS::ExecState *exec) const {
   KstVectorPtr v = makeVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   if (v->dirty()) {
     v->update();
@@ -396,29 +369,25 @@ KJS::Value KstBindVector::numShifted(KJS::ExecState *exec) const {
 KJS::Value KstBindVector::interpolate(KJS::ExecState *exec, const KJS::List& args) {
   double rc = KST::NOPOINT;
   if (args.size() != 2) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly two arguments.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   unsigned i = 0;
   unsigned ns_i = 0;
 
-  if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i) ||
-      args[1].type() != KJS::NumberType || !args[1].toUInt32(ns_i)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+  if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
+    return createTypeError(exec, 0);
+  } else if (args[1].type() != KJS::NumberType || !args[1].toUInt32(ns_i)) {
+    return createTypeError(exec, 1);
   }
 
   // no need to check ranges - KstVector does it for us
 
   KstVectorPtr v = makeVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
+
   v->writeLock();
   rc = v->interpolate(i, ns_i);
   v->unlock();
@@ -431,9 +400,7 @@ KJS::Value KstBindVector::zero(KJS::ExecState *exec, const KJS::List& args) {
   Q_UNUSED(args)
   KstVectorPtr v = makeVector(_d);
   if (!v || !v->editable()) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstWriteLocker wl(v);
   v->zero();
@@ -445,9 +412,7 @@ KJS::Value KstBindVector::update(KJS::ExecState *exec, const KJS::List& args) {
   Q_UNUSED(args)
   KstVectorPtr v = makeVector(_d);
   if (!v || !v->editable()) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstWriteLocker wl(v);
   v->update();
@@ -460,9 +425,7 @@ KJS::Value KstBindVector::editable(KJS::ExecState *exec) const {
   Q_UNUSED(exec)
   KstVectorPtr v = makeVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(v);
   return KJS::Boolean(v->editable());
@@ -473,9 +436,7 @@ KJS::Value KstBindVector::numNaN(KJS::ExecState *exec) const {
   Q_UNUSED(exec)
   KstVectorPtr v = makeVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(v);
   return KJS::Number(v->numNaN());
@@ -485,9 +446,7 @@ KJS::Value KstBindVector::numNaN(KJS::ExecState *exec) const {
 KJS::Value KstBindVector::array(KJS::ExecState *exec) const {
   KstVectorPtr v = makeVector(_d);
   if (!v) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
   KstReadLocker rl(v);
   int index;
