@@ -91,6 +91,7 @@ static ViewObjectProperties viewObjectProperties[] = {
   { "color", &KstBindViewObject::setColor, &KstBindViewObject::color },
   { "backgroundColor", &KstBindViewObject::setBackgroundColor, &KstBindViewObject::backgroundColor },
   { "children", 0L, &KstBindViewObject::children },
+  { "maximized", &KstBindViewObject::setMaximized, &KstBindViewObject::maximized },
   { "minimumSize", 0L, &KstBindViewObject::minimumSize },
   { "type", 0L, &KstBindViewObject::type },
   { 0L, 0L, 0L }
@@ -165,7 +166,7 @@ KJS::Value KstBindViewObject::get(KJS::ExecState *exec, const KJS::Identifier& p
       return (this->*viewObjectProperties[i].get)(exec);
     }
   }
-  
+
   return KstBindObject::get(exec, propertyName);
 }
 
@@ -173,18 +174,14 @@ KJS::Value KstBindViewObject::get(KJS::ExecState *exec, const KJS::Identifier& p
 KJS::Value KstBindViewObject::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindObject::methodCount();
   if (id > start) {
     KstBindViewObject *imp = dynamic_cast<KstBindViewObject*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*viewObjectBindings[id - start - 1].method)(exec, args);
@@ -208,9 +205,7 @@ void KstBindViewObject::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 void KstBindViewObject::setColor(KJS::ExecState *exec, const KJS::Value& value) {
   QVariant cv = KJSEmbed::convertToVariant(exec, value);
   if (!cv.canCast(QVariant::Color)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
@@ -234,9 +229,7 @@ KJS::Value KstBindViewObject::color(KJS::ExecState *exec) const {
 void KstBindViewObject::setBackgroundColor(KJS::ExecState *exec, const KJS::Value& value) {
   QVariant cv = KJSEmbed::convertToVariant(exec, value);
   if (!cv.canCast(QVariant::Color)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
@@ -259,13 +252,19 @@ KJS::Value KstBindViewObject::backgroundColor(KJS::ExecState *exec) const {
 
 void KstBindViewObject::setMaximized(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
     KstWriteLocker wl(d);
+
+    bool maximized = value.toBoolean(exec);
+    if (maximized) {
+      KstViewObjectPtr tlv = d->topLevelParent();
+      if (tlv) {
+        tlv->recursively(&KstViewObject::setMaximized, false);
+      }
+    }
     d->setMaximized(value.toBoolean(exec));
     KstApp::inst()->paintAll(KstPainter::P_PAINT);
   }
@@ -286,9 +285,7 @@ KJS::Value KstBindViewObject::maximized(KJS::ExecState *exec) const {
 void KstBindViewObject::setSize(KJS::ExecState *exec, const KJS::Value& value) {
   KstBindSize *imp = 0L;
   if (value.type() != KJS::ObjectType || !(imp = dynamic_cast<KstBindSize*>(value.toObject(exec).imp()))) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
@@ -311,9 +308,7 @@ KJS::Value KstBindViewObject::size(KJS::ExecState *exec) const {
 
 void KstBindViewObject::setTransparent(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
@@ -337,9 +332,7 @@ KJS::Value KstBindViewObject::transparent(KJS::ExecState *exec) const {
 
 void KstBindViewObject::setOnGrid(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
@@ -364,9 +357,7 @@ KJS::Value KstBindViewObject::onGrid(KJS::ExecState *exec) const {
 void KstBindViewObject::setColumns(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned cols = 1;
   if (value.type() != KJS::NumberType || !value.toUInt32(cols)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
@@ -393,9 +384,7 @@ KJS::Value KstBindViewObject::columns(KJS::ExecState *exec) const {
 void KstBindViewObject::setPosition(KJS::ExecState *exec, const KJS::Value& value) {
   KstBindPoint *imp = 0L;
   if (value.type() != KJS::ObjectType || !(imp = dynamic_cast<KstBindPoint*>(value.toObject(exec).imp()))) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
@@ -431,23 +420,18 @@ KJS::Value KstBindViewObject::resize(KJS::ExecState *exec, const KJS::List& args
   if (args.size() == 1) {
     KstBindSize *imp = 0L;
     if (args[0].type() != KJS::ObjectType || !(imp = dynamic_cast<KstBindSize*>(args[0].toObject(exec).imp()))) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createTypeError(exec, 0);
     }
     x = unsigned(imp->_sz.width());
     y = unsigned(imp->_sz.height());
   } else if (args.size() == 2) {
-    if (args[0].type() != KJS::NumberType || !args[0].toUInt32(x) ||
-      args[1].type() != KJS::NumberType || !args[1].toUInt32(y)) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+    if (args[0].type() != KJS::NumberType || !args[0].toUInt32(x)) {
+      return createTypeError(exec, 0);
+    } else if (args[1].type() != KJS::NumberType || !args[1].toUInt32(y)) {
+      return createTypeError(exec, 1);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr d = makeViewObject(_d);
@@ -473,23 +457,18 @@ KJS::Value KstBindViewObject::move(KJS::ExecState *exec, const KJS::List& args)
   if (args.size() == 1) {
     KstBindPoint *imp = 0L;
     if (args[0].type() != KJS::ObjectType || !(imp = dynamic_cast<KstBindPoint*>(args[0].toObject(exec).imp()))) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createTypeError(exec, 0);
     }
     x = unsigned(imp->_x);
     y = unsigned(imp->_y);
   } else if (args.size() == 2) {
-    if (args[0].type() != KJS::NumberType || !args[0].toUInt32(x) ||
-      args[1].type() != KJS::NumberType || !args[1].toUInt32(y)) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+    if (args[0].type() != KJS::NumberType || !args[0].toUInt32(x)) {
+      return createTypeError(exec, 0);
+    } else if (args[1].type() != KJS::NumberType || !args[1].toUInt32(y)) {
+      return createTypeError(exec, 1);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr d = makeViewObject(_d);
@@ -512,15 +491,11 @@ KJS::Value KstBindViewObject::move(KJS::ExecState *exec, const KJS::List& args)
 
 KJS::Value KstBindViewObject::convertTo(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Null();
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Null();
+    return createTypeError(exec, 0);
   }
 
   QString type = args[0].toString(exec).qstring();
@@ -541,9 +516,7 @@ KJS::Value KstBindViewObject::convertTo(KJS::ExecState *exec, const KJS::List& a
 
 KJS::Value KstBindViewObject::raiseToTop(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
-    exec->setException(eobj);
-    return KJS::Null();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr d = makeViewObject(_d);
@@ -566,9 +539,7 @@ KJS::Value KstBindViewObject::raiseToTop(KJS::ExecState *exec, const KJS::List&
 
 KJS::Value KstBindViewObject::lowerToBottom(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
-    exec->setException(eobj);
-    return KJS::Null();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr d = makeViewObject(_d);
@@ -591,9 +562,7 @@ KJS::Value KstBindViewObject::lowerToBottom(KJS::ExecState *exec, const KJS::Lis
 
 KJS::Value KstBindViewObject::raise(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
-    exec->setException(eobj);
-    return KJS::Null();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr d = makeViewObject(_d);
@@ -616,9 +585,7 @@ KJS::Value KstBindViewObject::raise(KJS::ExecState *exec, const KJS::List& args)
 
 KJS::Value KstBindViewObject::lower(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
-    exec->setException(eobj);
-    return KJS::Null();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr d = makeViewObject(_d);
@@ -641,9 +608,7 @@ KJS::Value KstBindViewObject::lower(KJS::ExecState *exec, const KJS::List& args)
 
 KJS::Value KstBindViewObject::remove(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
-    exec->setException(eobj);
-    return KJS::Null();
+    return createSyntaxError(exec);
   }
 
   {
@@ -651,9 +616,7 @@ KJS::Value KstBindViewObject::remove(KJS::ExecState *exec, const KJS::List& args
     KstTopLevelViewPtr tlvTest =  kst_cast<KstTopLevelView>(_d);
 
     if (tlvTest) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "Unable to delete the view.");
-      exec->setException(eobj);
-      return KJS::Null();
+      return createGeneralError(exec, i18n("Unable to delete the view."));
     }
 
     KstViewObjectPtr vo;
@@ -681,16 +644,12 @@ KJS::Value KstBindViewObject::remove(KJS::ExecState *exec, const KJS::List& args
 
 KJS::Value KstBindViewObject::findChild(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstBindPoint *imp = 0L;
   if (args[0].type() != KJS::ObjectType || !(imp = dynamic_cast<KstBindPoint*>(args[0].toObject(exec).imp()))) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createTypeError(exec, 0);
   }
 
   KstViewObjectPtr d = makeViewObject(_d);
