@@ -266,6 +266,39 @@ void KstJS::resetInterpreter() {
 }
 
 
+bool KstJS::writeHistory(const QString &filename) {
+  bool retVal = false;
+
+  if (_iface) {
+    retVal = _iface->writeHistory(filename);
+  }
+
+  return retVal;
+}
+
+
+bool KstJS::clearHistory() {
+  bool retVal = false;
+
+  if (_iface) {
+    _iface->clearHistory();
+    retVal = true;
+  }
+
+  return retVal;
+}
+
+
+bool KstJS::addToOutput(const QString &output) {
+  bool retVal = false;
+
+  if (_iface) {
+    retVal = _iface->addToOutput(output);
+  }
+
+  return retVal;
+}
+
 static char shellStr[30];
 
 void KstJS::showConsole() {
@@ -301,6 +334,7 @@ void KstJS::showConsole() {
   }
 
   _konsolePart->widget()->show();
+  _showAction->setChecked(true);
 #endif
 }
 
