@@ -20,6 +20,7 @@
 
 #include <qguardedptr.h>
 #include <qsplitter.h>
+#include <qstring.h>
 
 #include <kstextension.h>
 #include <kxmlguiclient.h>
@@ -47,6 +48,9 @@ class KstJS : public KstExtension, public KXMLGUIClient {
 
     KJSEmbed::KJSEmbedPart *part() const { return _jsPart; }
     void addScript(QString script);
+    bool writeHistory(const QString& filename);
+    bool clearHistory();
+    bool addToOutput(const QString& output);
 
   public slots:
     void doShow(bool);
