@@ -30,9 +30,13 @@ class JSIfaceImpl : public JSIface {
 
     QString evaluate(const QString& script);
     QString evaluateFile(const QString& filename);
+    bool writeHistory(const QString& filename);
+    void clearHistory();
+    bool addToOutput(const QString& output);
 
   protected:
     KJSEmbed::KJSEmbedPart *_jsPart;
+    QString _output;
 };
 
 #endif
