@@ -113,9 +113,9 @@ int run(DCOPRef& ref) {
 
     if (clean == "help") {
       printf("%s", _T("Help:\n"));
-      printf("%s", _T("session\t\tDisplay the name of the session in use\n"));
-      printf("%s", _T("help\t\tDisplay help\n"));
-      printf("%s", _T("exit\t\tExit the command-line interpreter\n"));
+      printf("%s", _T("session\t\t\t\tDisplay the name of the session in use\n"));
+      printf("%s", _T("help\t\t\t\tDisplay help\n"));
+      printf("%s", _T("exit\t\t\t\tExit the command-line interpreter\n"));
       continue;
     }
 
