@@ -782,8 +782,12 @@ int main(int argc, char *argv[]) {
           args->isSet("a"),                 // add averaging
           !print_and_exit);                 // delayed
     } else {
-      //kst->openDocumentFile();
-      showQuickStart = true;
+      //
+      // don't display the Quick Start dialog if we are passing extension commands...
+      //
+      if (!args->getOption("E")) {
+        showQuickStart = true;
+      }
     }
 
     if (args->isSet("nq")) {
