@@ -321,6 +321,9 @@ QString KstTimezone::name() const
     return m_name;
 }
 
+//
+// NOTE: this is the offset needed to get from local time to UTC
+//
 int KstTimezone::offset(Qt::TimeSpec basisSpec) const
 {
     char *originalZone = ::getenv("TZ");
@@ -334,6 +337,17 @@ int KstTimezone::offset(Qt::TimeSpec basisSpec) const
     QDateTime remoteTime = QDateTime::currentDateTime(Qt::LocalTime);
     int offset = remoteTime.secsTo(basisTime);
 
+    // Round things off nicely if necessary
+    int error = offset % 60;
+    if (error == 59) 
+    {
+      offset++;
+    }
+    else if (error == 1) 
+    {
+      offset--;
+    }
+
     // Now restore things
     if (!originalZone)
     {
@@ -344,6 +358,7 @@ int KstTimezone::offset(Qt::TimeSpec basisSpec) const
         ::putenv(strdup(QString("TZ=").append(originalZone).utf8()));
     }
     tzset();
+
     return offset;
 }
 
