@@ -46,10 +46,9 @@ static int anonymousVectorCounter = 1;
 /** Create a vector */
 KstVector::KstVector(KstObjectTag in_tag, int size, KstObject *provider, bool isScalarList)
 : KstPrimitive(provider), _nsum(0), _scalars(isScalarList ? 0 : 11) {
-  //kstdDebug() << "+++ CREATING VECTOR: " << (void*) this << endl;
   _editable = false;
-  NumShifted = 0;
-  NumNew = 0;
+  _numShifted = 0;
+  _numNew = 0;
   _saveData = false;
   _isScalarList = isScalarList;
 
@@ -70,7 +69,7 @@ KstVector::KstVector(KstObjectTag in_tag, int size, KstObject *provider, bool is
   }
 
   _v = static_cast<double*>(KST::malloc(size * sizeof(double)));
-  if (!_v) { // Malloc failed
+  if (!_v) {
     _v = static_cast<double*>(KST::malloc(sizeof(double)));
     _size = 1;
   } else {
@@ -96,8 +95,8 @@ KstVector::KstVector(const QDomElement& e)
   KstObjectTag in_tag = KstObjectTag::invalidTag;
 
   _editable = false;
-  NumShifted = 0;
-  NumNew = 0;
+  _numShifted = 0;
+  _numNew = 0;
   _isScalarList = false;
   _saveable = false;
   _saveData = false;
@@ -150,7 +149,6 @@ KstVector::KstVector(const QDomElement& e)
 
 
 KstVector::~KstVector() {
-  //kstdDebug() << "+++ DELETING VECTOR: " << (void*) this << endl;
   KST::scalarList.lock().writeLock();
   KST::scalarList.setUpdateDisplayTags(false);
   for (QDictIterator<KstScalar> it(_scalars); it.current(); ++it) {
@@ -380,19 +378,20 @@ void KstVector::updateScalars() {
     if (_nsum >= 2) {
       double sum = _scalars["sum"]->value();
       double sumsq = _scalars["sumsquared"]->value();
+
       _scalars["mean"]->setValue(_mean = sum/double(_nsum));
       _scalars["sigma"]->setValue(sqrt((sumsq - sum * sum / double(_nsum)) / double(_nsum-1)));
       _scalars["rms"]->setValue(sqrt(sumsq/double(_nsum)));
     } else {
+      _scalars["mean"]->setValue(_mean = KST::NOPOINT);
       _scalars["sigma"]->setValue(_max - _min);
       _scalars["rms"]->setValue(sqrt(_scalars["sumsquared"]->value()));
-      _scalars["mean"]->setValue(_mean = KST::NOPOINT);
     }
   }
 }
 
 
-const QDict<KstScalar>& KstVector::scalars() const {  
+const QDict<KstScalar>& KstVector::scalars() const {
   return _scalars;
 }
 
@@ -401,9 +400,9 @@ double* KstVector::realloced(double *memptr, int newSize) {
   double *old = _v;
   _v = memptr;
   if (newSize < _size) {
-    NumNew = newSize; // all new if we shrunk the vector
+    _numNew = newSize; // all new if we shrunk the vector
   } else {
-    NumNew = newSize - _size;
+    _numNew = newSize - _size;
   }
   _size = newSize;
   updateScalars();
@@ -414,7 +413,9 @@ double* KstVector::realloced(double *memptr, int newSize) {
 void KstVector::zero() {
   setDirty();
   _ns_min = _ns_max = 0.0;
+
   memset(_v, 0, sizeof(double)*_size);
+
   updateScalars();
 }
 
@@ -422,39 +423,30 @@ void KstVector::zero() {
 void KstVector::blank() {
   setDirty();
   _ns_min = _ns_max = 0.0;
-#if 0 
-  // FIXME: make this set NANs across, portably
-  memset(_v, 0, sizeof(double)*_size);
-#else
+
   for (int i = 0; i < _size; ++i) {
     _v[i] = KST::NOPOINT;
   }
-#endif
+
   updateScalars();
 }
 
 
 bool KstVector::resize(int sz, bool reinit) {
-  //kstdDebug() << "resizing to: " << sz << endl;
   if (sz > 0) {
     _v = static_cast<double*>(KST::realloc(_v, sz*sizeof(double)));
     if (!_v) {
       return false;
     }
+
 #ifdef ZERO_MEMORY
     if (reinit && _size < sz) {
-#if ZERO_MEMORY == 2
-      abort(); // must use NAN here
-      memset(&_v[_size], 0, (sz - _size)*sizeof(double));
-#else
       for (int i = _size; i < sz; i++) {
         _v[i] = KST::NOPOINT;
       }
-#endif
     }
-#else
-    abort();  // avoid unpleasant surprises
 #endif
+
     _size = sz;
     updateScalars();
   }
@@ -638,8 +630,8 @@ void KstVector::setTagName(const KstObjectTag& newTag) {
 
 
 void KstVector::setNewAndShift(int inNew, int inShift) {
-  NumNew = inNew;
-  NumShifted = inShift;
+  _numNew = inNew;
+  _numShifted = inShift;
 }
 
 
@@ -659,7 +651,7 @@ double *const KstVector::value() const {
 
 
 void KstVector::newSync() {
-  NumNew = NumShifted = 0;
+  _numNew = _numShifted = 0;
 }
 
 
@@ -788,4 +780,3 @@ int KstVector::indexNearX(double x, int NS) {
 #undef INITSIZE
 
 #include "kstvector.moc"
-// vim: et sw=2 ts=2
