@@ -77,6 +77,7 @@
 #include "kstmonochromedialog_i.h"
 #include "kstplugindialog_i.h"
 #include "kstbasicdialog_i.h"
+#include "kstpluginmanager_i.h"
 #include "kstprintoptionspage.h"
 #include "kstpsddialog_i.h"
 #include "kstquickstartdialog_i.h"
@@ -95,7 +96,6 @@
 #include "kstviewwindow.h"
 #include "plotmimesource.h"
 #include "plugincollection.h"
-#include "pluginmanager.h"
 #include "psversion.h"
 #include "statuslabel.h"
 #include "sysinfo.h"
@@ -107,8 +107,6 @@
 #define KST_STATUSBAR_DATA   1
 #define KST_STATUSBAR_STATUS 2
 
-#define KST_QUICKSTART_DLG
-
 static KstApp *inst = 0L;
 
 const QString& KstApp::defaultTag = KGlobal::staticQString("<Auto Name>");
@@ -164,9 +162,7 @@ KstApp::KstApp(QWidget *parent, const char *name)
   graphFileDialog = new KstGraphFileDialogI(this);
   vectorSaveDialog = new KstVectorSaveDialogI(this);
   _monochromeDialog = new KstMonochromeDialogI(this);
-#ifdef KST_QUICKSTART_DLG
   _quickStartDialog = new KstQuickStartDialogI(this, 0 , true);
-#endif
 
   initActions();
   readOptions();
@@ -896,6 +892,11 @@ void KstApp::slotConfigureKeys() {
 }
 
 
+void KstApp::waitForUpdate() const {
+  _updateThread->waitForUpdate();
+}
+
+
 bool KstApp::paused() const {
   return _updateThread->paused();
 }
@@ -2012,11 +2013,21 @@ void KstApp::showViewVectorsDialog() {
 }
 
 
+void KstApp::showViewVectorsDialog(const QString &vector) {
+  viewVectorsDialog->showViewVectorsDialog(vector);
+}
+
+
 void KstApp::showViewMatricesDialog() {
   viewMatricesDialog->showViewMatricesDialog();
 }
 
 
+void KstApp::showViewMatricesDialog(const QString &matrix) {
+  viewMatricesDialog->showViewMatricesDialog(matrix);
+}
+
+
 void KstApp::showViewFitsDialog() {
   viewFitsDialog->showViewFitsDialog();
 }
@@ -2240,7 +2251,7 @@ void KstApp::updateViewManager(bool onlyVisible) {
 
 
 void KstApp::showPluginManager() {
-  PluginManager *pm = new PluginManager(this, "Plugin Manager");
+  KstPluginManagerI *pm = new KstPluginManagerI(this, "Plugin Manager");
   pm->exec();
   delete pm;
 
@@ -2592,11 +2603,9 @@ const QStringList KstApp::recentFiles() const {
 
 
 void KstApp::showQuickStartDialog() {
-#ifdef KST_QUICKSTART_DLG
   if (KstSettings::globalSettings()->showQuickStart) {
     _quickStartDialog->show_I();
   }
-#endif
 }
 
 
