@@ -29,7 +29,6 @@
 #include "kstcolorsequence.h"
 #include "kstplotbase.h"
 #include "kstplotdefines.h"
-#include "kstviewwidget.h"
 #include "kstviewlegend.h"
 #include "kst_export.h"
 #include "kstscalar.h"
@@ -38,6 +37,7 @@ namespace Equation {
   class Node;
 }
 
+class KstViewWidget;
 class Kst2DPlot;
 typedef KstObjectList<KstSharedPtr<Kst2DPlot> > Kst2DPlotList;
 class KstViewLabel;
@@ -197,7 +197,6 @@ public:
   KstPlotLabel *yTickLabel() const;
   KstPlotLabel *fullTickLabel() const;
   void setPlotLabelFontSizes(int size);
-  
 
   QRect GetPlotRegion() const;
   QRect GetWinRegion() const;
@@ -217,7 +216,7 @@ public:
 
   KstBaseCurveList Curves;
 
-  void generateDefaultLabels(bool xl = true, bool yl = true, bool zl = true);
+  void generateDefaultLabels(bool xl = false, bool yl = false, bool zl = false);
 
   /* kstview tells kstplot where to offset the plot to */
   void setPixRect(const QRect& RelPlotRegion, const QRect& RelWinRegion, const QRect& RelPlotAndAxisRegion);
@@ -287,7 +286,7 @@ public:
   bool hasVectorToMarkers() const;
   void removeVectorToMarkers();
   KstVectorPtr vectorToMarkers() const;
-  
+
   void setXOffsetMode(bool xOffsetMode) { _xOffsetMode = xOffsetMode; }
   void setYOffsetMode(bool yOffsetMode) { _yOffsetMode = yOffsetMode; }
   bool xOffsetMode() const { return _xOffsetMode; }
@@ -335,7 +334,14 @@ public:
   int lineStyleMarkers() const { return _lineStyleMarkers; }
   void setDefaultColorMarker(bool defaultColor) { _defaultMarkerColor = defaultColor; }
   bool defaultColorMarker() const { return _defaultMarkerColor; }
-  
+
+  void setAutoLabelTop(bool autoLabel) { _autoLabelTop = autoLabel; }
+  bool autoLabelTop( ) const { return _autoLabelTop; }
+  void setAutoLabelX(bool autoLabel) { _autoLabelX = autoLabel; }
+  bool autoLabelX( ) const { return _autoLabelX; }
+  void setAutoLabelY(bool autoLabel) { _autoLabelY = autoLabel; }
+  bool autoLabelY( ) const { return _autoLabelY; }
+
   // set and get tick mark display options
   void setXTicksInPlot(bool yes);
   void setXTicksOutPlot(bool yes);
@@ -461,7 +467,6 @@ private:
   // for backwards compatibility with old labels - convert an old saved label to a KstViewLabel
   KstViewLabelPtr convertLabelToViewLabel(const QDomElement &e);
 
-  void updateDirtyFromLabels();
   void setCursorPos(QWidget *view);
   void unsetCursorPos(QWidget *view);
   void drawCursorPos(QWidget *view);
@@ -525,14 +530,14 @@ private:
   bool _yMinorGrid : 1;
   bool _majorGridColorDefault : 1;
   bool _minorGridColorDefault : 1;
-  
+
   int _majorPenWidth;
   int _minorPenWidth;
   int _axisPenWidth;
 
   double _xLogBase;
   double _yLogBase;
-  
+
   bool _cursorOffset : 1;
 
   bool _xLog : 1;
@@ -558,6 +563,10 @@ private:
   bool _suppressLeft : 1;
   bool _suppressRight : 1;
 
+  bool _autoLabelTop : 1;
+  bool _autoLabelX : 1;
+  bool _autoLabelY : 1;
+
   bool _xMinParsedValid : 1, _xMaxParsedValid : 1, _yMinParsedValid : 1, _yMaxParsedValid : 1;
   bool _xTransformed : 1, _yTransformed : 1;
 
@@ -643,7 +652,7 @@ private:
   QString _xTransformedExp, _yTransformedExp;
 
   // helper functions for draw(...)
-  void plotLabels(QPainter& p, int x_px, int y_px, double xleft_bdr_px, double xright_bdr_px, double ytop_bdr_px);
+  void plotLabels(QPainter& p, int x_px, int y_px, double xleft_bdr_px, double xright_bdr_px, double ytop_bdr_px, double ybot_bdr_px);
   void plotAxes(QPainter& p, QRect& plotRegion,
       TickParameters tpx,
       double xleft_bdr_px, double xright_bdr_px,
@@ -664,7 +673,7 @@ private:
 
   KstScaleModeType _xScaleModeDefault;
   KstScaleModeType _yScaleModeDefault;
-  
+
   int _tabToShow;
 };
 
@@ -672,4 +681,4 @@ typedef KstSharedPtr<Kst2DPlot> Kst2DPlotPtr;
 typedef KstObjectMap<Kst2DPlotPtr> Kst2DPlotMap;
 
 #endif
-// vim: ts=2 sw=2 et
+
