@@ -46,6 +46,7 @@
 #include "kstlinestyle.h"
 #include "kstplotlabel.h"
 #include "kstsettings.h"
+#include "ksttoplevelview.h"
 
 Kst2dPlotWidget::Kst2dPlotWidget(QWidget* parent, const char* name, WFlags fl) : View2DPlotWidget(parent, name, fl )
 {
@@ -80,10 +81,10 @@ Kst2dPlotWidget::Kst2dPlotWidget(QWidget* parent, const char* name, WFlags fl) :
   connect(XExpression, SIGNAL(toggled(bool)), this, SLOT(updateButtons()));
   connect(YExpression, SIGNAL(toggled(bool)), this, SLOT(updateButtons()));
 
-  connect(scalarSelectorX1, SIGNAL(activated(const QString&)), XExpressionMin, SLOT(insert(const QString&)));
-  connect(scalarSelectorY1, SIGNAL(activated(const QString&)), YExpressionMin, SLOT(insert(const QString&)));
-  connect(scalarSelectorX2, SIGNAL(activated(const QString&)), XExpressionMax, SLOT(insert(const QString&)));
-  connect(scalarSelectorY2, SIGNAL(activated(const QString&)), YExpressionMax, SLOT(insert(const QString&)));
+  connect(scalarSelectorX1, SIGNAL(activated(const QString&)), this, SLOT(insertXExpressionMin(const QString&)));
+  connect(scalarSelectorY1, SIGNAL(activated(const QString&)), this, SLOT(insertYExpressionMin(const QString&)));
+  connect(scalarSelectorX2, SIGNAL(activated(const QString&)), this, SLOT(insertXExpressionMax(const QString&)));
+  connect(scalarSelectorY2, SIGNAL(activated(const QString&)), this, SLOT(insertYExpressionMax(const QString&)));
 
   // adding/removing curves
   connect(DisplayedCurveList, SIGNAL(clicked(QListBoxItem*)), this, SLOT(updateButtons()));
@@ -97,16 +98,21 @@ Kst2dPlotWidget::Kst2dPlotWidget(QWidget* parent, const char* name, WFlags fl) :
   connect(_up, SIGNAL(clicked()), this, SLOT(upDisplayedCurve()));
   connect(_down, SIGNAL(clicked()), this, SLOT(downDisplayedCurve()));
 
-  connect(AutoLabel, SIGNAL(clicked()), this, SLOT(generateDefaultLabels()));
+  connect(_checkBoxAutoLabelTop, SIGNAL(clicked()), this, SLOT(autoLabelTop()));
+  connect(_checkBoxAutoLabelX, SIGNAL(clicked()), this, SLOT(autoLabelX()));
+  connect(_checkBoxAutoLabelY, SIGNAL(clicked()), this, SLOT(autoLabelY()));
 
   connect(ScalarList, SIGNAL(activated(int)), this, SLOT(insertCurrentScalar()));
 
   connect(YAxisText, SIGNAL(selectionChanged()), this, SLOT(setScalarDestYLabel()));
   connect(YAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(setScalarDestYLabel()));
+  connect(YAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedYAxisText()));
   connect(XAxisText, SIGNAL(selectionChanged()), this, SLOT(setScalarDestXLabel()));
   connect(XAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(setScalarDestXLabel()));
+  connect(XAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedXAxisText()));
   connect(TopLabelText, SIGNAL(selectionChanged()), this, SLOT(setScalarDestTopLabel()));
   connect(TopLabelText, SIGNAL(textChanged(const QString &)), this, SLOT(setScalarDestTopLabel()));
+  connect(TopLabelText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedTopAxisText()));
 
   connect(_checkBoxXInterpret, SIGNAL(toggled(bool)), _comboBoxXInterpret, SLOT(setEnabled(bool)));
   connect(_checkBoxXInterpret, SIGNAL(toggled(bool)), _comboBoxXDisplay, SLOT(setEnabled(bool)));
@@ -202,13 +208,32 @@ Kst2dPlotWidget::Kst2dPlotWidget(QWidget* parent, const char* name, WFlags fl) :
 Kst2dPlotWidget::~Kst2dPlotWidget() {
 }
 
-void Kst2dPlotWidget::generateDefaultLabels() {
+void Kst2dPlotWidget::resizeEvent(QResizeEvent *event) {
+  fillMarkerLineCombo();
+  View2DPlotWidget::resizeEvent(event);
+}
+
+void Kst2dPlotWidget::generateDefaultLabels(bool xl, bool yl, bool zl) {
+  disconnect(YAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedYAxisText()));
+  disconnect(XAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedXAxisText()));
+  disconnect(TopLabelText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedTopAxisText()));
+
   if (_plot) {
-    _plot->generateDefaultLabels();
-    XAxisText->setText(_plot->xLabel()->text());
-    YAxisText->setText(_plot->yLabel()->text());
-    TopLabelText->setText(_plot->topLabel()->text());
+    _plot->generateDefaultLabels(xl, yl, zl);
+    if (xl) {
+      XAxisText->setText(_plot->xLabel()->text());
+    }
+    if (yl) {
+      YAxisText->setText(_plot->yLabel()->text());
+    }
+    if (zl) {
+      TopLabelText->setText(_plot->topLabel()->text());
+    }
   }
+
+  connect(YAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedYAxisText()));
+  connect(XAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedXAxisText()));
+  connect(TopLabelText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedTopAxisText()));
 }
 
 void Kst2dPlotWidget::updateButtons() {
@@ -258,7 +283,7 @@ void Kst2dPlotWidget::updateButtons() {
   _xTransformTopExp->setEnabled(_xTransformTop->isChecked());
 
   // updates for range tab Y...
-  YACRange->setEnabled(_editMultipleMode || XAC->isChecked());
+  YACRange->setEnabled(_editMultipleMode || YAC->isChecked());
   YExpressionMin->setEnabled(_editMultipleMode || YExpression->isChecked());
   YExpressionMax->setEnabled(_editMultipleMode || YExpression->isChecked());
   scalarSelectorY1->setEnabled(_editMultipleMode || YExpression->isChecked());
@@ -286,12 +311,10 @@ void Kst2dPlotWidget::updateButtons() {
     RemovePlotMarker->setEnabled(selected);
     RemoveAllPlotMarkers->setEnabled(count > 0);
   }
-  _colorMarker->setEnabled(_checkBoxDefaultMarkerColor->state() != QButton::Off);
+  _colorMarker->setEnabled(_checkBoxDefaultMarkerColor->state() != QButton::On);
 }
 
-
-void Kst2dPlotWidget::addDisplayedCurve()
-{
+void Kst2dPlotWidget::addDisplayedCurve() {
   uint count = AvailableCurveList->count();
   if (count > 0) {
     for (int i = count-1; i >= 0; i--) {
@@ -303,12 +326,9 @@ void Kst2dPlotWidget::addDisplayedCurve()
     updateButtons();
     emit changed();
   }
-  TrackContents->setChecked(false);
 }
 
-
-void Kst2dPlotWidget::removeDisplayedCurve()
-{
+void Kst2dPlotWidget::removeDisplayedCurve() {
   uint count = DisplayedCurveList->count();
   if (count > 0) {
     for (int i = count-1; i >= 0; i--) {
@@ -320,26 +340,20 @@ void Kst2dPlotWidget::removeDisplayedCurve()
     updateButtons();
     emit changed();
   }
-  TrackContents->setChecked(false);
 }
 
-
-void Kst2dPlotWidget::upDisplayedCurve()
-{
+void Kst2dPlotWidget::upDisplayedCurve() {
   if (DisplayedCurveList->up()) {
     emit changed();
   }
 }
 
-
-void Kst2dPlotWidget::downDisplayedCurve()
-{
+void Kst2dPlotWidget::downDisplayedCurve() {
   if (DisplayedCurveList->down()) {
     emit changed();
   }
 }
 
-
 void Kst2dPlotWidget::fillMarkerLineCombo() {
   QRect rect = _comboMarkerLineStyle->style().querySubControlMetrics(QStyle::CC_ComboBox, _comboMarkerLineStyle, QStyle::SC_ComboBoxEditField);
   rect.setLeft(rect.left() + 2);
@@ -347,7 +361,6 @@ void Kst2dPlotWidget::fillMarkerLineCombo() {
   rect.setTop(rect.top() + 2);
   rect.setBottom(rect.bottom() - 2);
 
-  // fill the point type dialog with point types
   QPixmap ppix(rect.width(), rect.height());
   QPainter pp(&ppix);
   QPen pen(QColor("black"), 0);
@@ -366,7 +379,6 @@ void Kst2dPlotWidget::fillMarkerLineCombo() {
   _comboMarkerLineStyle->setCurrentItem(currentItem);
 }
 
-
 void Kst2dPlotWidget::updateAxesButtons() {
   bool major = _xMajorGrid->isChecked() || _yMajorGrid->isChecked();
   bool minor = _xMinorGrid->isChecked() || _yMinorGrid->isChecked();
@@ -385,7 +397,6 @@ void Kst2dPlotWidget::updateAxesButtons() {
   _yMinorTicks->setEnabled(_yMinorTicksAuto->state() != QButton::On);
 }
 
-
 void Kst2dPlotWidget::updateScalarCombo() {
   ScalarList->clear();
   scalarSelectorX1->clear();
@@ -533,6 +544,9 @@ void Kst2dPlotWidget::populateEditMultiple(const Kst2DPlot *plot) {
   populateEditMultiple(_minorGridColor);
   populateEditMultiple(_comboBoxTopLabelJustify);
   populateEditMultiple(FontComboBox);
+  populateEditMultiple(_checkBoxAutoLabelTop);
+  populateEditMultiple(_checkBoxAutoLabelX);
+  populateEditMultiple(_checkBoxAutoLabelY);
 
   //
   // X Axis tab...
@@ -663,6 +677,10 @@ void Kst2dPlotWidget::fillWidget(const Kst2DPlot *plot) {
   _checkBoxDefaultMajorGridColor->setChecked(plot->defaultMajorGridColor());
   _checkBoxDefaultMinorGridColor->setChecked(plot->defaultMinorGridColor());
 
+  _checkBoxAutoLabelTop->setChecked(plot->autoLabelTop());
+  _checkBoxAutoLabelX->setChecked(plot->autoLabelX());
+  _checkBoxAutoLabelY->setChecked(plot->autoLabelY());
+
   // insert the current plot name in the plot name edit box
   _title->setText(plot->tagName());
 
@@ -766,6 +784,10 @@ void Kst2dPlotWidget::fillWidget(const Kst2DPlot *plot) {
   _spinBoxXAngle->setValue((int)plot->xTickLabel()->rotation());
   _spinBoxYAngle->setValue((int)plot->yTickLabel()->rotation());
 
+  disconnect(YAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedYAxisText()));
+  disconnect(XAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedXAxisText()));
+  disconnect(TopLabelText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedTopAxisText()));
+
   XAxisText->setText(plot->xLabel()->text());
   XLabelFontSize->setValue(plot->xLabel()->fontSize());
 
@@ -774,6 +796,11 @@ void Kst2dPlotWidget::fillWidget(const Kst2DPlot *plot) {
 
   TopLabelText->setText(plot->topLabel()->text());
   TopLabelFontSize->setValue(plot->topLabel()->fontSize());
+
+  connect(YAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedYAxisText()));
+  connect(XAxisText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedXAxisText()));
+  connect(TopLabelText, SIGNAL(textChanged(const QString &)), this, SLOT(modifiedTopAxisText()));
+
   FontComboBox->setCurrentFont(plot->topLabel()->fontName());
   switch (plot->topLabel()->justification()) {
     case KST_JUSTIFY_H_LEFT:
@@ -981,6 +1008,30 @@ void Kst2dPlotWidget::applyAppearance(Kst2DPlotPtr plot) {
     plot->topLabel()->setFontName(FontComboBox->currentText());
   }
 
+  if (!_editMultipleMode || _checkBoxAutoLabelTop->state() != QButton::NoChange) {
+    if (_checkBoxAutoLabelTop->state() == QButton::On) {
+      plot->setAutoLabelTop(true);
+    } else if (_checkBoxAutoLabelTop->state() == QButton::Off) {
+      plot->setAutoLabelTop(false);
+    }
+  }
+
+  if (!_editMultipleMode || _checkBoxAutoLabelX->state() != QButton::NoChange) {
+    if (_checkBoxAutoLabelX->state() == QButton::On) {
+      plot->setAutoLabelX(true);
+    } else if (_checkBoxAutoLabelX->state() == QButton::Off) {
+      plot->setAutoLabelX(false);
+    }
+  }
+
+  if (!_editMultipleMode || _checkBoxAutoLabelY->state() != QButton::NoChange) {
+    if (_checkBoxAutoLabelY->state() == QButton::On) {
+      plot->setAutoLabelY(true);
+    } else if (_checkBoxAutoLabelY->state() == QButton::Off) {
+      plot->setAutoLabelY(false);
+    }
+  }
+
   if (!_editMultipleMode || XLabelFontSize->value() != XLabelFontSize->minValue()) {
     plot->xLabel()->setFontSize(XLabelFontSize->value());
   }
@@ -1370,16 +1421,18 @@ void Kst2dPlotWidget::applyPlotMarkers(Kst2DPlotPtr plot) {
     } else {
       plot->removeCurveToMarkers();
     }
+
+    if (UseVector->isChecked()) {
+      KstVectorPtr vector = *(KST::vectorList.findTag(_vectorForMarkers->selectedVector()));
+      plot->setVectorToMarkers(vector);
+    } else {
+      plot->removeVectorToMarkers();
+    }
   }
 
-  if (UseVector->isChecked()) {
-    KstVectorPtr vector = *(KST::vectorList.findTag(_vectorForMarkers->selectedVector()));
-    plot->setVectorToMarkers(vector);
-  } else {
-    plot->removeVectorToMarkers();
+  if (!_editMultipleMode || _comboMarkerLineStyle->currentText().compare(QString(" ")) != 0) {
+    plot->setLineStyleMarkers(_comboMarkerLineStyle->currentItem());
   }
-
-  plot->setLineStyleMarkers(_comboMarkerLineStyle->currentItem());
   if (!_editMultipleMode || _spinBoxMarkerLineWidth->value() != _spinBoxMarkerLineWidth->minValue()) {
     plot->setLineWidthMarkers(_spinBoxMarkerLineWidth->value());
   }
@@ -1464,4 +1517,60 @@ void Kst2dPlotWidget::editLegend() {
   ShowLegend->setChecked(true);
 }
 
+void Kst2dPlotWidget::insertXExpressionMin(const QString& strIn) {
+  QString str;
+
+  str = "["+strIn+"]";
+
+  XExpressionMin->insert(str);
+}
+
+void Kst2dPlotWidget::insertYExpressionMin(const QString& strIn) {
+  QString str;
+
+  str = "["+strIn+"]";
+
+  YExpressionMin->insert(str);
+}
+
+void Kst2dPlotWidget::insertXExpressionMax(const QString& strIn) {
+  QString str;
+
+  str = "["+strIn+"]";
+
+  XExpressionMax->insert(str);
+}
+
+void Kst2dPlotWidget::insertYExpressionMax(const QString& strIn) {
+  QString str;
+
+  str = "["+strIn+"]";
+
+  YExpressionMax->insert(str);
+}
+
+void Kst2dPlotWidget::modifiedYAxisText() {
+  _checkBoxAutoLabelY->setChecked(false);
+}
+
+void Kst2dPlotWidget::modifiedXAxisText() {
+  _checkBoxAutoLabelX->setChecked(false);
+}
+
+void Kst2dPlotWidget::modifiedTopAxisText() {
+  _checkBoxAutoLabelTop->setChecked(false);
+}
+
+void Kst2dPlotWidget::autoLabelY() {
+  generateDefaultLabels(false, true, false);
+}
+
+void Kst2dPlotWidget::autoLabelX() {
+  generateDefaultLabels(true, false, false);
+}
+
+void Kst2dPlotWidget::autoLabelTop() {
+  generateDefaultLabels(false, false, true);
+}
+
 #include "kst2dplotwidget_i.moc"
