@@ -150,6 +150,11 @@ void KstBasicDialogI::init() {
 
 
 QString KstBasicDialogI::editTitle() {
+  KstBasicPluginPtr ptr = kst_cast<KstBasicPlugin>(_dp);
+  if (ptr) {
+    return i18n("Edit ") + ptr->name();
+  }
+
   return i18n("Edit ") + _pluginName;
 }
 
