@@ -35,6 +35,7 @@
 #include "curveplacementwidget.h"
 #include "editmultiplewidget.h"
 #include "kst2dplot.h"
+#include "kstchoosecolordialog_i.h"
 #include "kstcurvedialog_i.h"
 #include "kstdataobjectcollection.h"
 #include "kstviewwindow.h"
@@ -76,6 +77,31 @@ KstCurveDialogI::KstCurveDialogI(QWidget* parent, const char* name, bool modal,
   connect(_w->_curveAppearance->_showBars, SIGNAL(clicked()), this, SLOT(setShowBarsDirty()));
   connect(_w->_checkBoxIgnoreAutoscale, SIGNAL(clicked()), this, SLOT(setCheckBoxIgnoreAutoscaleDirty()));
 
+  // for apply button
+  connect(_w->_xVector, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yVector, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xError, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xMinusError, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yError, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yMinusError, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xVector, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yVector, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xError, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xMinusError, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yError, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yMinusError, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xVector->_vector, SIGNAL(completion(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yVector->_vector, SIGNAL(completion(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xError->_vector, SIGNAL(completion(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xMinusError->_vector, SIGNAL(completion(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yError->_vector, SIGNAL(completion(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yMinusError->_vector, SIGNAL(completion(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_interp, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_checkBoxXMinusSameAsPlus, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_checkBoxYMinusSameAsPlus, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_curveAppearance, SIGNAL(changed()), this, SLOT(wasModifiedApply()));
+  connect(_w->_checkBoxIgnoreAutoscale, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+
   _w->_xError->provideNoneVector(true);
   _w->_yError->provideNoneVector(true);
   _w->_xMinusError->provideNoneVector(true);
@@ -270,8 +296,11 @@ bool KstCurveDialogI::newObject() {
     EYMinus->readLock();
   }
 
-  // create the curve
-  KstVCurvePtr curve = new KstVCurve(tag_name, VX, VY, EX, EY, EXMinus, EYMinus, _w->_curveAppearance->color());
+  QColor color = KstApp::inst()->chooseColorDlg()->getColorForCurve(VX, VY);
+  if (!color.isValid()) {
+    color = _w->_curveAppearance->color();
+  }
+  KstVCurvePtr curve = new KstVCurve(tag_name, VX, VY, EX, EY, EXMinus, EYMinus, color);
 
   if (EX) {
     EX->unlock();
