@@ -75,7 +75,6 @@ static QMap<int,Kst2DPlotPtr> PlotMap;
 
 KstObjectItem::KstObjectItem(QListView *parent, KstRVectorPtr x, KstDataManagerI *dm, int localUseCount)
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_DATA_VECTOR), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Data Vector"));
@@ -86,7 +85,6 @@ KstObjectItem::KstObjectItem(QListView *parent, KstRVectorPtr x, KstDataManagerI
 
 KstObjectItem::KstObjectItem(QListView *parent, KstSVectorPtr x, KstDataManagerI *dm, int localUseCount)
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_STATIC_VECTOR), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Static Vector"));
@@ -97,7 +95,6 @@ KstObjectItem::KstObjectItem(QListView *parent, KstSVectorPtr x, KstDataManagerI
 
 KstObjectItem::KstObjectItem(QListView *parent, KstAVectorPtr x, KstDataManagerI *dm, int localUseCount)
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_A_VECTOR), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Static Vector"));
@@ -108,7 +105,6 @@ KstObjectItem::KstObjectItem(QListView *parent, KstAVectorPtr x, KstDataManagerI
 
 KstObjectItem::KstObjectItem(KListViewItem *parent, KstVectorPtr x, KstDataManagerI *dm, int localUseCount)
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_VECTOR), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Slave Vector"));
@@ -119,7 +115,6 @@ KstObjectItem::KstObjectItem(KListViewItem *parent, KstVectorPtr x, KstDataManag
 
 KstObjectItem::KstObjectItem(QListView *parent, KstDataObjectPtr x, KstDataManagerI *dm, int localUseCount)
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_OBJECT), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   for (KstVectorMap::Iterator i = x->outputVectors().begin();
@@ -141,7 +136,6 @@ KstObjectItem::KstObjectItem(QListView *parent, KstDataObjectPtr x, KstDataManag
 
 KstObjectItem::KstObjectItem(QListView *parent, KstRMatrixPtr x, KstDataManagerI *dm, int localUseCount) 
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_DATA_MATRIX), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Data Matrix"));
@@ -152,7 +146,6 @@ KstObjectItem::KstObjectItem(QListView *parent, KstRMatrixPtr x, KstDataManagerI
 
 KstObjectItem::KstObjectItem(QListView *parent, KstSMatrixPtr x, KstDataManagerI *dm, int localUseCount) 
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_STATIC_MATRIX), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Static Matrix"));
@@ -163,7 +156,6 @@ KstObjectItem::KstObjectItem(QListView *parent, KstSMatrixPtr x, KstDataManagerI
 
 KstObjectItem::KstObjectItem(QListView *parent, KstAMatrixPtr x, KstDataManagerI *dm, int localUseCount) 
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_A_MATRIX), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Static Matrix"));
@@ -174,7 +166,6 @@ KstObjectItem::KstObjectItem(QListView *parent, KstAMatrixPtr x, KstDataManagerI
 
 KstObjectItem::KstObjectItem(KListViewItem *parent, KstMatrixPtr x, KstDataManagerI *dm, int localUseCount) 
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_MATRIX), _tag(x->tag()), _dm(dm) {
-  assert(x);
   _inUse = false;
   setText(0, x->tag().tag());
   setText(1, i18n("Slave Matrix"));
@@ -570,31 +561,41 @@ void KstObjectItem::reload() {
 
 void KstObjectItem::makeCurve() {
   KstCurveDialogI::globalInstance()->show();
-  KstCurveDialogI::globalInstance()->setVector(_tag.tag());
+  KstCurveDialogI::globalInstance()->setVector(_tag.tagString());
 }
 
 
 void KstObjectItem::makeCSD() {
   KstCsdDialogI::globalInstance()->show();
-  KstCsdDialogI::globalInstance()->setVector(_tag.tag());
+  KstCsdDialogI::globalInstance()->setVector(_tag.tagString());
 }
 
 
 void KstObjectItem::makePSD() {
   KstPsdDialogI::globalInstance()->show();
-  KstPsdDialogI::globalInstance()->setVector(_tag.tag());
+  KstPsdDialogI::globalInstance()->setVector(_tag.tagString());
 }
 
 
 void KstObjectItem::makeHistogram() {
   KstHsDialogI::globalInstance()->show();
-  KstHsDialogI::globalInstance()->setVector(_tag.tag());
+  KstHsDialogI::globalInstance()->setVector(_tag.tagString());
 }
 
 
 void KstObjectItem::makeImage() {
   KstImageDialogI::globalInstance()->show();
-  KstImageDialogI::globalInstance()->setMatrix(_tag.tag());
+  KstImageDialogI::globalInstance()->setMatrix(_tag.tagString());
+}
+
+
+void KstObjectItem::viewVectorValues() {
+  KstApp::inst()->showViewVectorsDialog(_tag.tagString());
+}
+
+
+void KstObjectItem::viewMatrixValues() {
+  KstApp::inst()->showViewMatricesDialog(_tag.tagString());
 }
 
 
@@ -1353,17 +1354,21 @@ void KstDataManagerI::contextMenu(QListViewItem *i, const QPoint& p, int col) {
     id = m->insertItem(i18n("Make &Histogram..."), koi, SLOT(makeHistogram()));
     id = m->insertItem(i18n("&Reload"), koi, SLOT(reload()));
     id = m->insertItem(i18n("Meta &Data"), koi, SLOT(showMetadata()));
+    id = m->insertItem(i18n("&View Values..."), koi, SLOT(viewVectorValues()));
   } else if (koi->rtti() == RTTI_OBJ_VECTOR) {
     id = m->insertItem(i18n("&Make Curve..."), koi, SLOT(makeCurve()));
     id = m->insertItem(i18n("Make Spect&rum..."), koi, SLOT(makePSD()));
     id = m->insertItem(i18n("Make &Spectrogram..."), koi, SLOT(makeCSD()));
     id = m->insertItem(i18n("Make &Histogram..."), koi, SLOT(makeHistogram()));
+    id = m->insertItem(i18n("&View Values..."), koi, SLOT(viewVectorValues()));
   } else if (koi->rtti() == RTTI_OBJ_DATA_MATRIX) {
     id = m->insertItem(i18n("Make &Image..."), koi, SLOT(makeImage()));  
     id = m->insertItem(i18n("&Reload"), koi, SLOT(reload()));
     id = m->insertItem(i18n("Meta &Data"), koi, SLOT(showMetadata()));
+    id = m->insertItem(i18n("&View Values..."), koi, SLOT(viewMatrixValues()));
   } else if (koi->rtti() == RTTI_OBJ_MATRIX || koi->rtti() == RTTI_OBJ_STATIC_MATRIX) {
     id = m->insertItem(i18n("Make &Image..."), koi, SLOT(makeImage()));
+    id = m->insertItem(i18n("&View Values..."), koi, SLOT(viewMatrixValues()));
   } else if ((c = kst_cast<KstBaseCurve>(koi->dataObject()))) {
     KPopupMenu *addMenu = new KPopupMenu(this);
     KPopupMenu *removeMenu = new KPopupMenu(this);
