@@ -125,6 +125,8 @@ class KstObjectItem : public QObject, public KListViewItem {
     void makeImage();
     void reload();
     void showMetadata();
+    void viewVectorValues();
+    void viewMatrixValues();
 
   signals:
     void updated();
