@@ -54,14 +54,14 @@ KstDebugDialogI::KstDebugDialogI(QWidget* parent,
 
   _buildInfo->setText(i18n("<h1>Kst</h1> version %1 (%2)").arg(KSTVERSION).arg(KstDebug::self()->kstRevision()));
 
+  _dataSources->setAllColumnsShowFocus(true);
+
   connect(KstApp::inst()->document(), SIGNAL(logAdded(const KstDebug::LogMessage&)), _log, SLOT(logAdded(const KstDebug::LogMessage&)));
   connect(KstApp::inst()->document(), SIGNAL(logCleared()), _log, SLOT(clear()));
   connect(_email, SIGNAL(clicked()), this, SLOT(email()));
   connect(_clear, SIGNAL(clicked()), this, SLOT(clear()));
   connect(checkBoxShowDebug, SIGNAL(toggled(bool)), _log, SLOT(setShowDebug(bool)));
   connect(checkBoxShowWarning, SIGNAL(toggled(bool)), _log, SLOT(setShowWarning(bool)));
-  //connect(checkBoxShowOther, SIGNAL(toggled(bool)), _log, SLOT(messagesOther()));
-  checkBoxShowOther->hide(); // unused
   connect(checkBoxShowNotice, SIGNAL(toggled(bool)), _log, SLOT(setShowNotice(bool)));
   connect(checkBoxShowError, SIGNAL(toggled(bool)), _log, SLOT(setShowError(bool)));
 }
@@ -71,10 +71,11 @@ KstDebugDialogI::~KstDebugDialogI() {
 }
 
 
-void KstDebugDialogI::show_I() {   
-  // Inefficient but shouldn't be a factor
+void KstDebugDialogI::show_I() {
   QListViewItemIterator it(_dataSources);
+
   KST::dataSourceList.lock().readLock();
+
   while (it.current()) {
     while (it.current()->childCount() > 0) {
       delete it.current()->firstChild();
@@ -89,6 +90,7 @@ void KstDebugDialogI::show_I() {
     }
     ++it;
   }
+
   KST::dataSourceList.lock().unlock();
 
   QDialog::show();
