@@ -881,18 +881,19 @@ void KstDoc::deleteContents() {
 
 
 void KstDoc::samplesUp() {
-  bool changed = false;
   KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
-  for (int i = 0; i < (int)rvl.count(); i++) {
-    KstRVectorPtr V = rvl[i];
-    V->writeLock();
-    int f0 = V->reqStartFrame();
-    int n = V->reqNumFrames();
-    int skip = V->skip();
-    bool doSkip = V->doSkip();
-    bool doAve = V->doAve();
-    int fileN = V->fileLength();
+  bool changed = false;
 
+  for (int i = 0; i < (int)rvl.count(); i++) {
+    KstRVectorPtr v = rvl[i];
+    v->writeLock();
+
+    int f0 = v->reqStartFrame();
+    int n = v->reqNumFrames();
+    int skip = v->skip();
+    bool doSkip = v->doSkip();
+    bool doAve = v->doAve();
+    int fileN = v->fileLength();
     bool didChange = false;
 
     if (f0 == -1) {
@@ -908,9 +909,10 @@ void KstDoc::samplesUp() {
     }
 
     if (didChange) {
-      V->changeFrames(f0, n, skip, doSkip, doAve);
+      v->changeFrames(f0, n, skip, doSkip, doAve);
     }
-    V->unlock();
+
+    v->unlock();
   }
 
   if (changed) {
@@ -925,16 +927,16 @@ void KstDoc::samplesDown() {
   bool changed = false;
   KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
   for (int i = 0; i < (int)rvl.count(); i++) {
-    KstRVectorPtr V = rvl[i];
-    V->writeLock();
-    int f0 = V->reqStartFrame();
+    KstRVectorPtr v = rvl[i];
+    v->writeLock();
+    int f0 = v->reqStartFrame();
     if (f0 == -1) {
-      f0 = V->startFrame();
+      f0 = v->startFrame();
     }
-    int n = V->reqNumFrames();
-    int skip = V->skip();
-    bool doSkip = V->doSkip();
-    bool doAve =  V->doAve();
+    int n = v->reqNumFrames();
+    int skip = v->skip();
+    bool doSkip = v->doSkip();
+    bool doAve =  v->doAve();
 
     bool didChange = false;
     if (f0 - n < 0) {
@@ -947,9 +949,10 @@ void KstDoc::samplesDown() {
     }
 
     if (didChange) {
-      V->changeFrames(f0, n, skip, doSkip, doAve);
+      v->changeFrames(f0, n, skip, doSkip, doAve);
     }
-    V->unlock();
+
+    v->unlock();
   }
 
   if (changed) {
@@ -1061,10 +1064,11 @@ void KstDoc::purge() {
         kstdDebug() << "    -> REMOVED" << endl;
 #endif
         KST::vectorList.lock().writeLock();
-        KST::vectorList.remove(const_cast<KstVector*>((*it).data()));
+        if (KST::vectorList.removeObject(const_cast<KstVector*>((*it).data()))) {
+          again = true;
+          modified = true;
+        }
         KST::vectorList.lock().unlock();
-        again = true;
-        modified = true;
       }
       ++prg;
       app->slotUpdateProgress(cnt, prg, purging);
@@ -1092,10 +1096,11 @@ void KstDoc::purge() {
         kstdDebug() << "    -> REMOVED" << endl;
 #endif
         KST::matrixList.lock().writeLock();
-        KST::matrixList.remove(const_cast<KstMatrix*>((*it).data()));
+        if (KST::matrixList.removeObject(const_cast<KstMatrix*>((*it).data()))) {
+          again = true;
+          modified = true;
+        }
         KST::matrixList.lock().unlock();
-        again = true;
-        modified = true;
       }
       ++prg;
       app->slotUpdateProgress(cnt, prg, purging);
@@ -1144,7 +1149,10 @@ void KstDoc::enableUpdates() {
 
 bool KstDoc::event(QEvent *e) {
   if (e->type() == KstEventTypeThread) {
-    _updating = true; // block update thread from sending events 'till we're done
+    //
+    // block update thread from sending events until we're done
+    //
+    _updating = true;
 
     ThreadEvent *te = static_cast<ThreadEvent*>(e);
     switch (te->_eventType) {
@@ -1249,6 +1257,7 @@ bool KstDoc::event(QEvent *e) {
           break;
       }
     }
+
     return true;
   }
 
