@@ -60,7 +60,7 @@ KstEventMonitorI::KstEventMonitorI(QWidget* parent, const char* name, bool modal
   connect(_w->_scalarSelectorEq, SIGNAL(selectionChangedLabel(const QString&)), _w->lineEditEquation, SLOT(insert(const QString&)));
   connect(_w->_scalarSelectorEq, SIGNAL(selectionChangedLabel(const QString&)), _w->lineEditEquation, SLOT(setFocus()));
   connect(_w->_pushButtonELOGConfigure, SIGNAL(clicked()), KstApp::inst(), SLOT(EventELOGConfigure()));
-  
+
   // more multiple edit mode
   connect(_w->checkBoxDebug, SIGNAL(clicked()), this, SLOT(setcheckBoxDebugDirty()));
   connect(_w->checkBoxEMailNotify, SIGNAL(clicked()), this, SLOT(setcheckBoxEMailNotifyDirty()));
@@ -68,6 +68,20 @@ KstEventMonitorI::KstEventMonitorI(QWidget* parent, const char* name, bool modal
   connect(_w->_useScript, SIGNAL(clicked()), this, SLOT(setScriptDirty()));
   connect(_w->_script, SIGNAL(textChanged()), this, SLOT(setScriptDirty()));
 
+  // for apply button
+  connect(_w->lineEditEquation, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->lineEditDescription, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->checkBoxDebug, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->radioButtonLogNotice, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->radioButtonLogWarning, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->radioButtonLogError, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->checkBoxEMailNotify, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->lineEditEMailRecipients, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->checkBoxELOGNotify, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_pushButtonELOGConfigure, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_useScript, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_script, SIGNAL(textChanged()), this, SLOT(wasModifiedApply()));
+
   setFixedHeight(height());
 }
 
@@ -212,15 +226,15 @@ bool KstEventMonitorI::newObject() {
 
 bool KstEventMonitorI::editSingleObject(EventMonitorEntryPtr emPtr) {
   emPtr->writeLock();
-  
+
   if (_lineEditEquationDirty) {
     emPtr->setEvent(_w->lineEditEquation->text());
   }
-  
+
   if (_lineEditDescriptionDirty) {
     emPtr->setDescription(_w->lineEditDescription->text());
   }
-  
+
   if (_checkBoxDebugDirty) {
     if (!(_w->radioButtonLogNotice->isChecked() ||
           _w->radioButtonLogWarning->isChecked() ||
@@ -308,11 +322,11 @@ bool KstEventMonitorI::editObject() {
       _tagName->setFocus();
       return false;
     }
-    
+
     ep->writeLock();
-    ep->setTagName(KstObjectTag(tag_name, ep->tag().context())); // FIXME: doesn't allow changing tag context
+    ep->setTagName(tag_name);
     ep->unlock();
-    
+
     // then edit the object
     _lineEditEquationDirty = true;
     _lineEditDescriptionDirty = true;
@@ -353,10 +367,10 @@ void KstEventMonitorI::populateEditMultiple() {
 
   _w->checkBoxELOGNotify->setTristate(true);
   _w->checkBoxELOGNotify->setNoChange();
-  
+
   _tagName->setText("");
   _tagName->setEnabled(false);
-  
+
   _w->lineEditEMailRecipients->setEnabled(true); 
   _w->radioButtonLogNotice->setEnabled(true);
   _w->radioButtonLogWarning->setEnabled(true);
@@ -367,7 +381,7 @@ void KstEventMonitorI::populateEditMultiple() {
   _w->_useScript->setChecked(false);
   _w->_script->setEnabled(false);
   _w->_script->setText("");
-  
+
   // and clean all the fields
   _lineEditEquationDirty = false;
   _lineEditDescriptionDirty = false;
@@ -406,4 +420,4 @@ void KstEventMonitorI::setcheckBoxELOGNotifyDirty() {
 }
 
 #include "ksteventmonitor_i.moc"
-// vim: ts=2 sw=2 et
+
