@@ -37,8 +37,6 @@ class KstPlotLabel {
     void setJustification(KstLJustifyType Justify);
     KstLJustifyType justification() const { return _justify; }
 
-    int ascent() const;
-
     void setInterpreted(bool interpreted);
     bool interpreted() const;
 
@@ -46,11 +44,14 @@ class KstPlotLabel {
     const QString& fontName() const;
 
     void setFontSize(int size);
+    int fontSize() const;
     void updateAbsFontSize(int x_pix, int y_pix);
 
-    int fontSize() const;
+    void setDataPrecision(int prec);
+    int dataPrecision() const;
 
-    inline int lineSpacing() const { return _lineSpacing; }
+    int ascent() const;
+    int lineSpacing() const;
 
     void setDoScalarReplacement(bool in_do);
     bool doScalarReplacement() const;
@@ -78,6 +79,7 @@ class KstPlotLabel {
 
     bool _replace : 1;
     bool _interpret : 1;
+    int _dataPrecision : 6;
     int _fontSize;
     int _absFontSize;
     int _textWidth;
