@@ -40,11 +40,11 @@
 #include "curveappearancewidget.h"
 #include "kst.h"
 #include "kstplugindialog_i.h"
+#include "kstpluginmanager_i.h"
 #include "kstdataobjectcollection.h"
 #include "kstdefaultnames.h"
 #include "plugincollection.h"
 #include "plugindialogwidget.h"
-#include "pluginmanager.h"
 #include "scalarselector.h"
 #include "stringselector.h"
 #include "vectorselector.h"
@@ -80,6 +80,16 @@ KstPluginDialogI::~KstPluginDialogI() {
 }
 
 
+QString KstPluginDialogI::editTitle() {
+  return i18n("Edit Plugin");
+}
+
+
+QString KstPluginDialogI::newTitle() {
+  return i18n("New Plugin");
+}
+
+
 void KstPluginDialogI::updatePluginList() {
   PluginCollection *pc = PluginCollection::self();
   QString previous = _pluginList[_w->PluginCombo->currentItem()];
@@ -868,7 +878,7 @@ void KstPluginDialogI::pluginChanged(int idx) {
 
 
 void KstPluginDialogI::showPluginManager() {
-  PluginManager *pm = new PluginManager(this, "Plugin Manager");
+  KstPluginManagerI *pm = new KstPluginManagerI(this, "Plugin Manager");
   pm->exec();
   delete pm;
   updatePluginList();
