@@ -35,6 +35,7 @@
 #include "curveplacementwidget.h"
 #include "editmultiplewidget.h"
 #include "kst2dplot.h"
+#include "kstchoosecolordialog_i.h"
 #include "kstdataobjectcollection.h"
 #include "kstobjectdefaults.h"
 #include "kstpsddialog_i.h"
@@ -62,11 +63,29 @@ KstPsdDialogI::KstPsdDialogI(QWidget* parent, const char* name, bool modal, WFla
   setMultiple(true);
   connect(_w->_vector, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
 
-  //for multiple edit mode
+  // for multiple edit mode
   connect(_w->_kstFFTOptions->Apodize, SIGNAL(clicked()), this, SLOT(setApodizeDirty()));
   connect(_w->_kstFFTOptions->RemoveMean, SIGNAL(clicked()), this, SLOT(setRemoveMeanDirty()));
   connect(_w->_kstFFTOptions->Interleaved, SIGNAL(clicked()), this, SLOT(setInterleavedDirty()));
   connect(_w->_kstFFTOptions->InterpolateHoles, SIGNAL(clicked()), this, SLOT(setInterpolateHolesDirty()));
+
+  // for apply button
+  connect(_w->_vector, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_vector, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->ApodizeFxn, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->FFTLen, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->FFTLen->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->Sigma, SIGNAL(valueChanged(double)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->Sigma->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->Apodize, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->RemoveMean, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->Interleaved, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->InterpolateHoles, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->SampRate, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->VectorUnits, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->RateUnits, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstFFTOptions->Output, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_curveAppearance, SIGNAL(changed()), this, SLOT(wasModifiedApply()));
 }
 
 
@@ -104,13 +123,16 @@ void KstPsdDialogI::fillFieldsForEdit() {
   _w->_kstFFTOptions->Interleaved->setChecked(pp->average());
   _w->_kstFFTOptions->Output->setCurrentItem(pp->output());
   _w->_kstFFTOptions->InterpolateHoles->setChecked(pp->interpolateHoles());
+  _w->_kstFFTOptions->synch();
 
   pp->unlock();
 
   _w->_curveAppearance->hide();
   _w->_curvePlacement->hide();
+
   _legendText->hide();
   _legendLabel->hide();
+
   adjustSize();
   resize(minimumSizeHint());
   setFixedHeight(height());
@@ -189,7 +211,11 @@ bool KstPsdDialogI::newObject() {
     psd->setInterpolateHoles(_w->_kstFFTOptions->InterpolateHoles->isChecked());
     p->unlock();
 
-    KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(psd->tag(),true), psd->vX(), psd->vY(), 0L, 0L, 0L, 0L, _w->_curveAppearance->color());
+    QColor color = KstApp::inst()->chooseColorDlg()->getColorForCurve(psd->vX(), psd->vY());
+    if (!color.isValid()) {
+      color = _w->_curveAppearance->color();
+    }
+    KstVCurvePtr vc = new KstVCurve(KST::suggestCurveName(psd->tag(),true), psd->vX(), psd->vY(), 0L, 0L, 0L, 0L, color);
     vc->setHasPoints(_w->_curveAppearance->showPoints());
     vc->setHasLines(_w->_curveAppearance->showLines());
     vc->setHasBars(_w->_curveAppearance->showBars());
@@ -393,7 +419,7 @@ bool KstPsdDialogI::editObject() {
     }
 
     pp->writeLock();
-    pp->setTagName(KstObjectTag(tag_name, pp->tag().context())); // FIXME: doesn't allow changing tag context
+    pp->setTagName(tag_name);
     pp->unlock();
 
     // then edit the object
