@@ -275,10 +275,10 @@ void KstTopLevelView::updateFocus(const QPoint& pos) {
   KstViewObjectPtr p = findDeepestChild(pos, false);
   if (p) {
     KstViewObjectPtr p2 = p;
-    while (p2->_parent && p2->_parent->_container) {
+    while (p2->_parent && p2->_parent->isContainer()) {
       p2 = p2->_parent;
     }
-    if (p2->_parent && !p2->_parent->_container) {
+    if (p2->_parent && !p2->_parent->isContainer()) {
       p = p2->_parent;
     }
   }
@@ -391,15 +391,15 @@ bool KstTopLevelView::handlePress(const QPoint& pos, bool shift) {
     return false;
   }
 
-  _pressTarget = findDeepestChild(pos, false);
+  _pressTarget = findDeepestChild(pos, false, true);
   if (_pressTarget) {
     KstViewObjectPtr p = _pressTarget;
-    while (p->_parent && (p->_parent->_container || kst_cast<KstPlotGroup>((KstViewObjectPtr)p->_parent)) && !kst_cast<KstTopLevelView>((KstViewObjectPtr)p->_parent)) {
+    while (p->_parent && (p->_parent->isContainer() || kst_cast<KstPlotGroup>((KstViewObjectPtr)p->_parent)) && !kst_cast<KstTopLevelView>((KstViewObjectPtr)p->_parent)) {
       p = p->_parent;
     }
-    if (p->_parent && !p->_parent->_container && !kst_cast<KstTopLevelView>((KstViewObjectPtr)p->_parent)) {
+    if (p->_parent && !p->_parent->isContainer() && !kst_cast<KstTopLevelView>((KstViewObjectPtr)p->_parent)) {
       _pressTarget = p->_parent;
-    } else if (p && !p->_container) {
+    } else if (p && !p->isContainer()) {
       _pressTarget = p;
     }
   }
@@ -1273,13 +1273,13 @@ void KstTopLevelView::menuClosed() {
 bool KstTopLevelView::popupMenu(KPopupMenu *menu, const QPoint& pos) {
   bool rc = false;
   // Want to clear focus without repaint
-  _pressTarget = findDeepestChild(pos, false);
+  _pressTarget = findDeepestChild(pos, false, true);
   if (_pressTarget) {
     KstViewObjectPtr p = _pressTarget;
-    while (p->_parent && p->_parent->_container) {
+    while (p->_parent && p->_parent->isContainer()) {
       p = p->_parent;
     }
-    if (p->_parent && !p->_parent->_container) {
+    if (p->_parent && !p->_parent->isContainer()) {
       _pressTarget = p->_parent;
     }
   }
