@@ -39,6 +39,7 @@
 #include "editmultiplewidget.h"
 #include "kst.h"
 #include "kstdatacollection.h"
+#include "kstfieldselect_i.h"
 #include "kstrvector.h"
 #include "kstsvector.h"
 #include "kstvectordefaults.h"
@@ -75,6 +76,7 @@ KstVectorDialogI::KstVectorDialogI(QWidget* parent, const char* name,
   connect(_w->_readFromSource, SIGNAL(clicked()), this, SLOT(enableSource()));
   connect(_w->_generateX, SIGNAL(clicked()), this, SLOT(enableGenerate()));
   connect(_w->_connect, SIGNAL(clicked()), this, SLOT(testURL()));
+  connect(_w->_pushButtonHierarchy, SIGNAL(clicked()), this, SLOT(showFields()));
 
   // connections for multiple edit mode
   connect(_w->_kstDataRange->CountFromEnd, SIGNAL(clicked()), this, SLOT(setCountFromEndDirty()));
@@ -104,10 +106,12 @@ KstVectorDialogI::KstVectorDialogI(QWidget* parent, const char* name,
   connect(_w->_kstDataRange->DoFilter, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
 
   _w->_configure->setEnabled(false);
+  _w->_connect->setHidden(true);
   _fieldCompletion = _w->Field->completionObject();
   _w->Field->setAutoDeleteCompletionObject(true);
   setFixedHeight(height());
   _configWidget = 0L;
+  _hierarchy = false;
   _w->Field->setEnabled(false);
   _ok->setEnabled(_w->Field->isEnabled());
   _legendLabel->hide();
@@ -152,6 +156,23 @@ void KstVectorDialogI::testURL() {
 }
 
 
+void KstVectorDialogI::showFields() {
+  KstFieldSelectI *dlg = new KstFieldSelectI(this, "Field Select", true);
+  if (dlg) {
+    dlg->setURL(_w->FileName->url());
+    dlg->exec();
+
+    if (dlg->result() == QDialog::Accepted) {
+      if (!dlg->selection().isEmpty()) {
+        _w->Field->setCurrentText(dlg->selection());
+      }
+    }
+
+    delete dlg;
+  }
+}
+
+
 void KstVectorDialogI::enableSource() {
   _w->_rvectorGroup->setEnabled(true);
   _w->_svectorGroup->setEnabled(false);
@@ -169,22 +190,25 @@ void KstVectorDialogI::enableGenerate() {
 
 
 void KstVectorDialogI::updateCompletion() {
-  QString current_text = _w->Field->currentText();
+  QStringList list;
+  QString currentText = _w->Field->currentText();
+
   _w->Field->clear();
 
-  // update filename list and ll axes combo boxes
   KST::dataSourceList.lock().readLock();
   KstDataSourcePtr ds = *KST::dataSourceList.findReusableFileName(_w->FileName->url());
   KST::dataSourceList.lock().unlock();
 
   delete _configWidget;
   _configWidget = 0L;
-  QStringList list;
+  _hierarchy = false;
+
   if (ds) {
     ds->readLock();
     list = ds->fieldList();
     _w->Field->setEditable(!ds->fieldListIsComplete());
     _configWidget = ds->configWidget();
+    _hierarchy = ds->supportsHierarchy();
     ds->unlock();
     _w->Field->setEnabled(true);
     _w->_connect->hide();
@@ -211,13 +235,14 @@ void KstVectorDialogI::updateCompletion() {
     _w->Field->setEditable(!complete);
     _w->Field->setEnabled(!list.isEmpty());
     if (!list.isEmpty() && !type.isEmpty()) {
+      _hierarchy = KstDataSource::supportsHierarchy(u, type);
       _configWidget = KstDataSource::configWidgetForSource(u, type);
     }
     _w->_kstDataRange->setAllowTime(KstDataSource::supportsTime(u, type));
   }
 
   _w->_configure->setEnabled(_configWidget);
-
+  _w->_pushButtonHierarchy->setEnabled(_hierarchy);
   _fieldCompletion = _w->Field->completionObject();
 
   _w->Field->insertStringList(list);
@@ -225,8 +250,8 @@ void KstVectorDialogI::updateCompletion() {
     _fieldCompletion->clear();
     _fieldCompletion->insertItems(list);
   }
-  if (!current_text.isEmpty() && (list.contains(current_text) || _w->Field->editable())) {
-    _w->Field->setCurrentText(current_text);
+  if (!currentText.isEmpty() && (list.contains(currentText) || _w->Field->editable())) {
+    _w->Field->setCurrentText(currentText);
   }
   _ok->setEnabled(_w->Field->isEnabled() || _editMultipleMode);
 }
