@@ -231,19 +231,6 @@ int KstViewBox::yRound() const {
 }
 
 
-void KstViewBox::setCornerStyle(Qt::PenJoinStyle style) {
-  if (_cornerStyle != style) {
-    setDirty();
-    _cornerStyle = style;
-  }
-}
-
-
-Qt::PenJoinStyle KstViewBox::cornerStyle() const {
-  return _cornerStyle;
-}
-
-
 bool KstViewBox::transparent() const {
   return KstViewObject::transparent();
 }
