@@ -52,6 +52,7 @@ class KstViewLegend : public KstBorderedViewObject {
     static KstViewLegendList globalLegendList();
 
     virtual KstViewObject* copyObjectQuietly(KstViewObject &parent, const QString& name = QString::null) const;
+    virtual KstViewObject* copyObjectQuietly() const;
     void setTitle(const QString& title);
     const QString& title() const;
     void reparseTitle();
@@ -73,20 +74,22 @@ class KstViewLegend : public KstBorderedViewObject {
     void paintSelf(KstPainter& p, const QRegion& bounds);
     void resize(const QSize&);
     QRegion clipRegion();
-    
-    QWidget *configWidget();
+
+    QWidget *configWidget(QWidget *parent);
 
     // handle custom widget, if any: is called by KstEditViewObjectDialogI
     bool fillConfigWidget(QWidget *w, bool isNew) const;
-    bool readConfigWidget(QWidget *w);
+    bool readConfigWidget(QWidget *w, bool editMultipleMode);
     void connectConfigWidget(QWidget *parent, QWidget *w) const;
-    
+    void populateEditMultiple(QWidget *w);
+    bool supportsDefaults();
+
     void addCurve(KstBaseCurvePtr curve);
     void removeCurve(KstBaseCurvePtr curve);
     void clear();
 
     void setCurveList(Kst2DPlotPtr plot);
-    
+
     bool vertical() const;
     void setVertical(bool vertical);
 
@@ -95,7 +98,6 @@ class KstViewLegend : public KstBorderedViewObject {
 
     KstBaseCurveList& curves();
 
-    void invalidateClipRegion();
     bool trackContents() const;
     void setTrackContents(bool track);
     void adjustSizeForText(const QRect& w);
@@ -117,7 +119,6 @@ class KstViewLegend : public KstBorderedViewObject {
 
     double _rotation;
     QString _fontName;
-//    KstScalarList _scalarsUsed;
     KstScalarMap _scalarsUsed;
     KstStringMap _stringsUsed;
     KstVectorMap _vectorsUsed;
@@ -131,7 +132,6 @@ class KstViewLegend : public KstBorderedViewObject {
     int _legendMargin;
     KstBackBuffer _backBuffer;
     KstBaseCurveList _curves;
-    QRegion _myClipMask;
     bool _trackContents;
 
     QString _title;
@@ -141,4 +141,4 @@ class KstViewLegend : public KstBorderedViewObject {
 typedef KstSharedPtr<KstViewLegend> KstViewLegendPtr;
 
 #endif
-// vim: ts=2 sw=2 et
+
