@@ -1037,16 +1037,22 @@ KstViewObjectPtr KstViewObject::findChild(const QString& name, bool recursive) {
 }
 
 
-KstViewObjectPtr KstViewObject::findDeepestChild(const QPoint& pos, bool borderForTransparent) {
+KstViewObjectPtr KstViewObject::findDeepestChild(const QPoint& pos, bool borderForTransparent, bool stopAtGroup) {
   KstViewObjectPtr obj = findChild(pos, borderForTransparent);
   if (obj) {
-    KstViewObjectPtr c;
-    do {
-      c = obj->findDeepestChild(pos, borderForTransparent);
-      if (c) {
-        obj = c;
-      }
-    } while (c);
+    if (!stopAtGroup || obj->type().compare("PlotGroup") != 0) {
+      KstViewObjectPtr c;
+
+      do {
+        c = obj->findDeepestChild(pos, borderForTransparent, stopAtGroup);
+        if (c) {
+          obj = c;
+          if (stopAtGroup && obj->type().compare("PlotGroup") == 0) {
+            break;
+          }
+        }
+      } while (c);
+    }
   }
   return obj;
 }
@@ -1101,6 +1107,7 @@ KstViewObjectPtr KstViewObject::findChild(const QPoint& pos, bool borderForTrans
 
 KstViewObjectPtr KstViewObject::findDeepestChild(const QRect& rect) {
   KstViewObjectPtr obj = findChild(rect);
+
   if (obj) {
     KstViewObjectPtr c;
     do {
@@ -1123,7 +1130,7 @@ KstViewObjectPtr KstViewObject::findChild(const QRect& rect) {
 
   KstViewObjectList::Iterator i = _children.end();
   for (--i; ; --i) {
-    if ((*i)->_container && (*i)->surroundingGeometry().contains(rect)) {
+    if ((*i)->isContainer() && (*i)->surroundingGeometry().contains(rect)) {
       obj = *i;
       break;
     }
