@@ -131,7 +131,7 @@ class KST_EXPORT KstViewObject : public KstObject {
     // split it into two methods eventually.  The bool is for toplevelview so
     // that it can do resize rect on transparent objects
     KstViewObjectPtr findChild(const QPoint& pos, bool borderForTransparent = false);
-    KstViewObjectPtr findDeepestChild(const QPoint& pos, bool borderForTransparent = false);
+    KstViewObjectPtr findDeepestChild(const QPoint& pos, bool borderForTransparent = false, bool stopAtGroup = false);
     KstViewObjectPtr findChild(const QString& name, bool recursive = true);
     bool contains(const KstViewObjectPtr child) const;
     template<class T> KstObjectList<KstSharedPtr<T> > findChildrenType(bool recursive = false);
