@@ -18,15 +18,15 @@
 #ifndef ENODES_H
 #define ENODES_H
 
+#include "plugin.h"
+#include "kstbasicplugin.h"
 #include "kststring.h"
 #include "kstvector.h"
 #include "kst_export.h"
 
-class Plugin;
-
-#define EQ_FALSE 0.0
-#define EQ_TRUE  1.0
-
+#define EQ_FALSE        0.0
+#define EQ_TRUE         1.0
+#define EQ_INDEX_ERROR -424242
 namespace Equation {
 
   /* Global lock for the parser */
@@ -133,16 +133,20 @@ namespace Equation {
       char *_name;
       ArgumentList *_args;
       void *_f;
-      KstSharedPtr<Plugin> _plugin;
+      KstPluginPtr _cStylePlugin;
+      KstBasicPluginPtr _dataObjectPlugin;
 
     private:
-      double evaluatePlugin(Context *ctx);
+      KstObject::UpdateType updateCStylePlugin(Context *ctx);
+      KstObject::UpdateType updateDataObjectPlugin(int counter, Context *ctx);
+      double evaluateCStylePlugin(Context *ctx);
+      double evaluateDataObjectPlugin(Context *ctx);
       unsigned _inputScalarCnt, _inputVectorCnt, _inputStringCnt;
       unsigned _inPid, _outputScalarCnt, _outputVectorCnt, _outputStringCnt;
       int *_inArrayLens, *_outArrayLens;
       double *_inScalars, *_outScalars;
       double **_inVectors, **_outVectors;
-      int _outputIndex; // -1 = scalar 0, -424242 = none/error, +0...n = vector
+      int _outputIndex; // -1 = scalar 0, EQ_INDEX_ERROR = none/error, +0...n = vector
       void *_localData;
       int _argCount;
   };
@@ -279,4 +283,3 @@ CreateNode(NotEqualTo)
 
 #endif
 
-// vim: ts=2 sw=2 et
