@@ -15,10 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-/** A class for handling equations for kst
- *@author C. Barth Netterfield
- */
-
 #include <assert.h>
 #include <math.h>
 #include <stdlib.h>
@@ -30,12 +26,13 @@
 #include <klocale.h>
 
 // application specific includes
+#include "defaultprimitivenames.h"
 #include "dialoglauncher.h"
 #include "enodes.h"
 #include "eparse-eh.h"
 #include "kstdatacollection.h"
-#include "defaultprimitivenames.h"
 #include "kstdebug.h"
+#include "kstdefaultnames.h"
 #include "kstequation.h"
 #include "kstsvector.h"
 
@@ -76,12 +73,12 @@ KstEquation::KstEquation(const QString& in_tag, const QString& equation, KstVect
 
 KstEquation::KstEquation(const QDomElement &e)
 : KstDataObject(e) {
-  QString in_tag, equation;
-
-  int ns = -1;
-  double x0 = 0.0, x1 = 1.0;
   KstObjectTag xvtag = KstObjectTag::invalidTag;
+  QString in_tag, equation;
+  double x0 = 0.0;
+  double x1 = 1.0;
   bool haveVector = false;
+  int ns = -1;
 
   _doInterp = false;
 
@@ -117,7 +114,7 @@ KstEquation::KstEquation(const QDomElement &e)
       ns = 2;
     }
     if (x0 == x1) {
-      x1 = x0 + 2;
+      x1 = x0 + 2.0;
     }
 
     KstObjectTag vtag = KstObjectTag::invalidTag;
@@ -143,16 +140,25 @@ KstEquation::~KstEquation() {
   _pe = 0L;
 }
 
+
 void KstEquation::commonConstructor(const QString& in_tag, const QString& in_equation) {
   _ns = 2;
   _pe = 0L;
   _typeString = i18n("Equation");
   _type = "Equation";
-  KstObject::setTagName(KstObjectTag::fromString(in_tag));
+
+  QString tagName;
+  if (in_tag.isEmpty()) {
+    tagName = KST::suggestEQName(in_equation);
+  } else {
+    tagName = in_tag;
+  }
+
+  KstObject::setTagName(KstObjectTag::fromString(tagName));
 
   KstVectorPtr xv = new KstVector(KstObjectTag("xsv", tag()), 2, this);
   _xOutVector = _outputVectors.insert(XOUTVECTOR, xv);
-    
+
   KstVectorPtr yv = new KstVector(KstObjectTag("sv", tag()), 2, this);
   _yOutVector = _outputVectors.insert(YOUTVECTOR, yv);
 
@@ -234,7 +240,7 @@ KstObject::UpdateType KstEquation::update(int update_counter) {
 }
 
 
-void KstEquation::reParse() {
+void KstEquation::reparse() {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
 
   if (!_equation.isEmpty()) {
@@ -244,8 +250,15 @@ void KstEquation::reParse() {
     int rc = yyparse();
     Equation::Node *en = static_cast<Equation::Node*>(ParsedEquation);
     if (rc == 0 && en) {
-      if (en->takeVectorsAndScalars(VectorsUsed, ScalarsUsed)) {
+      if (en->takeVectorsAndScalars(_vectorsUsed, _scalarsUsed)) {
         _equation = en->text();
+
+        KstStringMap sm;
+        _vectorsUsed.clear();
+        _scalarsUsed.clear();
+
+        en->collectObjects(_vectorsUsed, _scalarsUsed, sm);
+
         setupConnections();
       } else {
         kstdWarning() << "Equation [" << _equation << "] failed to find its vectors/scalars when re-parsing." << endl;
@@ -273,7 +286,7 @@ void KstEquation::save(QTextStream &ts, const QString& indent) {
     Equation::Node *en = static_cast<Equation::Node*>(ParsedEquation);
     if (rc == 0 && en) {
       QString etext;
-      if (en->takeVectorsAndScalars(VectorsUsed, ScalarsUsed)) {
+      if (en->takeVectorsAndScalars(_vectorsUsed, _scalarsUsed)) {
         etext = en->text();
       } else {
         kstdWarning() << "Equation [" << _equation << "] failed to find its vectors/scalars when saving. The resulting Kst file may have issues." << endl;
@@ -301,8 +314,8 @@ void KstEquation::setEquation(const QString& in_fn) {
   _equation = in_fn;
   setRecursed(false);
 
-  VectorsUsed.clear();
-  ScalarsUsed.clear();
+  _vectorsUsed.clear();
+  _scalarsUsed.clear();
 
   _ns = 2; // reset the updating
   delete _pe;
@@ -321,7 +334,7 @@ void KstEquation::setEquation(const QString& in_fn) {
       Equation::FoldVisitor vis(&ctx, &_pe);
       KstStringMap sm;
 
-      if (_pe->collectObjects(VectorsUsed, ScalarsUsed, sm)) {
+      if (_pe->collectObjects(_vectorsUsed, _scalarsUsed, sm)) {
         setupConnections();
         _pe->update(-1, &ctx);
       } else {
@@ -392,7 +405,7 @@ bool KstEquation::FillY(bool force, bool usedUpdated) {
   // determine value of Interp
   if (_doInterp) {
     ns = (*_xInVector)->length();
-    for (KstVectorMap::ConstIterator i = VectorsUsed.begin(); i != VectorsUsed.end(); ++i) {
+    for (KstVectorMap::ConstIterator i = _vectorsUsed.begin(); i != _vectorsUsed.end(); ++i) {
       if (i.data()->length() > ns) {
         ns = i.data()->length();
       }
@@ -429,7 +442,7 @@ bool KstEquation::FillY(bool force, bool usedUpdated) {
     v_shift = (*_xInVector)->numShift();
     v_new = (*_xInVector)->numNew();
 
-    for (KstVectorMap::ConstIterator i = VectorsUsed.begin(); i != VectorsUsed.end(); ++i) {
+    for (KstVectorMap::ConstIterator i = _vectorsUsed.begin(); i != _vectorsUsed.end(); ++i) {
       if (v_shift != i.data()->numShift()) {
         v_shift = _ns;
       }
@@ -489,7 +502,7 @@ bool KstEquation::FillY(bool force, bool usedUpdated) {
     if (_pe && rc == 0) {
       Equation::FoldVisitor vis(&ctx, &_pe);
       KstStringMap sm;
-      _pe->collectObjects(VectorsUsed, ScalarsUsed, sm);
+      _pe->collectObjects(_vectorsUsed, _scalarsUsed, sm);
       setupConnections();
       ParsedEquation = 0L;
     } else {
@@ -510,7 +523,7 @@ bool KstEquation::FillY(bool force, bool usedUpdated) {
   if (!(*_xOutVector)->resize(iv->length())) {
     // FIXME: handle error?
     unlockInputsAndOutputs();
-    return false;    
+    return false;
   }
 
   unlockInputsAndOutputs();
@@ -545,22 +558,21 @@ KstDataObjectPtr KstEquation::makeDuplicate(KstDataObjectDataObjectMap& duplicat
 
 
 void KstEquation::replaceDependency(KstDataObjectPtr oldObject, KstDataObjectPtr newObject) {
-  
   QString newExp = _equation;
-  
+
   // replace all occurences of outputVectors, outputScalars from oldObject
   for (KstVectorMap::Iterator j = oldObject->outputVectors().begin(); j != oldObject->outputVectors().end(); ++j) {
     QString oldTag = j.data()->tagName();
     QString newTag = ((newObject->outputVectors())[j.key()])->tagName();
     newExp = newExp.replace("[" + oldTag + "]", "[" + newTag + "]");
   }
-  
+
   for (KstScalarMap::Iterator j = oldObject->outputScalars().begin(); j != oldObject->outputScalars().end(); ++j) {
     QString oldTag = j.data()->tagName();
     QString newTag = ((newObject->outputScalars())[j.key()])->tagName();
     newExp = newExp.replace("[" + oldTag + "]", "[" + newTag + "]");
   }
-  
+
   // and dependencies on matrix stats (there won't be matrices themselves in the expression)
   for (KstMatrixMap::Iterator j = oldObject->outputMatrices().begin(); j != oldObject->outputMatrices().end(); ++j) {
     QDictIterator<KstScalar> scalarDictIter(j.data()->scalars());
@@ -570,7 +582,7 @@ void KstEquation::replaceDependency(KstDataObjectPtr oldObject, KstDataObjectPtr
       newExp = newExp.replace("[" + oldTag + "]", "[" + newTag + "]"); 
     }
   }
-  
+
   // only replace _inputVectors
   for (KstVectorMap::Iterator j = oldObject->outputVectors().begin(); j != oldObject->outputVectors().end(); ++j) {
     for (KstVectorMap::Iterator k = _inputVectors.begin(); k != _inputVectors.end(); ++k) {
@@ -587,7 +599,7 @@ void KstEquation::replaceDependency(KstDataObjectPtr oldObject, KstDataObjectPtr
       newExp = newExp.replace("[" + oldTag + "]", "[" + newTag + "]"); 
     }
   }
-  
+
   setEquation(newExp);
 }
 
@@ -595,10 +607,10 @@ void KstEquation::replaceDependency(KstDataObjectPtr oldObject, KstDataObjectPtr
 void KstEquation::replaceDependency(KstVectorPtr oldVector, KstVectorPtr newVector) {
   QString oldTag = oldVector->tagName();
   QString newTag = newVector->tagName();
-  
+
   // replace all occurences of oldTag with newTag
-  QString newExp = _equation.replace("["+oldTag+"]", "["+newTag+"]");
-  
+  QString newExp = _equation.replace("[" + oldTag + "]", "[" + newTag + "]");
+
   // also replace all occurences of scalar stats for the oldVector
   QDictIterator<KstScalar> scalarDictIter(oldVector->scalars());
   for (; scalarDictIter.current(); ++scalarDictIter) {
@@ -606,23 +618,22 @@ void KstEquation::replaceDependency(KstVectorPtr oldVector, KstVectorPtr newVect
     QString newTag = ((newVector->scalars())[scalarDictIter.currentKey()])->tagName();
     newExp = newExp.replace("[" + oldTag + "]", "[" + newTag + "]"); 
   }
-  
+
   setEquation(newExp);
 
   // do the dependency replacements for _inputVectors, but don't call parent function as it
   // replaces _inputScalars 
   for (KstVectorMap::Iterator j = _inputVectors.begin(); j != _inputVectors.end(); ++j) {
     if (j.data() == oldVector) {
-      _inputVectors[j.key()] = newVector;  
-    }      
+      _inputVectors[j.key()] = newVector;
+    }
   }
 }
 
 
 void KstEquation::replaceDependency(KstMatrixPtr oldMatrix, KstMatrixPtr newMatrix) {
-
   QString newExp = _equation;
-  
+
   // also replace all occurences of scalar stats for the oldMatrix
   QDictIterator<KstScalar> scalarDictIter(oldMatrix->scalars());
   for (; scalarDictIter.current(); ++scalarDictIter) {
@@ -630,16 +641,15 @@ void KstEquation::replaceDependency(KstMatrixPtr oldMatrix, KstMatrixPtr newMatr
     QString newTag = ((newMatrix->scalars())[scalarDictIter.currentKey()])->tagName();
     newExp = newExp.replace("[" + oldTag + "]", "[" + newTag + "]"); 
   }
-  
+
   setEquation(newExp);
 }
 
 
 bool KstEquation::uses(KstObjectPtr p) const {
-  
-  // check VectorsUsed in addition to _input*'s
+  // check _vectorsUsed in addition to _input*'s
   if (KstVectorPtr vect = kst_cast<KstVector>(p)) {
-    for (KstVectorMap::ConstIterator j = VectorsUsed.begin(); j != VectorsUsed.end(); ++j) {
+    for (KstVectorMap::ConstIterator j = _vectorsUsed.begin(); j != _vectorsUsed.end(); ++j) {
       if (j.data() == vect) {
         return true;
       }
@@ -647,7 +657,7 @@ bool KstEquation::uses(KstObjectPtr p) const {
   } else if (KstDataObjectPtr obj = kst_cast<KstDataObject>(p) ) {
     // check all connections from this expression to p
     for (KstVectorMap::Iterator j = obj->outputVectors().begin(); j != obj->outputVectors().end(); ++j) {
-      for (KstVectorMap::ConstIterator k = VectorsUsed.begin(); k != VectorsUsed.end(); ++k) {
+      for (KstVectorMap::ConstIterator k = _vectorsUsed.begin(); k != _vectorsUsed.end(); ++k) {
         if (j.data() == k.data()) {
           return true;
         }
@@ -659,15 +669,14 @@ bool KstEquation::uses(KstObjectPtr p) const {
 
 
 void KstEquation::setupConnections() {
-  for (KstScalarMap::iterator i = ScalarsUsed.begin(); i != ScalarsUsed.end(); ++i) {
-    disconnect(i.data(), SIGNAL(tagChanged()), this, SLOT(reParse()));
-    connect(i.data(), SIGNAL(tagChanged()), this, SLOT(reParse()));
-  } 
-  for (KstVectorMap::iterator i = VectorsUsed.begin(); i != VectorsUsed.end(); ++i) {
-    disconnect(i.data(), SIGNAL(tagChanged()), this, SLOT(reParse()));
-    connect(i.data(), SIGNAL(tagChanged()), this, SLOT(reParse()));
-  } 
+  for (KstScalarMap::iterator i = _scalarsUsed.begin(); i != _scalarsUsed.end(); ++i) {
+    disconnect(i.data(), SIGNAL(tagChanged()), this, SLOT(reparse()));
+    connect(i.data(), SIGNAL(tagChanged()), this, SLOT(reparse()));
+  }
+  for (KstVectorMap::iterator i = _vectorsUsed.begin(); i != _vectorsUsed.end(); ++i) {
+    disconnect(i.data(), SIGNAL(tagChanged()), this, SLOT(reparse()));
+    connect(i.data(), SIGNAL(tagChanged()), this, SLOT(reparse()));
+  }
 }
 
 #include "kstequation.moc"
-// vim: ts=2 sw=2 et
