@@ -19,8 +19,10 @@
 #include "dialoglauncher.h"
 #include "kstdatacollection.h"
 #include "kstdebug.h"
+#include "kstdefaultnames.h"
 #include "kstimage.h"
 #include "kstmath.h"
+#include "kstsettings.h"
 
 #include <klocale.h>
 
@@ -35,8 +37,11 @@ static const QString& THEMATRIX = KGlobal::staticQString("THEMATRIX");
 KstImage::KstImage(const QDomElement& e) : KstBaseCurve(e){
   QString in_matrixName, in_paletteName;
   bool in_hasColorMap = false, in_hasContourMap = false;
-  double in_zLower = 0, in_zUpper = 0;
+  double in_zLower = 0.0;
+  double in_zUpper = 0.0;
+
   _autoThreshold = false;
+  _pal = 0L;
 
   /* parse the DOM tree */
   QDomNode n = e.firstChild();
@@ -106,9 +111,13 @@ KstImage::KstImage(const QDomElement& e) : KstBaseCurve(e){
 
 //constructor for colormap only
 KstImage::KstImage(const QString &in_tag, KstMatrixPtr in_matrix, double lowerZ, double upperZ, bool autoThreshold, KPalette* pal) : KstBaseCurve(){
-
   _inputMatrices[THEMATRIX] = in_matrix;
-  setTagName(KstObjectTag(in_tag, KstObjectTag::globalTagContext));  // FIXME: always top-level?
+  if (in_tag == QString::null) {
+    QString tag_name = KST::suggestImageName(KstObjectTag(in_matrix->tagName()));
+    setTagName(KstObjectTag(in_matrix->tagName(), KstObjectTag::globalTagContext)); 
+  } else {
+    setTagName(KstObjectTag(in_tag, KstObjectTag::globalTagContext));
+  }
   _typeString = i18n("Image");
   _type = "Image";
   _zLower = lowerZ;
@@ -126,7 +135,12 @@ KstImage::KstImage(const QString &in_tag, KstMatrixPtr in_matrix, double lowerZ,
 //constructor for contour map only
 KstImage::KstImage(const QString &in_tag, KstMatrixPtr in_matrix, int numContours, const QColor& contourColor, int contourWeight) : KstBaseCurve(){
   _inputMatrices[THEMATRIX] = in_matrix;
-  setTagName(KstObjectTag(in_tag, KstObjectTag::globalTagContext));  // FIXME: always top-level?
+  if (in_tag == QString::null) {
+    QString tag_name = KST::suggestImageName(KstObjectTag(in_matrix->tagName()));
+    setTagName(KstObjectTag(tag_name, KstObjectTag::globalTagContext)); 
+  } else {
+    setTagName(KstObjectTag(in_tag, KstObjectTag::globalTagContext));
+  }
   _typeString = i18n("Image");
   _type = "Image";
   _contourColor = contourColor;
@@ -137,7 +151,6 @@ KstImage::KstImage(const QString &in_tag, KstMatrixPtr in_matrix, int numContour
 
   setColorDefaults();
   setDirty();
-
 }
 
 
@@ -152,7 +165,12 @@ KstImage::KstImage(const QString &in_tag,
                    const QColor& contourColor,
                    int contourWeight) {
   _inputMatrices[THEMATRIX] = in_matrix;
-  setTagName(KstObjectTag(in_tag, KstObjectTag::globalTagContext));  // FIXME: always top-level?
+  if (in_tag == QString::null) {
+    QString tag_name = KST::suggestImageName(KstObjectTag(in_matrix->tagName()));
+    setTagName(KstObjectTag(tag_name, KstObjectTag::globalTagContext)); 
+  } else {
+    setTagName(KstObjectTag(in_tag, KstObjectTag::globalTagContext));
+  }
   _typeString = i18n("Image");
   _type = "Image";
   _contourColor = contourColor;
@@ -212,24 +230,24 @@ KstObject::UpdateType KstImage::update(int update_counter) {
   if (_inputMatrices.contains(THEMATRIX)) {
     KstMatrixPtr mp = _inputMatrices[THEMATRIX];
     bool updated = UPDATE == mp->update(update_counter);
-  
+
     if (updated || force) {
       // stats
       NS = mp->sampleCount();
-      MinX = mp->minX();
+      _minX = mp->minX();
       int xNumSteps = mp->xNumSteps();
       double xStepSize = mp->xStepSize();
-      MaxX = xNumSteps*xStepSize + MinX;
-      MinY = mp->minY();
+      _maxX = xNumSteps*xStepSize + _minX;
+      _minY = mp->minY();
       int yNumSteps = mp->yNumSteps();
       double yStepSize = mp->yStepSize();
-      MaxY = yNumSteps*yStepSize + MinY;
-      _ns_maxx = MaxX;
-      _ns_minx = MinX;
-      _ns_maxy = MaxY;
-      _ns_miny = MinY;
-      MinPosY = MinY > 0 ? MinY : yStepSize;
-      MinPosX = MinX > 0 ? MinX : xStepSize;
+      _maxY = yNumSteps*yStepSize + _minY;
+      _ns_maxx = _maxX;
+      _ns_minx = _minX;
+      _ns_maxy = _maxY;
+      _ns_miny = _minY;
+      _minPosY = _minY > 0.0 ? _minY : yStepSize;
+      _minPosX = _minX > 0.0 ? _minX : xStepSize;
 
       //recalculate the thresholds if necessary
       if (_autoThreshold) {
@@ -269,24 +287,28 @@ QString KstImage::propertyString() const {
 
 
 QColor KstImage::getMappedColor(double x, double y) {
-  bool ok;
-  
-  double z = _inputMatrices[THEMATRIX]->value(x, y, &ok);
-  if (ok) {
-    int index;
-    if (_zUpper - _zLower != 0) {
-      if (z > _zUpper) {
-        index = _pal->nrColors() - 1;
-      } else if (z < _zLower) {
-        index = 0;
-      } else {
+  if (_pal) {
+    bool ok;
+    double z;
+
+    z = _inputMatrices[THEMATRIX]->value(x, y, &ok);
+    if (ok) {
+      int index;
+      if (_zUpper - _zLower != 0) {
+        if (z > _zUpper) {
+          index = _pal->nrColors() - 1;
+        } else if (z < _zLower) {
+          index = 0;
+        } else {
           index = (int)floor(((z - _zLower) * (_pal->nrColors() - 1)) / (_zUpper - _zLower));
+        }
+      } else {
+        index = 0;
       }
-    } else {
-      index = 0;
+      return _pal->color(index);
     }
-    return _pal->color(index);
   }
+
   return QColor();
 }
 
@@ -294,6 +316,18 @@ QColor KstImage::getMappedColor(double x, double y) {
 void KstImage::setPalette(KPalette* pal) {
   delete _pal;
   _pal = pal;
+  setDirty();
+}
+
+
+void KstImage::setPalette(const QString& strPalette) {
+  KPalette* pal = new KPalette(strPalette);
+
+  if (pal) {
+    delete _pal;
+    _pal = pal;
+    setDirty();
+  }
 }
 
 
@@ -318,8 +352,16 @@ void KstImage::setLowerThreshold(double z) {
   _zLower = z;
 }
 
+
+void KstImage::setThresholdToMinMax() {
+  setLowerThreshold(matrix()->minValue());
+  setUpperThreshold(matrix()->maxValue());
+  setAutoThreshold(false);
+}
+
+
 void KstImage::setThresholdToSpikeInsensitive(double per) {
-  if (per==0) {
+  if (per == 0.0) {
     setAutoThreshold(true);
   } else {
     matrix()->writeLock();
@@ -474,7 +516,7 @@ KstDataObjectPtr KstImage::makeDuplicate(KstDataObjectDataObjectMap& duplicatedM
   if (_pal) {
     newPalette = new KPalette(*_pal);
   }
-  
+
   QString name(tagName() + '\'');
   while (KstData::self()->dataTagNameNotUnique(name, false)) {
     name += '\'';
@@ -496,16 +538,22 @@ QString KstImage::matrixTag() const {
 
 KstMatrixPtr KstImage::matrix() const {
   if (_inputMatrices.contains(THEMATRIX)) {
-    return _inputMatrices[THEMATRIX]; 
+    return _inputMatrices[THEMATRIX];
   } else {
     return NULL;
   }
 }
 
 
+void KstImage::setMatrix(const KstMatrixPtr& matrix) {
+  _inputMatrices[THEMATRIX] = matrix;
+  setDirty();
+}
+
+
 QString KstImage::xLabel() const {
   if (_inputMatrices.contains(THEMATRIX)) {
-    return _inputMatrices[THEMATRIX]->xLabel();  
+    return _inputMatrices[THEMATRIX]->xLabel();
   } else {
     return QString();
   }
@@ -531,7 +579,7 @@ QString KstImage::topLabel() const {
 
 
 KstCurveType KstImage::curveType() const {
-  return KST_IMAGE;  
+  return KST_IMAGE;
 }
 
 
@@ -543,37 +591,39 @@ KstDataObjectPtr KstImage::providerDataObject() const {
   if (mp) {
     mp->readLock();
     provider = kst_cast<KstDataObject>(mp->provider());
-    mp->unlock();  
+    mp->unlock();
   }
   return provider;
 }
 
 
-double KstImage::distanceToPoint(double xpos, double dx, double ypos) const {
-  Q_UNUSED(dx)
-  // dx is not relevant for double clicks on images - clicks must be inside the image
-  if (xpos <= MaxX && xpos >= MinX && ypos <= MaxY && ypos >= MinY) {
-    return 0;
+double KstImage::distanceToPoint(double xpos, double ypos, double distanceMax, const KstCurveRenderContext& context) {
+  Q_UNUSED(context)
+  Q_UNUSED(distanceMax);
+
+  double distance = -1.0;
+
+  if (xpos <= _maxX && xpos >= _minX && ypos <= _maxY && ypos >= _minY) {
+    distance = 0.0;
   }
-  return 1.0E300;
+
+  return distance;
 }
 
 
 void KstImage::paint(const KstCurveRenderContext& context) {
+  KstImagePtr image = this;
+  KstPainter* p = context.p;
+  QColor invalid = context.backgroundColor;
   double Lx = context.Lx, Hx = context.Hx, Ly = context.Ly, Hy = context.Hy;
   double m_X = context.m_X, m_Y = context.m_Y, b_X = context.b_X, b_Y = context.b_Y;
   double x_max = context.x_max, y_max = context.y_max, x_min = context.x_min, y_min = context.y_min;
-  bool xLog = context.xLog, yLog = context.yLog;
   double xLogBase = context.xLogBase;
   double yLogBase = context.yLogBase;
-  KstPainter* p = context.p;
-  QColor invalid = context.backgroundColor;
-  
   double x, y, width, height;
-  double img_Lx_pix = 0, img_Ly_pix = 0, img_Hx_pix = 0, img_Hy_pix = 0;
+  double img_Lx_pix = 0.0, img_Ly_pix = 0.0, img_Hx_pix = 0.0, img_Hy_pix = 0.0;
+  bool xLog = context.xLog, yLog = context.yLog;
 
-  KstImagePtr image = this;
-  
   if (_inputMatrices.contains(THEMATRIX)) { // don't paint if we have no matrix
     image->matrixDimensions(x, y, width, height);
 
@@ -625,7 +675,7 @@ void KstImage::paint(const KstCurveRenderContext& context) {
           img_Ly_pix = (y + height) * m_Y + b_Y;
         }
       }
-  
+
       // color map
       QColor thisPixel;
       if (image->hasColorMap()) {
@@ -689,7 +739,7 @@ void KstImage::paint(const KstCurveRenderContext& context) {
               double zTL, zTR, zBL, zBR;
               double new_x_small = (i - b_X) / m_X, new_y_small = (j + 1 - b_Y) / m_Y;
               double new_x_large = (i + CONTOUR_STEP - b_X) / m_X, new_y_large = (j+1+CONTOUR_STEP - b_Y) / m_Y;
-    
+
               if (xLog) {
                 new_x_small = pow(xLogBase, new_x_small);
                 new_x_large = pow(xLogBase, new_x_large);
@@ -698,17 +748,17 @@ void KstImage::paint(const KstCurveRenderContext& context) {
                 new_y_small = pow(yLogBase, new_y_small);
                 new_y_large = pow(yLogBase, new_y_large);
               }
-    
+
               zTL = mp->value(new_x_small, new_y_small, 0L);
               zTR = mp->value(new_x_large, new_y_small, 0L);
               zBL = mp->value(new_x_small, new_y_large, 0L);
               zBR = mp->value(new_x_large, new_y_large, 0L);
-    
+
               // determine the lines to draw
               int numPoints = 0;
               bool passTop = false, passBottom = false, passLeft = false, passRight = false;
               QPoint topPoint, bottomPoint, leftPoint, rightPoint;
-    
+
               // passes through the top
               if (hasPrevBottom) {
                 topPoint = lastPoint;
@@ -721,7 +771,7 @@ void KstImage::paint(const KstCurveRenderContext& context) {
                 topPoint.setY(j);
               }
               hasPrevBottom = false;
-    
+
               // passes through the bottom
               if ((lineK < zBR && lineK > zBL) || (lineK < zBL && lineK > zBR)) {
                 ++numPoints;
@@ -733,7 +783,7 @@ void KstImage::paint(const KstCurveRenderContext& context) {
                   hasPrevBottom = true;
                 }
               }
-    
+
               // passes through the left
               if ((lineK < zBL && lineK > zTL) || (lineK < zTL && lineK > zBL)) {
                 ++numPoints;
@@ -749,7 +799,7 @@ void KstImage::paint(const KstCurveRenderContext& context) {
                 rightPoint.setY(int(((lineK - zTR)*CONTOUR_STEP + (zBR - zTR)*j) / (zBR - zTR)));
                 rightPoint.setX(i + CONTOUR_STEP);
               }
-    
+
               if (numPoints == 4) {
                 // draw a cross
                 p->drawLine(topPoint, bottomPoint);
@@ -773,7 +823,7 @@ void KstImage::paint(const KstCurveRenderContext& context) {
                 // two points - connect them
                 QPoint point1, point2;
                 bool true1 = false;
-    
+
                 if (passTop) {
                   point1 = topPoint;
                   true1 = true;
@@ -809,19 +859,20 @@ void KstImage::paint(const KstCurveRenderContext& context) {
 
 void KstImage::yRange(double xFrom, double xTo, double* yMin, double* yMax) {
   if (!yMin || !yMax) {
-    return;  
-  }
-  // if x range overlaps with image x range, just return image y range
-  if ((xFrom <= MinX && xTo >= MinX) ||
-      (xTo >= MaxX && xFrom <= MaxX) ||
-      (xFrom > MinX && xFrom < MaxX) ||
-      (xTo > MinX && xTo < MaxX)) {
-    *yMin = MinY;
-    *yMax = MaxY;
     return;
   }
-  *yMin = 0;
-  *yMax = 0;
+  // if x range overlaps with image x range, just return image y range
+  if ((xFrom <= _minX && xTo >= _minX) ||
+      (xTo >= _maxX && xFrom <= _maxX) ||
+      (xFrom > _minX && xFrom < _maxX) ||
+      (xTo > _minX && xTo < _maxX)) {
+    *yMin = _minY;
+    *yMax = _maxY;
+    return;
+  }
+  *yMin = 0.0;
+  *yMax = 0.0;
+
   return;
 }
 
@@ -829,6 +880,7 @@ void KstImage::yRange(double xFrom, double xTo, double* yMin, double* yMax) {
 void KstImage::paintLegendSymbol(KstPainter *p, const QRect& bound) {
   if (hasColorMap() && _pal) {
     int l = bound.left(), r = bound.right(), t = bound.top(), b = bound.bottom();
+
     // draw the color palette
     for (int i = l; i <= r; i++) {
       int index = (int)floor(((i - l) * (_pal->nrColors() - 1)) / (r - l));
@@ -843,6 +895,3 @@ void KstImage::paintLegendSymbol(KstPainter *p, const QRect& bound) {
     p->drawRect(bound.left(), bound.top(), bound.width(), bound.height());
   }
 }
-
-
-// vim: ts=2 sw=2 et
