@@ -34,7 +34,8 @@ enum KstAxisInterpretation {
   AXIS_INTERP_MJD,
   AXIS_INTERP_RJD,
   AXIS_INTERP_AIT,
-  AXIS_INTERP_AIT_NANO };
+  AXIS_INTERP_AIT_NANO,
+  AXIS_INTERP_AIT_PLANCK_IDEF };
 
 enum KstAxisDisplay { 
   AXIS_DISPLAY_YEAR,
@@ -76,7 +77,8 @@ const AxisInterpretation AxisInterpretations[] = {
   { I18N_NOOP2("Modified Julian Date", "MJD"), AXIS_INTERP_MJD },
   { I18N_NOOP2("Reduced Julian Date", "RJD"), AXIS_INTERP_RJD },
   { I18N_NOOP2("Temps Atomique International", "TAI"), AXIS_INTERP_AIT },
-  { I18N_NOOP2("Temps Atomique International - Nanoseconds", "TAI (ns)"), AXIS_INTERP_AIT_NANO }
+  { I18N_NOOP2("Temps Atomique International - Nanoseconds", "TAI (ns)"), AXIS_INTERP_AIT_NANO },
+  { I18N_NOOP2("Temps Atomique International - 2^-16 seconds", "TAI (2^-16 seconds)"), AXIS_INTERP_AIT_PLANCK_IDEF }
 };
 
 const AxisDisplay AxisDisplays[] = {
