@@ -27,6 +27,7 @@
 #include "kstcolorsequence.h"
 #include "kstdatacollection.h"
 #include "kstdebug.h"
+#include "kstdefaultnames.h"
 #include "kstlinestyle.h"
 #include "kstmath.h"
 #include "kstrvector.h"
@@ -67,9 +68,9 @@ KstVCurve::KstVCurve(const QString &in_tag, KstVectorPtr in_X, KstVectorPtr in_Y
   setLineStyle(0);
   setBarStyle(0);
   setPointDensity(0);
+  setPointStyle(0);
   setInterp(InterpY);
 
-  commonConstructor(in_tag, in_color);
   if (in_X) {
     _inputVectors[COLOR_XVECTOR] = in_X;
   }
@@ -94,6 +95,7 @@ KstVCurve::KstVCurve(const QString &in_tag, KstVectorPtr in_X, KstVectorPtr in_Y
     _inputVectors[EYMINUSVECTOR] = in_EYMinus;
   }
 
+  commonConstructor(in_tag, in_color);
   setDirty();
 }
 
@@ -101,8 +103,7 @@ KstVCurve::KstVCurve(const QString &in_tag, KstVectorPtr in_X, KstVectorPtr in_Y
 KstVCurve::KstVCurve(QDomElement &e)
 : KstBaseCurve(e) {
   QString in_tag, xname, yname, exname, eyname, exminusname, eyminusname;
-  // QColor in_color(KstColorSequence::next(-1));
-  QColor in_color("red"); // the above line is invalid.
+  QColor in_color("red");
   bool hasMinus = false;
 
   setHasPoints(false);
@@ -146,25 +147,25 @@ KstVCurve::KstVCurve(QDomElement &e)
         setLegendText(e.text());
       // the following options are only needed to change from the default
       } else if (e.tagName() == "hasLines") {
-        HasLines = e.text() != "0";
+        _hasLines = e.text() != "0";
       } else if (e.tagName() == "hasPoints") {
-        HasPoints = e.text() != "0";
+        _hasPoints = e.text() != "0";
       } else if (e.tagName() == "hasBars") {
-        HasBars = e.text() != "0";
+        _hasBars = e.text() != "0";
       } else if (e.tagName() == "pointType") {
-        PointStyle = e.text().toInt();
+        _pointStyle = e.text().toInt();
       } else if (e.tagName() == "lineWidth") {
-        LineWidth = e.text().toInt();
+        _lineWidth = e.text().toInt();
       } else if (e.tagName() == "lineStyle") {
-        LineStyle = e.text().toInt();
+        _lineStyle = e.text().toInt();
       } else if (e.tagName() == "barStyle") {
-        BarStyle = e.text().toInt();
+        _barStyle = e.text().toInt();
       } else if (e.tagName() == "pointDensity") {
-        PointDensity = e.text().toInt();
+        _pointDensity = e.text().toInt();
       } else if (e.tagName() == "ignoreAutoScale") {
         _ignoreAutoScale = true;
       } else if (e.tagName() == "interp") {
-	_interp = KstVCurve::InterpType(e.text().toInt());
+        _interp = KstVCurve::InterpType(e.text().toInt());
       }
     }
     n = n.nextSibling();
@@ -193,12 +194,17 @@ KstVCurve::KstVCurve(QDomElement &e)
 
 
 void KstVCurve::commonConstructor(const QString &in_tag, const QColor &in_color) {
-  MaxX = MinX = MeanX = MaxY = MinY = MeanY = MinPosX = MinPosY = 0;
+  _maxX = _minX = _meanX = _maxY = _minY = _meanY = _minPosX = _minPosY = 0.0;
   NS = 0;
   _typeString = i18n("Curve");
   _type = "Curve";
-  Color = in_color;
-  setTagName(KstObjectTag::fromString(in_tag));
+  _color = in_color;
+  if (in_tag == QString::null) {
+    QString tag_name = KST::suggestCurveName(yVTag());
+    setTagName(KstObjectTag::fromString(tag_name));
+  } else {
+    setTagName(KstObjectTag::fromString(in_tag));
+  }
   updateParsedLegendTag();
 }
 
@@ -250,25 +256,25 @@ KstObject::UpdateType KstVCurve::update(int update_counter) {
     depUpdated = UPDATE == eymV->update(update_counter) || depUpdated;
   }
 
-  MaxX = cxV->max();
-  MinX = cxV->min();
-  MeanX = cxV->mean();
-  MinPosX = cxV->minPos();
+  _maxX = cxV->max();
+  _minX = cxV->min();
+  _meanX = cxV->mean();
+  _minPosX = cxV->minPos();
   _ns_maxx = cxV->ns_max();
   _ns_minx = cxV->ns_min();
 
-  if (MinPosX > MaxX) {
-    MinPosX = 0;
+  if (_minPosX > _maxX) {
+    _minPosX = 0.0;
   }
-  MaxY = cyV->max();
-  MinY = cyV->min();
-  MeanY = cyV->mean();
-  MinPosY = cyV->minPos();
+  _maxY = cyV->max();
+  _minY = cyV->min();
+  _meanY = cyV->mean();
+  _minPosY = cyV->minPos();
   _ns_maxy = cyV->ns_max();
   _ns_miny = cyV->ns_min();
 
-  if (MinPosY > MaxY) {
-    MinPosY = 0;
+  if (_minPosY > _maxY) {
+    _minPosY = 0;
   }
 
   switch (interp()) {
@@ -505,21 +511,21 @@ void KstVCurve::save(QTextStream &ts, const QString& indent) {
   if (_inputVectors.contains(EYMINUSVECTOR)) {
     ts << l2 << "<eyMinusVectag>" << QStyleSheet::escape(_inputVectors[EYMINUSVECTOR]->tag().tagString()) << "</eyMinusVectag>" << endl;
   }
-  ts << l2 << "<color>" << Color.name() << "</color>" << endl;
-  if (HasLines) {
+  ts << l2 << "<color>" << _color.name() << "</color>" << endl;
+  if (_hasLines) {
     ts << l2 << "<hasLines/>" << endl;
   }
-  ts << l2 << "<lineWidth>" << LineWidth << "</lineWidth>" << endl;
-  ts << l2 << "<lineStyle>" << LineStyle << "</lineStyle>" << endl;
-  if (HasPoints) {
+  ts << l2 << "<lineWidth>" << _lineWidth << "</lineWidth>" << endl;
+  ts << l2 << "<lineStyle>" << _lineStyle << "</lineStyle>" << endl;
+  if (_hasPoints) {
     ts << l2 << "<hasPoints/>" << endl;
   }
-  ts << l2 << "<pointType>" << PointStyle << "</pointType>" << endl;
-  ts << l2 << "<pointDensity>" << PointDensity << "</pointDensity>" << endl;
-  if (HasBars) {
+  ts << l2 << "<pointType>" << _pointStyle << "</pointType>" << endl;
+  ts << l2 << "<pointDensity>" << _pointDensity << "</pointDensity>" << endl;
+  if (_hasBars) {
     ts << l2 << "<hasBars/>" << endl;
   }
-  ts << l2 << "<barStyle>" << BarStyle << "</barStyle>" << endl;
+  ts << l2 << "<barStyle>" << _barStyle << "</barStyle>" << endl;
   if (_ignoreAutoScale) {
     ts << l2 << "<ignoreAutoScale/>" << endl;
   }
@@ -763,33 +769,34 @@ int KstVCurve::getIndexNearXY(double x, double dx_per_pix, double y) const {
       index = i;
     }
   }
+
   return index;
 }
 
 
 void KstVCurve::setHasPoints(bool in_HasPoints) {
-  HasPoints = in_HasPoints;
+  _hasPoints = in_HasPoints;
   setDirty();
   emit modifiedLegendEntry();
 }
 
 
 void KstVCurve::setHasLines(bool in_HasLines) {
-  HasLines = in_HasLines;
+  _hasLines = in_HasLines;
   setDirty();
   emit modifiedLegendEntry();
 }
 
 
 void KstVCurve::setHasBars(bool in_HasBars) {
-  HasBars = in_HasBars;
+  _hasBars = in_HasBars;
   setDirty();
   emit modifiedLegendEntry();
 }
 
 
 void KstVCurve::setLineWidth(int in_LineWidth) {
-  LineWidth = in_LineWidth;
+  _lineWidth = in_LineWidth;
   setDirty();
   emit modifiedLegendEntry();
 }
@@ -797,7 +804,7 @@ void KstVCurve::setLineWidth(int in_LineWidth) {
 
 void KstVCurve::setLineStyle(int in_LineStyle) {
   if (in_LineStyle >= 0 && (unsigned int)in_LineStyle < KSTLINESTYLE_MAXTYPE) {
-    LineStyle = in_LineStyle;
+    _lineStyle = in_LineStyle;
     setDirty();
     emit modifiedLegendEntry();
   }
@@ -805,7 +812,7 @@ void KstVCurve::setLineStyle(int in_LineStyle) {
 
 
 void KstVCurve::setBarStyle(int in_BarStyle) {
-  BarStyle = in_BarStyle;
+  _barStyle = in_BarStyle;
   setDirty();
   emit modifiedLegendEntry();
 }
@@ -813,16 +820,15 @@ void KstVCurve::setBarStyle(int in_BarStyle) {
 
 void KstVCurve::setPointDensity(int in_PointDensity) {
   if (in_PointDensity >= 0 && (unsigned int)in_PointDensity < KSTPOINTDENSITY_MAXTYPE) {
-    PointDensity = in_PointDensity;
+    _pointDensity = in_PointDensity;
     setDirty();
   }
 }
 
 
 void KstVCurve::setPointStyle(int in_PointStyle) {
-  if (in_PointStyle >= 0 && (unsigned int)in_PointStyle < KSTPOINT_MAXTYPE)
-  {
-    PointStyle = in_PointStyle;
+  if (in_PointStyle >= 0 && (unsigned int)in_PointStyle < KSTPOINT_MAXTYPE) {
+    _pointStyle = in_PointStyle;
     setDirty();
     emit modifiedLegendEntry();
   }
@@ -831,24 +837,24 @@ void KstVCurve::setPointStyle(int in_PointStyle) {
 
 void KstVCurve::setColor(const QColor& new_c) {
   setDirty();
-  Color = new_c;
+  _color = new_c;
   emit modifiedLegendEntry();
 }
 
 
 double KstVCurve::maxX() const {
   if (hasBars() && sampleCount() > 0) {
-    return MaxX + (MaxX - MinX)/(2*(sampleCount()-1));
+    return _maxX + (_maxX - _minX)/(2*(sampleCount()-1));
   }
-  return MaxX;
+  return _maxX;
 }
 
 
 double KstVCurve::minX() const {
   if (hasBars() && sampleCount() > 0) {
-    return MinX - (MaxX - MinX)/(2*(sampleCount()-1));
+    return _minX - (_maxX - _minX)/(2*(sampleCount()-1));
   }
-  return MinX;
+  return _minX;
 }
 
 
@@ -864,15 +870,15 @@ KstDataObjectPtr KstVCurve::makeDuplicate(KstDataObjectDataObjectMap& duplicated
   while (KstData::self()->dataTagNameNotUnique(name, false)) {
     name += '\'';
   }
-  KstVCurvePtr vcurve = new KstVCurve(name, VX, VY, EX, EY, EXMinus, EYMinus, Color);
+  KstVCurvePtr vcurve = new KstVCurve(name, VX, VY, EX, EY, EXMinus, EYMinus, _color);
   // copy some other properties as well
-  vcurve->setHasPoints(HasPoints);
-  vcurve->setHasLines(HasLines);
-  vcurve->setHasBars(HasBars);
-  vcurve->setBarStyle(BarStyle);
-  vcurve->setLineWidth(LineWidth);
-  vcurve->setLineStyle(LineStyle);
-  vcurve->setPointDensity(PointDensity);
+  vcurve->setHasPoints(_hasPoints);
+  vcurve->setHasLines(_hasLines);
+  vcurve->setHasBars(_hasBars);
+  vcurve->setBarStyle(_barStyle);
+  vcurve->setLineWidth(_lineWidth);
+  vcurve->setLineStyle(_lineStyle);
+  vcurve->setPointDensity(_pointDensity);
 
   duplicatedMap.insert(this, KstDataObjectPtr(vcurve));
   return KstDataObjectPtr(vcurve);
@@ -916,13 +922,13 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
     Qt::PenStyle style = KstLineStyle[lineStyle()];
     int i0, iN;
     int width;
-    
+
     if (lineWidth() == 0) {
       width = penWidth;
     } else {
       width = lineWidth() * penWidth;
     }
-    
+
     if (xv->isRising()) {
       i0 = indexNearX(XMin, xv, NS);
       if (i0 > 0) {
@@ -1222,6 +1228,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         overlap = false;
       }
     } // end if hasLines()
+
 #ifdef BENCHMARK
     clock_t linesEnd = clock();
     kstdDebug() << "        Lines clocks: " << (linesEnd - linesStart) << endl;
@@ -1232,6 +1239,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
     KstVectorPtr eyv = *_inputVectors.find(EYVECTOR);
     KstVectorPtr exmv = *_inputVectors.find(EXMINUSVECTOR);
     KstVectorPtr eymv = *_inputVectors.find(EYMINUSVECTOR);
+
     // draw the bargraph bars, if any...
     if (hasBars()) {
       bool has_top = true;
@@ -1248,26 +1256,26 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         p->setPen(QPen(color(), width, style));
       }
 
-      if (!exv) {        
+      if (!exv) {
         // determine the bar position width. NOTE: This is done
         //  only if xv->isRising() as in this case the calculation
         //  is simple...
         drX = (maxX() - minX())/double(sampleCount());
-        if (xv->isRising()) {       
+        if (xv->isRising()) {
           double oldX = 0.0;
 
           for (i_pt = i0; i_pt <= iN; i_pt++) {
             rX = xv->interpolate(i_pt, NS);
-            if (i_pt > i0) {                      
+            if (i_pt > i0) {
               if (rX - oldX < drX) {
-                drX = rX - oldX;                      
+                drX = rX - oldX;
               }
             }
             oldX = rX; 
           }
         }
       }
-      
+
       for (i_pt = i0; i_pt <= iN; i_pt++) {
         visible = has_bot = has_top = has_left = has_right = true;
 
@@ -1366,8 +1374,9 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
 #ifdef BENCHMARK
     b_2 = benchtmp.elapsed();
 #endif
-
-    p->setPen(QPen(color(), width));
+    QPen pen(color(), width);
+    pen.setCapStyle(Qt::RoundCap);
+    p->setPen(pen);
 
     // draw the points, if any...
     if (hasPoints()) {
@@ -1392,7 +1401,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           pt.setX(d2i(m_X * rX + b_X));
           pt.setY(d2i(m_Y * rY + b_Y));
           if (rgn.contains(pt)) {
-            KstCurvePointSymbol::draw(PointStyle, p, pt.x(), pt.y(), width);
+            KstCurvePointSymbol::draw(_pointStyle, p, pt.x(), pt.y(), width);
             rgn -= QRegion(pt.x()-(size/2), pt.y()-(size/2), size, size, QRegion::Ellipse);
           }
         }
@@ -1410,7 +1419,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           X1 = m_X * rX + b_X;
           Y1 = m_Y * rY + b_Y;
           if (X1 >= Lx && X1 <= Hx && Y1 >= Ly && Y1 <= Hy) {
-            KstCurvePointSymbol::draw(PointStyle, p, d2i(X1), d2i(Y1), width);
+            KstCurvePointSymbol::draw(_pointStyle, p, d2i(X1), d2i(Y1), width);
           }
         }
       }
@@ -1490,12 +1499,20 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         if (X1 < Lx && X2 > Lx) {
           X1 = Lx;
           do_low_flag = false;
+        } else if (X1 > Lx && X2 < Lx) {
+          X2 = Lx;
+          do_high_flag = false;
         }
+
         if (X1 < Hx && X2 > Hx) {
           X2 = Hx;
           do_high_flag = false;
+        } else if (X1 > Hx && X2 < Hx) {
+          X1 = Hx;
+          do_low_flag = false;
         }
 
+
         if (X1 >= Lx && X2 <= Hx && Y1 >= Ly && Y1 <= Hy) {
           int X1i = d2i(X1);
           int X2i = d2i(X2);
@@ -1581,10 +1598,17 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         if (Y1 < Ly && Y2 > Ly) {
           Y1 = Ly;
           do_low_flag = false;
+        } else if (Y1 > Ly && Y2 < Ly) {
+          Y2 = Ly;
+          do_high_flag = false;
         }
+
         if (Y1 < Hy && Y2 > Hy) {
           Y2 = Hy;
           do_high_flag = false;
+        } else if (Y1 > Hy && Y2 < Hy) {
+          Y1 = Hy;
+          do_low_flag = false;
         }
 
         if (X1 >= Lx && X1 <= Hx && Y1 >= Ly && Y2 <= Hy) {
@@ -1626,7 +1650,7 @@ void KstVCurve::yRange(double xFrom, double xTo, double* yMin, double* yMax) {
   KstVectorPtr xv = *_inputVectors.find(COLOR_XVECTOR);
   KstVectorPtr yv = *_inputVectors.find(COLOR_YVECTOR);
   if (!xv || !yv) {
-    *yMin = *yMax = 0;
+    *yMin = *yMax = 0.0;
     return;
   }
 
@@ -1639,12 +1663,16 @@ void KstVCurve::yRange(double xFrom, double xTo, double* yMin, double* yMax) {
     i0 = 0;
     iN = sampleCount() - 1;
   }
+
   // search for min/max
   bool first = true;
-  double newYMax = 0, newYMin = 0;
+  double newYMax = 0.0;
+  double newYMin = 0.0;
+
   for (int i_pt = i0; i_pt <= iN; i_pt++) {
     double rX = xv->interpolate(i_pt, NS);
     double rY = yv->interpolate(i_pt, NS);
+
     // make sure this point is visible
     if (rX >= xFrom && rX <= xTo) {
       // update min/max
@@ -1676,52 +1704,237 @@ KstDataObjectPtr KstVCurve::providerDataObject() const {
 }
 
 
-double KstVCurve::distanceToPoint(double xpos, double dx, double ypos) const {
-// find the y distance between the curve and a point. return 1.0E300 if this distance is undefined. i don't want to use -1 because it will make the code which uses this function messy.
-  KstVectorPtr xv = *_inputVectors.find(COLOR_XVECTOR);
-  if (!xv) {
-    return 1.0E300; // anything better we can do?
-  }
+double KstVCurve::distanceToPoint(double xpos, double ypos, double distanceMax, const KstCurveRenderContext& context) {
+  //
+  // xpos, ypos are values rather than pixel position...
+  //
+  double distance = -1.0;
 
-  double distance = 1.0E300;
+  if (hasLines() || hasPoints()) {
+    KstVectorPtr xv = *_inputVectors.find(COLOR_XVECTOR);
+    double distanceNew;
+    double xposPixel;
+    double yposPixel;
+    double xposPoint;
+    double yposPoint;
+    double yOffset;
+    double xNear;
+    double yNear;
+    double yMin;
+    double yMax;
+    double xLo;
+    double xHi;
+    bool doneLine = false;
+    int iNearX;
+    int i;
 
-  int i_near_x = getIndexNearXY(xpos, dx, ypos);
-  double near_x, near_y;
-  point(i_near_x, near_x, near_y);
-
-  if (fabs(near_x - xpos) < dx) {
-    distance = fabs(ypos - near_y); // initial estimate.
-  }
-
-  if (hasLines() && xv->isRising()) {
-    // if hasLines then we should find the distance between the curve and the point, not the data and 
-    //  the point. if isRising because it is (probably) to slow to use this technique if the data is 
-    //  unordered. borrowed from indexNearX. use binary search to find the indices immediately above 
-    //  and below our xpos.
-    int i_top = NS - 1;
-    int i_bot = 0;
-
-    while (i_bot + 1 < i_top) {
-      int i0 = (i_top + i_bot)/2;
-
-      double rX = xv->interpolate(i0, NS);
-      if (xpos < rX) {
-        i_top = i0;
-      } else {
-        i_bot = i0;
-      }
+    if (context.xLog) {
+      xposPixel = logXLo(xpos, context.xLogBase);
+      xposPixel = context.m_X*xposPixel + context.b_X;
+    } else {
+      xposPixel = context.m_X*xpos + context.b_X;
     }
-    // end borrowed
 
-    double x_bot, y_bot, x_top, y_top;
-    point(i_bot, x_bot, y_bot);
-    point(i_top, x_top, y_top);
+    if (context.yLog) {
+      yposPixel = logYLo(ypos, context.yLogBase);
+      yposPixel = context.m_Y*yposPixel + context.b_Y;
+    } else {
+      yposPixel = context.m_Y*ypos + context.b_Y;
+    }
 
-    if (x_bot <= xpos && x_top >= xpos) {
-      near_y = (y_top - y_bot) / (x_top - x_bot) * (xpos - x_bot) + y_bot; // calculate y value for line segment between x_bot and x_top.
-      
-      if (fabs(ypos - near_y) < distance) {
-        distance = fabs(ypos - near_y);
+    iNearX = getIndexNearXY(xpos, distanceMax, ypos);
+    if (iNearX != -1) {
+      point(iNearX, xNear, yNear);
+      if (context.xLog) {
+        xposPoint = logXLo(xNear, context.xLogBase);
+        xposPoint = context.m_X*xposPoint + context.b_X;
+      } else {
+        xposPoint = context.m_X*xNear + context.b_X;
+      }
+
+      if (context.yLog) {
+        yposPoint = logYLo(yNear, context.yLogBase);
+        yposPoint = context.m_Y*yposPoint + context.b_Y;
+      } else {
+        yposPoint = context.m_Y*yNear + context.b_Y;
+      }
+
+      distance = sqrt(((xposPoint - xposPixel)*(xposPoint - xposPixel)) + ((yposPoint - yposPixel)*(yposPoint - yposPixel)));
+    }
+
+    if (xv && xv->isRising()) {
+      if (hasLines()) {
+        //
+        // check how far the closest line is from -5 to +5 pixels from our current x-position...
+        //
+        for (i=-5; i<5; ++i) {
+          if (context.xLog) {
+            xLo = pow(context.xLogBase, logXLo(xpos) + ((double)i / context.m_X));
+            xHi = pow(context.xLogBase, logXLo(xpos) + (((double)i+1.0) / context.m_X));
+          } else {
+            xLo = xpos + ((double)i / context.m_X);
+            xHi = xpos + (((double)i+1.0) / context.m_X);
+          }
+
+          if (xLo >= minX() && xHi <= maxX()) {
+            yRange(xLo, xHi, &yMin, &yMax);
+
+            if (yMin == 0.0 && yMax == 0.0 && !doneLine) {
+              //
+              // we are probably on a line, in between two points...
+              //
+              KstVectorPtr xv = *_inputVectors.find(COLOR_XVECTOR);
+
+              if (xv && xv->isRising()) {
+                // if hasLines then we should find the distance between the curve and the point, not the data and 
+                //  the point. if isRising because it is (probably) to slow to use this technique if the data is 
+                //  unordered. borrowed from indexNearX. use binary search to find the indices immediately above 
+                //  and below our xpos.
+                double xBottom;
+                double yBottom;
+                double xTop;
+                double yTop;
+                int iTop = NS - 1;
+                int iBottom = 0;
+
+                while (iBottom + 1 < iTop) {
+                  int i0 = (iTop + iBottom)/2;
+                  double rX = xv->interpolate(i0, NS);
+
+                  if (xpos < rX) {
+                    iTop = i0;
+                  } else {
+                    iBottom = i0;
+                  }
+                }
+
+                point(iBottom, xBottom, yBottom);
+                point(iTop, xTop, yTop);
+
+                if (xBottom <= xpos && xTop >= xpos) {
+                  if (context.xLog) {
+                    xTop = logXLo(xTop, context.xLogBase);
+                    xTop = context.m_X*xTop + context.b_X;
+                    xBottom = logXLo(xBottom, context.xLogBase);
+                    xBottom = context.m_X*xBottom + context.b_X;
+                  } else {
+                    xTop = context.m_X*xTop + context.b_X;
+                    xBottom = context.m_X*xBottom + context.b_X;
+                  }
+
+                  if (context.yLog) {
+                    yTop = logYLo(yTop, context.yLogBase);
+                    yTop = context.m_Y*yTop + context.b_Y;
+                    yBottom = logYLo(yBottom, context.yLogBase);
+                    yBottom = context.m_Y*yBottom + context.b_Y;
+                  } else {
+                    yTop = context.m_Y*yTop + context.b_Y;
+                    yBottom = context.m_Y*yBottom + context.b_Y;
+                  }
+
+                  distanceNew = fabs(((xTop-xBottom)*(yBottom-yposPixel)) - ((xBottom-xposPixel)*(yTop-yBottom)));
+                  distanceNew /= sqrt(((xTop-xBottom)*(xTop-xBottom)) + ((yTop-yBottom)*(yTop-yBottom)));
+
+                  if (distance == -1.0 || distanceNew < distance) {
+                    distance = distanceNew;
+                  }
+                }
+              }
+              doneLine = true;
+            } else {
+              //
+              // we are probably in an area of very dense lines...
+              //
+              if (context.yLog) {
+                yMin = logYLo(yMin, context.yLogBase);
+                yMax = logYLo(yMax, context.yLogBase);
+              }
+              yMin = context.m_Y*yMin + context.b_Y;
+              yMax = context.m_Y*yMax + context.b_Y;
+
+              if ((yMin <= yposPixel && yposPixel <= yMax) || 
+                  (yMax <= yposPixel && yposPixel <= yMin)) {
+                yOffset = 0.0;
+              } else if (fabs(yMin - yposPixel) < fabs(yMax - yposPixel)) {
+                yOffset = fabs(yMin - yposPixel);
+              } else {
+                yOffset = fabs(yMax - yposPixel);
+              }
+              distanceNew = ((double)i * (double)i) + (yOffset * yOffset);
+              distanceNew = sqrt(distanceNew);
+              if (distance == -1.0 || distanceNew < distance) {
+                distance = distanceNew;
+              }
+            }
+          }
+        }
+      } else {
+        //
+        // we have points only and need to check more carefully if we are close to a point...
+        //
+        KstVectorPtr xv = xVector();
+        KstVectorPtr yv = yVector();
+        double xPixel;
+        double yPixel;
+        double x;
+        double y;
+        int iNearXLoop;
+
+        if (xv && yv) {
+          iNearXLoop = iNearX;
+          xPixel = context.Hx;
+          while (iNearXLoop > 0 && xPixel > context.Lx && xPixel > xposPixel - distanceMax) {
+            x = xv->interpolate(iNearXLoop, NS);
+            y = yv->interpolate(iNearXLoop, NS);
+            if (context.xLog) {
+              xPixel = logXLo(x, context.xLogBase);
+              xPixel = context.m_X*xPixel + context.b_X;
+            } else {
+              xPixel = context.m_X*x + context.b_X;
+            }
+
+            if (context.yLog) {
+              yPixel = logYLo(y, context.yLogBase);
+              yPixel = context.m_Y*yPixel + context.b_Y;
+            } else {
+              yPixel = context.m_Y*y + context.b_Y;
+            }
+
+            distanceNew = sqrt(((xPixel - xposPixel)*(xPixel - xposPixel)) + 
+                               ((yPixel - yposPixel)*(yPixel - yposPixel)));
+            if (distanceNew < distance || distance == -1.0) {
+              distance = distanceNew;
+            }
+            iNearXLoop--;
+          }
+
+          iNearXLoop = iNearX;
+          xPixel = context.Lx;
+          while (iNearXLoop < NS && xPixel < context.Hx && xPixel < xposPixel + distanceMax) {
+            x = xv->interpolate(iNearXLoop, NS);
+            y = yv->interpolate(iNearXLoop, NS);
+            if (context.xLog) {
+              xPixel = logXLo(x, context.xLogBase);
+              xPixel = context.m_X*xPixel + context.b_X;
+            } else {
+              xPixel = context.m_X*x + context.b_X;
+            }
+
+            if (context.yLog) {
+              yPixel = logYLo(y, context.yLogBase);
+              yPixel = context.m_Y*yPixel + context.b_Y;
+            } else {
+              yPixel = context.m_Y*y + context.b_Y;
+            }
+
+            distanceNew = sqrt(((xPixel - xposPixel)*(xPixel - xposPixel)) + 
+                               ((yPixel - yposPixel)*(yPixel - yposPixel)));
+            if (distanceNew < distance || distance == -1.0) {
+              distance = distanceNew;
+            }
+            iNearXLoop++;
+          }
+        }
       }
     }
   }
@@ -1749,7 +1962,7 @@ void KstVCurve::paintLegendSymbol(KstPainter *p, const QRect& bound) {
   if (hasPoints()) {
     // draw a point in the middle
     p->setPen(QPen(color(), width));
-    KstCurvePointSymbol::draw(PointStyle, p, bound.left() + bound.width()/2, bound.top() + bound.height()/2, width, 600);
+    KstCurvePointSymbol::draw(_pointStyle, p, bound.left() + bound.width()/2, bound.top() + bound.height()/2, width, 600);
   }
   p->restore();
 }
