@@ -497,9 +497,9 @@ void KstVectorView::setYVector(KstVectorPtr new_v) {
 }
 
 
-void KstVectorView::setFlagVector(KstVectorPtr Flag) {
-  if (Flag) {
-    _inputVectors[IN_FLAGVECTOR] = Flag;
+void KstVectorView::setFlagVector(KstVectorPtr flag) {
+  if (flag) {
+    _inputVectors[IN_FLAGVECTOR] = flag;
   } else {
     _inputVectors.remove(IN_FLAGVECTOR);
   }
