@@ -51,10 +51,14 @@ BinnedMap::BinnedMap( QObject */*parent*/, const char */*name*/, const QStringLi
     : KstDataObject() {
   _typeString = i18n("Plugin");
   _type = "Plugin";
-  _xMin = _yMin = -1;
-  _xMax = _yMax = 1;
-  _nx = _ny = 1;
-  _autoBin = false;
+
+  setXMin(-1.0);
+  setYMin(-1.0);
+  setXMax(1.0);
+  setYMax(1.0);
+  setNX(1);
+  setNY(1);
+  setAutoBin(false);
 }
 
 BinnedMap::~BinnedMap() {
@@ -240,7 +244,7 @@ void BinnedMap::binnedmap() {
   KstScalarPtr autobin = *_inputScalars.find(AUTOBIN);
 
   if (autobin) {
-    if (autobin->value()) {
+    if (autobin->value() != 0.0) {
       _autoBin = true;
     } else {
       _autoBin = false;
@@ -248,7 +252,17 @@ void BinnedMap::binnedmap() {
   }
 
   if (_autoBin) {
-    AutoSize(X(), Y(), &_nx, &_xMin, &_xMax, &_ny, &_yMin, &_yMax);
+    double minx, miny, maxx, maxy;
+    int nx, ny;
+
+    autoSize(X(), Y(), &nx, &minx, &maxx, &ny, &miny, &maxy);
+
+    setNX(nx);
+    setNY(ny);
+    setXMin(minx);
+    setXMax(maxx);
+    setYMin(miny);
+    setYMax(maxy);
   } else {
     KstScalarPtr xmin = *_inputScalars.find(XMIN);
     KstScalarPtr xmax = *_inputScalars.find(XMAX);
@@ -428,48 +442,60 @@ void BinnedMap::save(QTextStream& ts, const QString& indent) {
 }
 
 void BinnedMap::setXMin(double xmin) {
-  _inputScalars.remove(XMIN);
+  if (_inputScalars.find(XMIN) != _inputScalars.end()) {
+    _inputScalars[XMIN]->setValue(xmin);
+  }
   _xMin = xmin;
 }
 
 void BinnedMap::setXMax(double xmax) {
-  _inputScalars.remove(XMAX);
+  if (_inputScalars.find(XMAX) != _inputScalars.end()) {
+    _inputScalars[XMAX]->setValue(xmax);
+  }
   _xMax = xmax;
 }
 
 void BinnedMap::setYMin(double ymin) {
-  _inputScalars.remove(YMIN);
+  if (_inputScalars.find(YMIN) != _inputScalars.end()) {
+    _inputScalars[YMIN]->setValue(ymin);
+  }
   _yMin = ymin;
 }
 
 void BinnedMap::setYMax(double ymax) {
-  _inputScalars.remove(YMAX);
+  if (_inputScalars.find(YMAX) != _inputScalars.end()) {
+    _inputScalars[YMAX]->setValue(ymax);
+  }
   _yMax = ymax;
 }
 
 double BinnedMap::xMin() const {
-  return (_xMin);
+  return _xMin;
 }
 
 double BinnedMap::xMax() const {
-  return(_xMax);
+  return _xMax;
 }
 
 double BinnedMap::yMin() const {
-  return(_yMin);
+  return _yMin;
 }
 
 double BinnedMap::yMax() const {
-  return(_yMax);
+  return _yMax;
 }
 
 void BinnedMap::setNX(int nx) {
-  _inputScalars.remove(NX);
+  if (_inputScalars.find(NX) != _inputScalars.end()) {
+    _inputScalars[NX]->setValue(nx);
+  }
   _nx = nx;
 }
 
 void BinnedMap::setNY(int ny) {
-  _inputScalars.remove(NY);
+  if (_inputScalars.find(NY) != _inputScalars.end()) {
+    _inputScalars[NY]->setValue(ny);
+  }
   _ny = ny;
 }
 
@@ -482,7 +508,13 @@ int BinnedMap::BinnedMap::nY() const {
 }
 
 void BinnedMap::setAutoBin(bool autobin) {
-  _inputScalars.remove(AUTOBIN);
+  if (_inputScalars.find(AUTOBIN) != _inputScalars.end()) {
+    if (autobin) {
+      _inputScalars[AUTOBIN]->setValue(1.0);
+    } else {
+      _inputScalars[AUTOBIN]->setValue(0.0);
+    }
+  }
   _autoBin = autobin;
 }
 
@@ -490,7 +522,7 @@ bool BinnedMap::autoBin() const {
   return _autoBin;
 }
 
-void BinnedMap::AutoSize(KstVectorPtr x, KstVectorPtr y, int *nx, double *minx, double *maxx, int *ny, double *miny, double *maxy) {
+void BinnedMap::autoSize(KstVectorPtr x, KstVectorPtr y, int *nx, double *minx, double *maxx, int *ny, double *miny, double *maxy) {
 
   // use a very simple guess at nx and ny... One could imagine something more
   // clever in principle.
