@@ -25,6 +25,8 @@ class BinnedMap : public KstDataObject {
     BinnedMap(QObject *parent, const char *name, const QStringList &args);
     virtual ~BinnedMap();
 
+    static void autoSize(KstVectorPtr x, KstVectorPtr y, int *nx, double *minx, double *maxx, int *ny, double *miny, double *maxy);
+
     // algorithm
     void binnedmap();
 
@@ -72,8 +74,6 @@ class BinnedMap : public KstDataObject {
     int nX() const;
     int nY() const;
 
-    static void AutoSize(KstVectorPtr x, KstVectorPtr y, int *nx, double *minx, double *maxx, int *ny, double *miny, double *maxy);
-
     void setAutoBin(bool);
     bool autoBin() const;
 
