@@ -40,6 +40,8 @@ class KST_EXPORT BinnedMapDialogI : public KstDataDialog {
   protected:
     virtual void fillFieldsForEdit();
     virtual void fillFieldsForNew();
+    QString editTitle();
+    QString newTitle();
 
   private:
     bool editSingleObject(BinnedMapPtr cps);
