@@ -236,7 +236,6 @@ void CrossPowerSpectrum::setFrequency(const QString &name) {
 
 KstObject::UpdateType CrossPowerSpectrum::update(int updateCounter) {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
-
   bool force = dirty();
   setDirty(false);
 
@@ -256,28 +255,24 @@ KstObject::UpdateType CrossPowerSpectrum::update(int updateCounter) {
 
   writeLockInputsAndOutputs();
 
-  depUpdated = UPDATE == v1()->update(updateCounter) || depUpdated;
-  depUpdated = UPDATE == v2()->update(updateCounter) || depUpdated;
+  depUpdated = ( ( UPDATE == v1()->update(updateCounter) ) || depUpdated );
+  depUpdated = ( ( UPDATE == v2()->update(updateCounter) ) || depUpdated );
 
-  depUpdated = UPDATE == fft()->update(updateCounter) || depUpdated;
-  depUpdated = UPDATE == sample()->update(updateCounter) || depUpdated;
+  depUpdated = ( ( UPDATE == fft()->update(updateCounter) ) || depUpdated );
+  depUpdated = ( ( UPDATE == sample()->update(updateCounter) ) || depUpdated );
 
-  crossspectrum();
+  if (depUpdated) {
+    crossspectrum();
 
-  vectorRealloced(real(), real()->value(), real()->length());
-  real()->setDirty();
-  real()->setNewAndShift(real()->length(), real()->numShift());
-  real()->update(updateCounter);
+    vectorRealloced(real(), real()->value(), real()->length());
+    real()->setNewAndShift(real()->length(), real()->numShift());
 
-  vectorRealloced(imaginary(), imaginary()->value(), imaginary()->length());
-  imaginary()->setDirty();
-  imaginary()->setNewAndShift(imaginary()->length(), imaginary()->numShift());
-  imaginary()->update(updateCounter);
+    vectorRealloced(imaginary(), imaginary()->value(), imaginary()->length());
+    imaginary()->setNewAndShift(imaginary()->length(), imaginary()->numShift());
 
-  vectorRealloced(frequency(), frequency()->value(), frequency()->length());
-  frequency()->setDirty();
-  frequency()->setNewAndShift(frequency()->length(), frequency()->numShift());
-  frequency()->update(updateCounter);
+    vectorRealloced(frequency(), frequency()->value(), frequency()->length());
+    frequency()->setNewAndShift(frequency()->length(), frequency()->numShift());
+  }
 
   unlockInputsAndOutputs();
 
