@@ -72,6 +72,16 @@ CrossSpectrumDialogI::~CrossSpectrumDialogI() {
 }
 
 
+QString CrossSpectrumDialogI::editTitle() {
+  return i18n("Edit Cross Power Spectrum");
+}
+
+
+QString CrossSpectrumDialogI::newTitle() {
+  return i18n("New Cross Power Spectrum");
+}
+
+
 void CrossSpectrumDialogI::update() {
   _w->_v1->update();
   _w->_v2->update();
