@@ -56,7 +56,12 @@ void ScalarSelector::update()
     
     qHeapSort(scalars);
     _scalar->insertStringList(scalars);
-    if (found) {
+
+    bool ok;
+    prev.toDouble(&ok);
+    ok = ok && _scalar->editable(); //if directentry is allowed, and if prev is a number, then we can put it back into the combobox.
+
+    if (found || ok) {
         _scalar->setCurrentText(prev);
     } else {
         _scalar->insertItem("0");
@@ -143,7 +148,7 @@ void ScalarSelector::editScalar()
                 setSelection(p);
             } else {
                 p = new KstScalar(KstObjectTag(se->_name->text(), KstObjectTag::globalTagContext), 0L, val);
-                
+
                 p->setOrphan(true);
                 p->setEditable(true);
                 emit newScalarCreated();
@@ -193,10 +198,35 @@ void ScalarSelector::setSelection( KstScalarPtr s )
 QString ScalarSelector::selectedScalar()
 {
     KstScalarPtr ptr = *KST::scalarList.findTag(_scalar->currentText());
-    if (ptr)
+    if (ptr) {
         return _scalar->currentText();
-    else
+    } else {
         return QString::null;
+    }
+}
+
+KstScalarPtr ScalarSelector::selectedScalarPtr()
+//returns a pointer to the selected scalar.
+//if the scalar does not exist, but
+	//the text entered is a number and
+	//the selector is editable then
+//a new scalar is created with the given value and returned.
+{
+  KstScalarPtr ptr = *KST::scalarList.findTag(_scalar->currentText());
+  
+  if (!ptr) {
+    if (_scalar->editable()) {
+      KstWriteLocker sl(&KST::scalarList.lock());
+      bool ok;
+      double val = _scalar->currentText().toDouble(&ok);
+
+      if (ok) {
+        ptr = new KstScalar(KstObjectTag::fromString(_scalar->currentText()), 0L, val, true, false);
+      }
+    }
+  }
+
+  return ptr;
 }
 
 void ScalarSelector::allowDirectEntry( bool allowed )
